%
%
%11.9.  Signalreprsentation %<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
% Die Dekodierung leistungsfhiger Kodes ist sehr rechenintensiv.  Bei hohen 
% Datenraten muss dieses auf einem speziellen Signalprozessor oder direkt in 
% Hardware realisiert werden.  Neben dem Dekodieralgorithmus selbst ist die 
% Wahl der Datenreprsentation entscheidend fr den Aufwand.  Der Algorithmus 
% soll das Kodewort finden, welches den kleinsten Abstand hat zum aktuell 
% empfangenen Wort.  Den Einfluss der Reprsentation kann man also unabhngig 
% vom Algorithmus bestimmen.  Abhngig vom Algorithmus sind allerdings die 
% Rundungsfehler.  Diese sollen hier nicht betrachtet werden.
%
% Das  {\fontname{Courier}n} - Bit-Kodewort sei  {\fontname{Courier}c_i (i=1,...,n)}  und das empfangene Wort sei  {\fontname{Courier}y_i} .
% 
% Als Abstandsmass nehmen wir einerseits fr die harte Entscheidung, bei der 
% {\fontname{Courier}y_i}  nur in der Reprsentation durch je ein Bit vorliegt, den Hammingabstand
%
%        n                                        %<'FontName',MSVFORMFONT>
% d_h =  _{\fontsize{26}\Sigma}  y_i \oplus x_i   %<'FontName',MSVFORMFONT>
%      i=1                                        %<'FontName',MSVFORMFONT>
%
% ( {\fontname{Courier}\oplus} bedeutet {\fontname{Courier}XOR} )  und andererseits den euklidischen Abstand
%
%         n                                            %<'FontName',MSVFORMFONT>
% d_e = ( _{\fontsize{26}\Sigma}  (y_i-x_i)^2 )^{1/2}  %<'FontName',MSVFORMFONT>
%       i=1                                            %<'FontName',MSVFORMFONT>
%
% Der Fall des additiven weissen Gauss-Rauschens kann sehr einfach demonstriert 
% werden durch die Berechnung des Abstandes eines Vektors aus normalverteilten 
% Zufallszahlen zum Nullvektor.  Bei Benutzung des Hammingabstandes ist der 
% Erwartungswert
%
% E\{d_h\} = 0.5 n erfc(1/(sqrt(2)\sigma))      %<'FontName',MSVFORMFONT>
%
% und bei Benutzung des euklidischen Abstandes
% 
% E\{d_e\} = sqrt(n) \sigma                     %<'FontName',MSVFORMFONT>
%
% Die Funktion  {\fontname{Courier}simdist(n,s,b)}  stellt diese beiden Erwartungswerte ber 
% der Standardabweichung  {\fontname{Courier}\sigma}  im Bereich  {\fontname{Courier}0 ... s}  dar.  Zustzlich werden die aktuellen
% Abstnde von zuflligen Vektoren der Lnge  {\fontname{Courier}n}  als Punkte eingezeichnet.
% Darberhinaus wird die Berechnung des euklidischen Abstandes fr die binre 
% Reprsentation des Signalbereiches  {\fontname{Courier}-b ... +b}  mit 2, 3, 4 und 8 Bits durchgefhrt
%
% Das folgende Bild zeigt die Abstnde ber  {\fontname{Courier}\sigma = 0...5}  fr die Kodewortlnge  {\fontname{Courier}n = 1000} .  
% Die Reprsentation in 2, 3, 4 bzw. 8 Bits  ist dabei limitiert auf den Signalbereich  {\fontname{Courier}-5...+5} :
%
simdist(1000,3);
%
% Als erstes sehen wir, dass die oben gemachte Vorhersage (schwarze bzw. blaue 
% Linie) fr die Erwartungswerte offensichtlich gut zu den simulierten Werten 
% (schwarze bzw. blaue Punkte) passt.  Insbesondere interessieren wir uns nun 
% fr den mglichen Fehler einer auf wenige Bits beschrnkten Reprsentation.
% Betrachten wir hierzu zunchst die linke Seite des Bildes bei kleiner 
% Standardabweichung.  Deutlich zu sehen ist, dass der Abstand bei sehr kleiner 
% Standardabweichung  {\fontname{Courier}0.0 ... 0.2}  bei Null verbleibt, weil der Niveauabstand 
% der Reprsentation noch grsser als die Standardabweichung ist.  Dieser Effekt 
% ist besonders stark bei der Reprsentation mit  {\fontname{Courier}2} Bit.
% Etwas weiter rechts, aber noch im linken Teil des Bildes liegt der Abstand 
% bei Reprsentation in wenigen Bits etwas ber dem korrekten euklidischen. 
% Dies liegt am Quantisierungsrauschen, welches zum Kanalrauschen hinzukommt. 
% Im rechten Teil des Bildes ist der Effekt der Limitierung auf den Bereich  {\fontname{Courier}-b ... +b}  
% zu sehen.  Man bedenke, dass eine Vergrsserung von  {\fontname{Courier}b}  zugleich 
% entsprechend die Niveauabstnde vergrssert.  Man muss also den richtigen 
% Kompromiss zwischen der Anzahl von Bits fr die Reprsentation und den 
% reprsentierten Bereich finden.  Hierzu benutzen wir die Funktion  {\fontname{Courier}quantrand(n)} ,
% die zu gegebener Anzahl von Bits fr die Reprsentation jeweils 6 Bilder 
% erzeugt:
% 
% (1) Input/Outputverhalten eines n-Bit-Quantisierers fr den Bereich  -1 ... +1
%
% (2) Den sich aus (1) ergebenden Quantisierungsfehler
%
% (3) Die Wahrscheinlichkeitsdichte der Normalverteilung mit der Standardabweichung 1.0
%
% (4) Die Verteilungsdichte der Fehler als Produkt von (2) und (3)
%
% (5) Den mittleren quadratischen Fehler aus (4) berechnet fr verschiedene 
%      Skalierungsfaktoren ber diesem Skalierungfaktor
%
% (6) Die Verteilungsdichte wie in (4) fr den optimalen Skalierungsfaktor.
%
% Wir betrachten dies fr  {\fontname{Courier}n = 2}  und {\fontname{Courier}n = 4} :
%
quantrand(2);
%
quantrand(4);
%
% Bei weiteren Aufrufen mit  {\fontname{Courier}1 \leq n \leq 32}  zeigt sich, dass das Minimum 
% der Kurve (5) relativ scharf ist.  Die Skalierung sollte also mglicht gut 
% eingehalten werden.
%
%
%
%% bung 11.9.1  Besttigen Sie die Aussagen der voranstehenden Abstze durch 
%% passende Aufrufe von simdist und quantrand.
%