function f = simdist(n,b,sigma)
% f = simdist(n,b,sigma)
% Fr normalverteilte Zufallsvektoren wird der Abstand bestimmt 
% fr folgende Abstandsmasse:
% Hammingabstand und euklidischer Abstand sowie fr den
% euklidischen Abstand die Berechnung mit einer Reprsentation
% der Vektorkomponenten mit 2, 3 und 4 Bit im 2-Komplement.
%
% n    :  Lnge der Vektoren (Default:  1000)
% b    :  Limitierung der Reprsentation auf den Wertebereich -b,...,+b (Default: 3.0)
% sigma:  Bereich der Standardabweichung  0..sigma  (Default: sigma = b)

% Autor:  Klaus von der Heide;  e-mail:  v.d.heide@on-line.de

% Defaults und Konstanten
% =======================
if nargin<2      b = 3;    end
if nargin<3  sigma = b;    end
if nargin<1      n = 1000; end
fsiz= 13;                                % FontSize
msiz= 20;                                % MarkerSize
col = 'bkgrcm';                          % Farben
m   = 8;                                 % Anzahl simulierter Vektoren
jj  = 100;                               % Anzahl der Abszissenpunkte
rr  = [0 1 2 3 4 8];                     % Anzahl der Bits der Reprsentation

% Simulation
% ==========
for j=1:jj
   for k=1:m
      s = sigma*j/jj*randn(1,n);         % Zufallsvektor
      f(j,k,1) = sum(s>1);               % Hammingabstand
      f(j,k,2) = sqrt(sum(s.^2));        % euklidischer Abstand reell
      for r=3:length(rr)
         f(j,k,r) = b*sqrt(sum(quantize(s/b,rr(r)).^2)); % euklidischer Abstand quantisiert
      end
   end
end

% Darstellung
% ===========
hd = fullscreen('Abstand');
for j=1:jj
   for k=1:m
      for r=2:length(rr)
         line(sigma*j/jj,f(j,k,r),'Marker','.','MarkerSize',msiz,'Color',col(r))
      end
   end
end
ss = sigma*(0:100)/100;
line(ss,sqrt(n)*ss,'Color',col(2),'LineWidth',1.5)
title('Vergleich der Abstandsmae','FontSize',fsiz)
xlabel('Standardabweichung','FontSize',fsiz)
ylabel('Abstand euklidisch ohne und mit Quantisierung','FontSize',fsiz)
legend('Euklidischer Abstand','Quantisierung 2 Bit','Quantisierung 3 Bit',...
       'Quantisierung 4 Bit','Quantisierung 8 Bit','euklidisch theoretisch',2)
ax1 = gca;
ax2 = axes('Position',get(ax1,'Position'),'YAxisLocation','right','Color','none');
for j=1:jj
   for k=1:m
      line(sigma*j/jj,f(j,k,1),'Marker','.','MarkerSize',msiz,'Color',col(1),'Parent',ax2)
   end
end
line(ss,0.5*n*erfc(1./(sqrt(2)*(ss+eps))),'Color',col(1),'LineWidth',1.5)
ylabel('Hamming-Abstand','FontSize',fsiz)
legend('Hamming-Abstand','Hamming theoretisch',4)