function x = abtastbild(fkt,fs,gt)
% x = abtastbild(fkt,fs,gt)
% Demo fr die Zeitdiskretisierung eines kontinuierlichen Signals:
% fkt ist ein String, der die Funktion im Zeitbereich darstellt mit 
% der Zeitvariablen t. Diese wird im Zeitbereich gt ausgewertet. 
% Man beachte dass fkt ausser t, fs und gt  keine weiteren Variablen 
% enthalten darf, da diese innerhalb von abtastbild nicht sichtbar sind.
% fs ist die Abtastrate.
% Beispiel:
% abtastbild('exp(-t.^2).*(sin(2*pi*3*t)+0.6*sin(2*pi*5*t))',13,[-2,2]);

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<3  gt = [0 1]; end
if nargin<2  fs = 10; end
if nargin<1  fkt= 'exp(-t.^2).*(sin(2*pi*3.32*t+1)+0.6*sin(2*pi*1.71*t))'; end
ft = 15;                               % FontSize fr Beschriftung
%
% Darstellung zeitkontinuierlich
% ==============================
fh= fullscreen('Sampling');            % Bilderzeugung
t = (0:799)/800*(gt(2)-gt(1))+gt(1);   % "kontinuierlicher" Zeitbereich
line(t,zeros(size(t)));                % Zeitachse zeichnen
y = eval(fkt);                         % Funktion berechnen
line(t,y,'Color','g','LineWidth',2.0); % Funktion zeitkontinuierlich zeichnen
%
% Abtastung
% =========
ts= gt(1):1/fs:gt(2);                  % Abtastpunkte
t = ts;                                % t auf Abtastpunkte umdefinieren (wegen eval)
ys= eval(fkt);                         % Funktion an Abtastpunkten berechnen
x = ys;                                % Rckgabe dieser Funktion: abgetastete Werte
%
% Darstellung zeitdiskret
% =======================
for i = 0:length(ts)-1
   line([ts(i+1),ts(i+1)],[0,ys(i+1)],'Color','r','LineWidth',1.5); 
end
line(ts,ys,'LineStyle','none','Color','r','Marker','o','LineWidth',2,'MarkerSize',7);
title(sprintf('Abtastung von  %s',fkt),'FontSize',ft)
xlabel('Zeitbereich','FontSize',ft)
set(gca,'xlim',gt)
