function x0 = analytsig(fsin,f1,f2,snr,m,velocity,blick,nur)
% x0 = analytsig(fsin,f1,f2,snr,m,velocity,blick,nur)
% Demo fr analytische Signale. (Demo auch ohne Parameter) 
% Es wird ein Sinus-Signal der Frequenz fsin erzeugt und 
% ein weisses Rauschen hinzugefgt. Dieses Signal wird mit 
% einem IIR-Bandpass vom Grad 8 und den Passbandgrenzen f1 und f2 
% gefiltert, so dass ein bandbegrenztes Signal mit Signal/Rauschver-
% hltnis snr entsteht. Anschliessend erfolgt die Wandlung in ein 
% analytisches Signal und die Darstellung als Bewegtbild.
% Ist snr > 9999, so wird nur das ungefilterte Signal gezeigt.
% In diesem Fall kann fr fsin optional ein Vektor von zwei Komponenten 
% eingegeben werden: [Frequenz, Phase] (Freqenz; 0 <= Phase < pi).
% m gibt optional die Lnge der darzustellenden Sequenz an (Default=500).
% velocity (optional) ist die Geschwindigkeit der Animation (0.1 ... 10). 
% blick gibt optional die Blickrichtung an entsprechend view,
% blick=[90,0] sieht genau lngs der Zeitachse; default=[12,10].
% Wird nur mit beliebigem Wert angegeben, so erfolgt nur die Darstellung 
% der Animation ohne die Filter.
% Einheit von fsin,f1,f2 ist die Nyquistfrequenz = Abtastrate/2;
% das Hilberfilter lsst dabei nur den Bereich 0.02..0.98 zu.
% Zunchst werden der Frequenzgang der benutzten Filter gezeigt und die 
% Spektren des Signals. Nach beliebigem Tastendruck folgt die Animation.
% Anhalten der Animation ist mglich durch Drcken der Taste p.
% Jede Taste startet die Animation wieder.
% Die Animation wird abgebrochen mit der Taste s (danach beliebige Taste).
% Die Geschwindigkeit wird verndert mit den Tasten + und -.
% Der Blickwinkel kann mit den Tasten r l h t verndert werden.
% Wenn die Animation zuende ist, werden die Bilder mit beliebigem 
% Tastendruck gelscht mit Ausnahme des 3D-Bildes. Diese kann dann 
% mit den Tasten r l h t sowie mit der Maus gedreht werden.
% Wird analytsig ganz ohne Parameter aufgerufen, so wird 
% analytsig(0.1,0.05,0.15,3,500,1,[12,10]) dargestellt.

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<1  fsin = 0.1; end
if nargin<2  f1 = 0.05;  end
if nargin<3  f2 = 0.15;  end
if nargin<4  snr= 10000; end
if nargin<5  m  = 500;   end;  % Lnge der Darstellung im Zeitbereich
if nargin<6  velocity=1; end;  % Darstellungsgeschwindigkeit
if nargin<7  blick = [12,10]; end;
if snr<0 error('snr kann nicht kleiner als 0 sein'); end;
if length(fsin)==2  fsn = fsin(1); ph = fsin(2); 
else if length(fsin)==1 fsn = fsin; ph = 0; else fsn = 0; ph = 0; end
end
if snr<10000
   if (fsn<0)|(fsn>1) error('fsin nicht im Bereich 0...1'); end;
   if f1<0.02 error('f1 darf nicht kleiner sein als 0.02'); end;
   if f2>0.98 error('f2 darf nicht grsser sein als 0.98'); end;
   if f2-f1 < 0.04 error('f2 - f1 muss grsser als 0.04 sein'); end;
   if (abs(fsin)<f1)|(abs(fsin)>f2) hinweis='Das Signal liegt nicht im Bandpass.', end;
end
fsz = 12;            % FontSize fr Beschriftung
%
% Filterentwurf
% =============
ga= 8;               % Filtergrad fr IIR-Bandpass
gh=126;              % Filtergrad fr Hilbertfilter
[ba,aa]=ellip(ga/2,0.5,60,[f1,f2]); % Bandpassfilterkoeffizienten
% Entwurf eines Hilbertfilters via Halbbandtiefpass:
bh=2*real(specrot(fir1(gh,1/2),pi/2)); % Hibertfilter
% zum Hilbertfilter passende Verzgerung:
bv=[zeros(1,gh/2),1,zeros(1,gh/2)];    % Koeffiz. der Verzgerung
%
% Signalerzeugung
% ===============
xanf=1300;             % Darstellungsanfang
xend=xanf+m-1;         % Darstellungsende
xe  =xanf+1023;        % Ende fr die 1024-FFT
n = xanf+max(1023,m)+200; % Sample-Lnge
t = 1:n;               % Zeitbereich in Abtastschritten
z = (1024:-1:1)/512;   % Frequenzbereich 0..Abtastfrequenz entspricht 0..2
sn= 1+(f2-f1)*snr;     % SNR auf Bandbreite umrechnen
if length(fsin)>2
   x = filter(ba,aa,fsin);                      % direkter Input
   y = filter(bv,1,x)+i*filter(bh,1,x);         % analytisches Signal
   if length(x)<xe xend = length(x); end        % Darstellung anpassen
else
   if snr>999
      x = cos(pi*fsn*t+ph);                     % nur Cosinus
      y = x + i*sin(pi*fsn*t+ph);               % analytisches Signal
   else
      x = filter(ba,aa,sinnoise(pi*fsn*t,sn));  % Sinus + Rauschen
      y = filter(bv,1,x)+i*filter(bh,1,x);      % analytisches Signal
   end
end
%
% Signaldarstellung
% =================
% Die Darstellung erfolgt in zwei Bildschirmen nacheinander. Zunchst 
% der Filterfrequenzgang und die Spektren.
switch screen
   case 1
      h0pos = [1 315 400 265];
      h1pos = [1 31 800 549];
      h2pos = [551 330 250 250];
      h3pos = [1 31 400 265];
      h4pos = [401 31 400 265];
      h5pos = [401 315 400 265];
   case 2
      h0pos = [1 402 512 346];
      h1pos = [1 31 1024 718];
      h2pos = [700 428 320 320];
      h3pos = [1 31 512 346];
      h4pos = [513 31 512 346];
      h5pos = [513 402 512 346];
   otherwise error('Bildpositionen fr screen nicht angegeben.');
end;
if nargin<8   
   h0 = fullscreen('Filter-Frequenzgang');
   set(h0,'position',h0pos)
   filterplot({{ba;aa};bh},0,1,0,-80,10);
   xlabel('Signalfrequenz und Rauschfilter','FontSize',fsz);
   line([abs(fsin),abs(fsin)],[0,0],'LineStyle','none','Color','r','Marker','.','MarkerSize',20);
   legend('Bandpass','Hilbertfilter','Signalfrequenz')
   
   h3 = fullscreen('Spektrum des Realteils');
   set(h3,'position',h3pos)
   plot(z,abs(fft(real(y(xanf:xe)))));
   xlabel('Spektrum des Realteils','FontSize',fsz);
   
   h4 = fullscreen('Spektrum des Imaginrteils');
   set(h4,'position',h4pos)
   plot(z,abs(fft(imag(y(xanf:xe)))));
   xlabel('Spektrum des Imaginrteils','FontSize',fsz);
   
   h5 = fullscreen('Spektrum des analytischen Signals');
   set(h5,'position',h5pos)
   plot(z,abs(fft(y(xanf:xe))));
   xlabel('Spektrum des analytischen Signals','FontSize',fsz);
end
% Demonstration: zwei Abbildungen in zwei Fenstern synchron.
% Gezeigt wird ein analytisches Signal im Zeitbereich
% sowie gleichzeitig der Signalvektor in der komplexen Ebene.
% v ist ein Faktor fr die Zeitdehnung.
% Es werden v*w Schwingungen abgebildet.
h1 = fullscreen('Zeitbereich');
set(h1,'position',h1pos,'KeyPressFcn','anicont','UserData',0);
ax = [-1,1,-1,1]*max(abs(y(xanf:xend)));
axis([xanf,xend,ax]);
axis square;
axis manual;
axis on;
xlabel('Zeit','FontSize',fsz);
ylabel('Realteil','FontSize',fsz);
zlabel('Imaginrteil','FontSize',fsz);
set(h1,'CurrentAxes',gca);
l1=line('Color','r','EraseMode','none',...
   'LineStyle','-','xdata',[0,0],'ydata',[0,0],'zdata',[0,0]);
l2=line('Color','b','EraseMode','none',...
   'LineStyle','-','xdata',[0,0],'ydata',[0,0],'zdata',[0,0]);
l3=line('Color','g','EraseMode','none',...
   'LineStyle','-','xdata',[0,0],'ydata',[0,0],'zdata',[0,0]);
view(blick);
h2 = fullscreen('Signalraum');
set(h2,'position',h2pos,'KeyPressFcn','anicont','UserData',0);
axis(1.1*ax); axis square; axis manual;
xlabel('Realteil','FontSize',fsz);
ylabel('Imaginrteil','FontSize',fsz);
title('komplexer Signalraum','FontSize',fsz);
axis on;
set(h2,'CurrentAxes',gca);
hold on;
v1=line('Color','r','EraseMode','background','Marker','.',...
   'LineStyle','-','xdata',[0,0],'ydata',[0,0]);
v2=line('Color','b','EraseMode','background',...
   'LineStyle','-','xdata',[0,0],'ydata',[0,0]);
v3=line('Color','g','EraseMode','background',...
   'LineStyle','-','xdata',[0,0],'ydata',[0,0]);
zrs  = [0 0];
k = xanf;
stop = 0;
while (k<xend)&stop==0
   k = k+1;
   switch get(h1,'UserData') + get(h2,'UserData')
      case 1,   velocity = velocity*2;
      case -1,  velocity = velocity/2;
      case 2,   stop = 1;
   end;
   set(h1,'UserData',0); set(h2,'UserData',0);
   for kk = 1:floor(1000/velocity) sin(kk); end; % Dummy
   d = [k-1,k];
   xd= real([y(k-1),y(k)]);
   yd= imag([y(k-1),y(k)]);
   set(l1,'xdata',d,'ydata',xd,'zdata',yd);
   set(l2,'xdata',d,'ydata',xd,'zdata',zrs);
   set(l3,'xdata',d,'ydata',zrs,'zdata',yd);
   xx=real(y(k));
   yy=imag(y(k));
   set(v1,'xdata',[0,xx],'ydata',[0,yy]);
   set(v2,'xdata',[0,xx],'ydata',[0,0]);
   set(v3,'xdata',[0, 0],'ydata',[0,yy]);
   drawnow;
end;
d  = xanf:k;
xd = real(y(d));
yd = imag(y(d));
zrs= zeros(1,length(d));
set(l3,'xdata',d,'ydata',zrs,'zdata',yd);
set(l2,'xdata',d,'ydata',xd,'zdata',zrs);
set(l1,'xdata',d,'ydata',xd,'zdata',yd);
drawnow
set(h1,'KeyPressFcn','zoom3d','ButtonDownFcn','zoom3d')
set(h2,'KeyPressFcn','zoom3d','ButtonDownFcn','zoom3d')
figure(h1); rotate3d; figure(h2)
