function augendiagramm(x,fa,fs,b,dd,st)
% augendiagramm(x,fa,fs,b,dd,st)
% Darstellung des Augendiagramms
%  x  :  darzustellendes Signal
%  fa :  Abtastfrequenz von x
%  fs :  Schrittfrequenz
%  b  :  Breite der Darstellung in Schritten
%  dd :  Lage des Nullpunkts in Schritten vom Anfang von x (z.B. dd = 0.5)
%  st :  Vektor der Stufen: die Stufen werden strichliert in rot eingetragen
% Beispiele:
% augendiagramm(raisedcosine(randb(16,[-1 +1]),100),1000,10,1.0,0)
% augendiagramm(add_awgn(raisedcosine(randb(100,[-1 +1]),100),1,10),1000,10,1.1,0)
% augendiagramm(raisedcosine(randx(100,(-1:0.66:+1)),100),1000,10,1.2,[],(-1:0.66:+1))
% augendiagramm(add_awgn(raisedcosine(randx(150,(-1:1/16:+1)),100),1,40),1000,10,1.2,[],(-1:1/16:+1))
% augendiagramm(nfach(randb(16,[-1 +1]),100),1000,10,1.3,0.5)

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Defaults und Konstanten
% =======================
if nargin<4       b = 1.0;  end
if nargin<5      dd = 0;    end
if nargin<3      fs = 10;   end
if nargin<2      fa = 1000; end
if nargin<1       x = raisedcosine(randb(32,[-1 +1]),100); end
if length(b)==0   b = 1.0;  end
if length(dd)==0 dd = 0;    end
if dd<0 | dd>=1  error('Es muss gelten:  0 <= dd < 1'); end
if fa<fs         error('fa < fs  ist sinnlos'); end
if fs<10         warning('fs < 10  ergibt zu grobes Raster'); end

d  = 1 - b/2 + dd;
fv = fa/fs;
tee= length(x);
ta = 1 + d*fv;
te = ta + b*fv;
if te>=tee       error('Signal zu kurz!'); end
ts = 0;
tn = inf;
tx = -inf;

% Darstellung
% ===========
xn = min(x);
xx = max(x);
fh = fullscreen('Augendiagramm');
while te<=tee
   t  = floor(ta):ceil(te);
   tt = t - ts;
   tn = min(tn,floor(ta-ts));
   tx = max(tx,ceil(te-ts));
   line(tt,x(t))
   ta = ta + fv;
   te = te + fv;
   ts = ts + fv;
end
set(gca,'XLim',[tn tx],'YLim',1.2*[xn xx],'Position',[0 0 1 1])
axis off

if nargin<6  break; end

% Stufen-Gitter
% =============
line([tn tx]'*ones(size(st)),[1 1]'*st,'LineStyle',':','Color','r')
line((fv*(b/2+d)+1)*[1 1],get(gca,'YLim'),'LineStyle',':','Color','r')