function r = binomialplot(n,p,xl,s)
% r = binomialplot(n,p,xl,s)
% Es wird die Wahrscheinlichkeit des Auftretens von k Ereignissen
% unter n Versuchen ber k aufgetragen mit dem Scharparameter p
% oder die Summenverteilung, falls s~=0.
% n :  Anzahl der Versuche
% p :  Wahrscheinlichkeit des Ereignisses (kann ein array sein)
% xl:  k-Bereich der Darstellung
% s=1: es wird die Summenverteilung berechnet und dargestellt
% r :  Matrix der berechneten Verteilungen,
%      je Komponente von p eine Zeile fr den k-Bereich xl
% Wenn die Ausgabe r einer Variablen zugewiesen wird, gibt es 
% keine graphische Ausgabe.
% Beispiel: binomialplot(100,0.1:0.1:0.5,[1 80],1);
% Die Skalierung kann mit der Taste y zwischen lin und log 
% gewechselt werden. 
% Mit den Zifferntasten ist eine Hervorhebung mglich. 

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Defaults und Konstanten
% =======================
if nargin<1  n = 1000;     end
if nargin<4  s = 0;        end
if nargin<3  xl= [0 n];    end
if nargin<2  p = [1:9]/10; end
fsiz = 13;
dk = 1 + floor((xl(2)-xl(1))/500);   % k-Schritt

% Verteilung
% ==========
for kp = 1:length(p)
   kk = 1;
   for k = xl(1):dk:xl(2)
      if s  r(kp,kk) = 1 - binomialsum(n,k,p(kp));
      else  r(kp,kk) = binomialvert(k,n,p(kp));
      end
      kk = kk + 1;
   end
end;

if nargout>0 break; end

% Darstellung
% ===========
h = fullscreen('BV'); 
plot(xl(1):dk:xl(2),r)
if s
   title(sprintf('Binomialsummenverteilung  n =%5d',n),'FontSize',fsiz)
   xlabel('Grenze k (maximale Anzahl der Ereignisse unter n Ereignissen)','FontSize',fsiz)
   ylabel('Wahrscheinlichkeit von <=k Ereignissen','FontSize',fsiz)
   axis([xl 0 1])
   grid on
else
   title(sprintf('Binomialverteilung  n =%5d',n),'FontSize',fsiz)
   xlabel('k (Anzahl der Ereignisse unter n Ereignissen)','FontSize',fsiz)
   ylabel('Wahrscheinlichkeit von k Ereignissen','FontSize',fsiz)
set(gca,'XLim',xl)
end
lg = sprintf('%s''p = %5.3f''','legend(',p(1));
for kp = 2:length(p) lg = sprintf('%s,''p = %5.3f''',lg,p(kp)); end
lg = sprintf('%s%s',lg,',0)');
eval(lg)
set(gcf,'UserData',{zeros(1,8); 1.2*ones(1,8); {}},'KeyPressFcn','hervorhebung');
