function  y = carriersync(x,fg,m,pg)
% y = carriersync(x,fg,m,pg)
% Im Signal  x^m  wird nach einem Trger gesucht.
% y ist das um den gefundenen Trger nach Null 
% versetzte analytische Signal.
% fg ist die Grenzfrequenz des Reglerfilters 
% relativ zur Abtastfrequenz.
% m gibt die zu benutzende Potenz an.
% pg ist der Polynomgrad.
% AM: 1, DSB: 2, BPSK: 2, QPSK: 4. 

% Autor:  K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<2  fg = 0.002; end
if nargin<3  m  = 1;     end
if nargin<4  pg = 3;     end

% Konstanten
% ==========
gh = 20;                          % Grad des Hilbertfilters
ia = 20;                          % Anfangsindex wegen Einschwingen
t  = ia:length(x);                % Zeitbereich

% Trgersynchronisation
% =====================
if isreal(x) x = real2analyt(x,gh,q); end % Hilbertfilter falls ntig
zsq = x.^m;                       % m-te Potenz
[b,a] = ellip(2,0.5,60,fg);       % Tiefpassfilter
tsq = filter(b,a,zsq);            % Glttung von zsq (sonst geht unwrap nicht)
[ua,uaf,dly] = unwrapf(angle(tsq(t))); % Phase ohne Sprnge
pc  = polyfit(t,ua,pg);           % Polynom-Fit in Phasengang
%y   = x.*exp(-i*(polyval(pc,1:length(x)))/m); % Korrektur
y   = delay(x,dly+floor(0.75*max(grpdelay(b,a,512))))... % Korrektur der Filterverzgerung
      .*exp(-i*(polyval(pc,1:length(x)))/m);             % Korrektur der Phase
