function complex_noise(nn)
% complex_noise(nn)
% Signalraumdarstellung von Rauschen mit der Standardabweichung
% 1/sqrt(2) fr den Real- und Imaginrteil. Die Summe der Energien
% ist damit 1.0.
% Optional kann die Anzahl der Punkte nn angegeben werden. 
% Default: nn = 10000

% Konstanten und Defaults
% =======================
if nargin<1  nn = 10000; end
fsiz = 13;                                    % FontSize

% Rauschen
% ========
ra = (randn(1,nn) + i*randn(1,nn))/sqrt(2);   % komplex
am = abs(ra);                                 % Amplitude
wi = angle(ra);                               % Phasenwinkel
mx = max(abs([real(ra),imag(ra)]));           % Maximum fr Darstellung 

% Darstellung
% ===========
hs = fullscreen('Signalraum','w',0,[1/3  1  0  1]);
line(real(ra'),imag(ra'),'LineStyle','none','Marker','.')
line([-mx,0;mx,0],[0,-mx;0,mx],'LineStyle','-','Color','r')
w = 0:pi/90:2*pi;
line(cos(w),sin(w),'LineStyle','-','Color','r') % Einheitskreis
axis([-mx,mx,-mx,mx]); axis square; axis off
title('Komplexes Rauschen mit Energie = 1.0','FontSize',fsiz)

hi = fullscreen('Imaginrteil','w',0,[2 3; 2 1]);
hist(imag(ra),20)
title('Verteilung Imaginrteil','FontSize',fsiz);
xlabel(sprintf('Standardabweichung = %5.3f',sqrt(sum(imag(ra).^2)/nn)))

hr = fullscreen('Realteil','w',0,[2 3; 1 1]);
hist(real(ra),20)
title('Verteilung Realteil','FontSize',fsiz);
xlabel(sprintf('Standardabweichung = %5.3f',sqrt(sum(real(ra).^2)/nn)))

