function  ber = convber(ri,cl,ebn0db,m,mt)
% ber = convber(r1,cl,ebn0db,m,mt)
% Berechnung der Bitfehlerrate eines Faltungscodes durch Simulation.
% ri     :  inverse Koderate
% cl     :  Constraint Length
% ebn0db :  Vektor der Werte Eb/N0 in dB, fr die simuliert werden soll.
% m>=1   :  Anzahl der fr jeden Wert ebn0db zu simulierenden Kodewrter
% m<1    :  relative gewnschte Genauigkeit der BER.  Die Simulation 
%           passt die Anzahl der Kodewrter der Fehlerrate an.
% mt     :  nach mt Sekunden soll die Berechnung abgebrochen werden
% ber    :  Bitfehlerrate fr die entsprechenden Werte ebn0db

if nargin<5      mt = 3600;  end
if nargin<4       m = 0.1;   end
if nargin<3  ebn0db = -1:6;  end
if nargin<2      cl = 7;     end       
if nargin<1      ri = 3;     end

[g,du] = faltpoly(ri,cl);
k = floor(16000/ri);

t0 = clock;
for kk=1:length(ebn0db)
   nf(kk) = 0;
   mm = 0;
   while (etime(clock,t0)<mt) & ((m>=1 & mm<m) | (m<1 & sqrt(nf(kk)+1)>m*nf(kk)))
      mm = mm + 1;
      n = viterbitest(g,ebn2sigma(1/ri,ebn0db(kk)),k);
      nf(kk) = nf(kk) + n;
      [kk mm n]
   end
   ber(kk) = nf(kk)/k/mm;
   ber
end

[gz,gs] = size(g);
txt = sprintf('(%2d,%2d,%2d) -Faltungskode',ri*cl,cl,du);
if m>=1  nerr = m*k*ber'; else nerr = nf'; end
plotber([ebn0db' ber' nerr],txt)