function  y = crcq(q,x,poly);
% y = crcq(q,x,poly);
% Berechnung des CRC des Vektors x mit dem Polynom poly im GF(q).
% q    :   GF(q)-Arithmetik
% x    :   Vektor aus Symbolen des GF(q) {0 ... q-1}
% poly :   Matrix der relevanten Exponenten des Polynoms,
%          erste Zeile: Exponenten, zweite Zeile: Faktoren.
%          z.B. [16 12 5 0; 3 1 2 2] fr 3*x^16 + 1*x^12 + 2*x^5 + 2*1
%          Die Reihenfolge spielt keine Rolle.

% Autor: Klaus von der Heide,  e-mail:  v.d.heide@on-line.de

global CRCQ_GF

fq = factor(q); 
if q~=fq(1)^length(fq) error('crcq: q muss Primzahlpotenz sein'); end
mp = max(poly(1,:));           % Lnge des Statusregisters
sr = zeros(1,mp);              % Reset des Statusregisters
p  = sr; 
p(mp-poly(1,:)+1) = poly(2,:); % Polynom
p  = p(:,2:end-1);             % Polynom ohne hchsten Term

if length(fq)==1
   for k=1:length(x)
      z  = rem(x(k) + sr(1), q);
      sr = [rem(sr(2:end) + p*z, q),z];
   end
else
   try,   qq = CRCQ_GF.q;
          1/((qq-q)==0);
   catch, CRCQ_GF = gftab(q);
   end
   for k=1:length(x)
      z  = CRCQ_GF.add(x(k)+1,sr(1)+1) - 1;
      sr = [CRCQ_GF.add(sr(2:end)+1,CRCQ_GF.mul(p+1,z+1))-1, z];
   end
end

y = sr;
