function x = fadingsim(fu,fo,tt,m,sv,ss);
% m-Wege-Simulation fr einen Frequenzbereich
%   fu  :   untere Frequenzgrenze in Hz
%   fo  :   obere Frequenzgrenze  in Hz
%   tt  :   darzustellender Zeitbereich in s
%   m   :   Anzahl der Streupunkte
%   sv  :   Standardabweichung der Wegnderungen in m/s
%   ss  :   Standardabweichung der Weglngen in m
%   x   :   komplexe Bildpunkte im 50 * 30 - Raster
% Das Bild wird nur mit 50 Zeit- und 30 Frequenzpunkten 
% aufgelst.  Man muss deshalb mit kleinen Ausschnitten 
% testen, ob die Darstellungsgrenze schon erreicht ist.
% Der Aufruf mit den Defaultwerten ist ein gutes Beispiel
% fr Kurzwellenkanle. Fr Mobilfunk vom Fahrzeug aus gilt:
% fadingsim(900000000,901000000,0.1,10,30,500);

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<6  ss = 10000;    end  
if nargin<5  sv = 5;        end  
if nargin<4   m = 10;       end  
if nargin<3  tt = 30;       end  
if nargin<2  fo = 14060000; end  
if nargin<1  fu = 14000000; end
%
% Konstanten
% ==========
fsz= 13;                 % FontSize
n  = 50;                 % Anzahl der Zeitpunkte
p  = 30;                 % Anzahl der Frequenzpunkte
c  = 299792458;          % Lichtgeschwindigkeit
%fs = 8000;               % Abtastrate fr Audioausgabe
sa = 0.3/sqrt(m);        % mittlere Amplitude der Streupunkte
t  = tt*(1:n)/n;         % Zeitbereich
f  = fu + (fo-fu)*(0:p-1)/(p-1); % Frequenzbereich
%
% Simulation der m Wege
% =====================
a  = sa*rand(1,m);       % Amplituden der Wege
s  = ss*randn(1,m);      % Wege
v  = sv*randn(1,m);      % nderungen der Wege
%
% Summation der m Signale
% =======================
x = a(1)*exp(i*2*pi*f'*(t - (s(1)+v(1)*t)/c));
for k = 2:m
   x = x + a(k)*exp(i*2*pi*f'*(t - (s(k)+v(k)*t)/c));
end
%
% Darstellung
% ===========
h = fullscreen('Fadingdiagramm');
contourf(t*(999*(tt<=1)+1),f/1000000,abs(x),4);
title('Mehrwegeausbreitung:  Fading-Diagramm','FontSize',fsz);
if tt<=1  xlabel('Zeit  [millisec]','FontSize',fsz);
else      xlabel('Zeit  [sec]','FontSize',fsz);
end
ylabel('Frequenz  [MHz]','FontSize',fsz);
colormap(copper);
