function  br = faltfrate(g,ebn0db,n)
% br = faltfrate(g,ebn0db,n)
% Ermittlung der Bitfehlerrate unter Einsatz eines Faltungskodes 
%
%     g  :  Matrix der Faltungspolynome,
%           anstelle von g kann auch ein Vektor mit den zwei 
%           Elementen [r, cl] eingegeben werden:
%           r  :  inverse Koderate,  cl  :  constraint length
%           In diesem Fall wird der Kode mit faltpoly erzeugt.
%
% ebn0db :  Eb/No in dB
%
%     n  :  Anzahl der Informationsbits in der Simulation
%
%    br  :  Bitfehlerrate bezogen auf die bertragenen Informationsbits
%
% siehe auch die schnellere Version  faltfrate2(g,ebn0db,n)

% Autor: Klaus von der Heide, e-mail:  v.d.heideqon-line.de
%
%
% Defaults
% ========
if nargin<3       n = 10000; end
if nargin<2  ebn0db = 3;     end
if nargin<1       g = [2,5]; end

% Konstanten
% ==========
[r,cl] = size(g);               % inverse Koderate und Constraint Length
if r<2                          % Fall Eingabe von r und cl
   r  = g(1);
   cl = g(2);
   g  = faltpoly(r,cl);         % Faltungspolynome
end
fsz = 13;                       % FontSize
del = 0.5;                      % Auflsung der Fehlerverteilung
nn = ceil(15000/r);             % Anzahl der Informationsbits pro Aufruf viterbi
kk = ceil(n/nn);                % Anzahl der Aufrufe viterbi
sigma = ebn2sigma(1/r,ebn0db);  % Standardabweichung des Rauschens 

% Simulation
% ==========
t0  = clock;
nf = 0;
for k=1:kk 
   u = randb(nn);               % zufllige Information
   x = 2*faltcode(u,g)-1;       % Faltungskodierung
   y = x + sigma*randn(size(x));% Kanalrauschen
   d   = viterbi(g,y,[-1 +1]);  % Dekodierung
   nf  = nf + sum(d~=u);        % Anzahl der Bitfehler in der dekodierten Information
end

br = sum(nf)/kk/nn;             % BER
%cpuzeit = etime(clock,t0)       % Ausgabe der CPU-Zeit ins Kommandofenster
