function [b,a,fs] = fernsprechkanal
% [b,a] = fernsprechkanal
% Einfache Simulation eines Fernsprechkanals durch ein
% IIR-Filter vom Grad 4.
% Ohne Zuweisung der Koeffizienten auf Variable gibt es 
% eine Graphik mit dem Frequenzgang.

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
[b,a] = ellip(2,0.1,120,[0.16 0.55]); % IIR-Filtermodell
fs = 8000;                            % Abtastrate des Modells

if nargout>0 break; end

fh = fullscreen('Fernsprechkanal');
fsiz = 13;                            % FontSize fr Titel
flab = 12;                            % FontSize fr Achsenbeschriftung

subplot(2,2,1)
filterplot({{b;a}})
title('Betragsfrequenzgang','FontSize',fsiz)
xlabel('Frequenz [Hz]','FontSize',flab)
set(gca,'XTick',[0:1/4:1],'XTickLabel',{'  0 ';'1000';'2000';'3000';'4000'})

subplot(2,2,2)
n = 30;
h = [0 impz(b,a,n,8000)'];
hi= interp1((0:n)/fs,h,(0:0.2:n)/fs,'spline');
plot(1000*(0:0.2:n)/fs,hi)
line([0 1000*n/fs],[0 0],'Color',0.7*[1 1 1],'LineStyle',':')
axis([0 1000*n/fs -0.6 +0.6])
title('Impulsantwort','FontSize',fsiz)
xlabel('Zeit [Millisekunden]','FontSize',flab)

subplot(2,2,3)
[h,f] = freqz(b,a,500);
plot(fs*f(2:length(f)-2)/2/pi,unwrap(angle(h(2:length(h)-2))))
grid on
title('Phasenfrequenzgang','FontSize',fsiz)
xlabel('Frequenz [Hz]','FontSize',flab)
ylabel('Winkel [rad]','FontSize',flab)

subplot(2,2,4)
[d,f] = grpdelay(b,a,4000);
%plot(fs*f/2/pi,1000*d/fs)
line(fs*f(1:350)/2/pi,1000*d(1:350)/fs,'LineStyle',':')
line(fs*f(351:2800)/2/pi,1000*d(351:2800)/fs,'LineStyle','-')
line(fs*f(2801:4000)/2/pi,1000*d(2801:4000)/fs,'LineStyle',':')
grid on
title('Gruppenlaufzeit','FontSize',fsiz)
xlabel('Frequenz [Hz]','FontSize',flab)
ylabel('Gruppenlaufzeit [ms]','FontSize',flab)
axis([0 4000 0 0.8])
