function z = fskrx2(signal,f0,f1,baud,bild,fs)
% z = fskrx2(signal,f0,f1,baud,bild,fs)
% 2-FSK-Empfnger mit Demodulation durch Korrelation fr Signale mit
% der Abtastrate 8 kHz.
%
% signal :  das Empfangssignal
% f0     :  Frequenz fr "0" in Hz
% f1     :  Frequenz fr "1" in Hz
% baud   :  Baudrate 
% bild   :  grafische Darstellung falls bild nicht angegeben oder 0
% fs     :  Abtastrate (Default: 8000 Hz)
% Defaultwerte:  V.21
%
% z      :  die empfangenen Symbole

% Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<6     fs = 8000;   end
if nargin<5   bild = 1;      end
if nargin<4   baud = 300;    end
if nargin<3     f1 =  980;   end
if nargin<2     f0 = 1180;   end
if nargin<1 signal = fsktx2; end
schritt = fs/baud;                   % Schritt in Abtastungen
rschritt= round(schritt);
r15     = round(1.5*schritt);
t = 0:length(signal) - 1;            % Zeitbereich

% Cos/Sin-Tabellen
% ================
c0tab = cos(2*pi*f0/fs*(0:schritt-1));
s0tab = sin(2*pi*f0/fs*(0:schritt-1));
c1tab = cos(2*pi*f1/fs*(0:schritt-1));
s1tab = sin(2*pi*f1/fs*(0:schritt-1));

% Empfnger und Demodulator
% =========================
y = signal./(abs(signal)+eps);       % Beseitigung der Amplitudenschwankung
a = sqrt(filter(c1tab,1,y).^2 + filter(s1tab,1,y).^2) - ...
    sqrt(filter(c0tab,1,y).^2 + filter(s0tab,1,y).^2); % Korrelation
s = a>0;                             % binre Dekodierung
s = s(rschritt+1:end);               % Einschwingphase wegschneiden

% Start/Stopp-Synchronisation
% ===========================
bereich= 1:length(s);                % gesamter Zeitbereich
zeiger = 1;                          % Zeiger: noch lesen
abtast = [];                         % Abtastzeitpunkte
startf = [];                         % Zeitpunkte der Synchronisationsflanken
while ~all(s(zeiger:length(s)))
   tast   = min(find((bereich>=zeiger).*(s==0))) + r15 + round(0:schritt:7*schritt);
   abtast = [abtast, tast];          % Abtastpunkte
   zeiger = max(tast) + 2*rschritt;  % Zeitzeiger   
   startf = [startf,tast(1)-r15];
end
abtast = abtast(1:max(find(abtast<length(s))));
z = s(abtast);                       % Abtastung der Bits (Datenentscheidung)

% Grafische Darstellung nur wenn bild~=0
% ======================================
if ~bild  break; end

% Auswertung
% ==========
fh = fullscreen('dekodiertes Binrsignal','w',2,[0 1 0.75 1]);
axes('Position',[0  0.1  1  0.8])
plot(1:length(s),s)
line([0 length(s)],[0 0],'LineStyle',':','Color',0.7*[1 1 1])
lh = line(abtast,s(abtast));
set(lh,'LineStyle','none','Marker','*','MarkerEdgeColor','r')
set(gca,'XLim',[0,length(s)],'YLim',[-0.5,1.5])
line([startf;startf],(ones(length(startf),1)*[0,1])','Color','r','LineWidth',2.5)
