function z = fsktx2(symbole,f0,f1,baud,vor,fs)
% z = fsktx2(symbole,f0,f1,baud,vor,fs)
% FSK-Sender
% symbole:  Vektor der zu sendenden Bits  {0 1}.
% f0     :  Frequenz fr "0" in Hz
% f1     :  Frequenz fr "1" in Hz
% baud   :  Baudrate 
% vor    :  Anzahl der Einsen vorweg
% fs     :  Abtastrate  (Default :  8 kHz)
% Es erfolgt eine harte Umschaltung zwische den beiden Frequenzen.
% Die Defaultwerte gelten fr V.21 bei der Abtastung mit 8 kHz.

% Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de
%
% Defaults und Konstanten
% =======================
if nargin<6      fs = 8000; end
if nargin<5     vor = 0;    end
if nargin<4    baud = 300;  end
if nargin<3      f1 =  980; end
if nargin<2      f0 = 1180; end
if nargin<1 symbole = randb(8); end
schritt = round(fs/baud);
n = length(symbole);
if rem(n,8) error('fsktx: die Lnge von symbole muss 8*m sein'); end
m = n/8;

% Bitsequenz
% ==========
lv = round(5*rand) + 6;
sequenz = ones(1,vor + lv);                        % Vorlauf
for k=0:m-1
   sequenz = [sequenz 0 symbole(8*k+1:8*k+8) 1 1]; % Startbit, Byte, 2 Stoppbits
end
sequenz = [sequenz ones(1,vor+14-lv)];             % Auslauf

% Signalerzeugung
% ===============
basband  = nfach(sequenz,schritt);                 % Basisbandsignal
t = 0:length(basband) - 1;                         % Zeitsegment
z = cos(2*pi*(f0*t + (f1-f0)*cumsum(basband))/fs); % Modulation