function gf = gftab(q)
% gf = gftab(q)
% Erzeugung einer Additions- und Multiplikationstabelle fr 
% den endlichen Krper  GF(q).  q muss Primzahlpotenz sein.
%
% gf ist eine Struktur mit den Feldern:
% gf.add :  Additionstabelle
% gf.mul :  Multiplikationstabelle
%           weitere Felder sind bei gf_new beschrieben.
%
% Als Elemente des GF(q) werden die natrlichen Zahlen 1 ... q verwendet.
% Das Eins-Element der Addition (die sog. Null) ist 1,
% das Eins-Element der Multiplikation (die sog. Eins) ist 2. 
% Damit knnen die Tabellen direkt geschachtelt verwendet werden.
%
% Beispiel:       zu berechnen in GF(8) ist  3*(1+8*2)
% Realisierung:   gf.mul(3,gf.add(1,gf.mul(8,2)))
%
% Hinweis:  aufgrund einer Instabilitt in der benutzten Funktion  gf_new 
%           muss die Berechnung fr wenige Werte von q bisweilen 
%           mehrfach wiederholt werden. Dabei kann sich das Programm
%           auch aufhngen.

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

if q==2
   gf.q   = 2;
   gf.add = 1 + [0 1; 1 0];
   gf.mul = 1 + [0 0; 0 1]; 
   break; 
end
fq = factor(q); 
if q~=fq(1)^length(fq) error('gftab: q muss Primzahlpotenz sein'); end
p  = fq(1);
n  = length(fq);

for a=1:q   ap(a,:) = num2basvec(a-1,p,n); end

w = 1;
while w
   try
      gf = gf_new(p,n);
      for a=1:q 
         for b=a:q
            gfaddtab(a,b) = basvec2num(rem(ap(a,:)+ap(b,:),p),p);
            gfmultab(a,b) = basvec2num(gf_mul(gf,ap(a,:),ap(b,:)),p); 
            gfaddtab(b,a) = gfaddtab(a,b);   
            gfmultab(b,a) = gfmultab(a,b);   
         end 
      end
      w = 0;
   end
end
gf.add = 1 + gfaddtab;
gf.mul = 1 + gfmultab;