function impulscmp(symb)
% impulscmp(symb)
% Darstellung der Sendesignale fr die Symbolfolge symb mit den Sendeimpulsen
% Rechteck, Gauss, RC im Zeitbereich, RC im Frequenzbereich, Sinc, Partial Response Klasse 4.
% sowie Darstellung der zugehrigen Spektren.
%
% Hinweis :  RC-Puls im Zeitbereich ist noch nicht realisiert
%
% symb = ganze Zahl >1  :  Anzahl der Niveaus fr 20 zufllige Symbole (Default = 2)
% symb = Vektor         :  zu sendende Symbole

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Default
% =======
if nargin<1        symb = randb(20,[-1 +1]); end
if length(symb)<2  symb = randx(20,-1:2/(symb-1):+1); end

% Konstanten
% ==========
np = 6;                       % Anzahl der Impulsformen
sl = 20;                      % Schrittlnge in Samples
pb = 16;                      % halbe Breite der Impulse in Schritten
pb1= pb - 0.5;
ms = min(symb);               % unterstes Niveau
ns = pb;
br = 3;                       % Breite der Spektraldarstellung in Schrittfrequenz
fsiz = 13;

% Impulsform
% ==========
p(1,:) = [zeros(1,pb1*sl) ones(1,sl) zeros(1,pb1*sl)];
p(2,:) = exp(-(pi*(-pb*sl:pb*sl-1)/sl/2).^2);
p(3,:) = [zeros(1,(pb-1)*sl) (1 + cos(pi*(-sl:sl-1)/sl))/2  zeros(1,(pb-1)*sl)];
p(4,:) = zeros(1,2*pb*sl);      % !!!!! 
p(5,:) = rcsinc((-pb*sl:pb*sl-1)/sl,pb);
t      = (-pb*sl:+pb*sl-1)/sl + 0.0001;
p(6,:) = sin(pi*t)./(pi*(t.^2-1));

% Generierung der Ausgabesignale
% ==============================
for k=1:np
   y(k,:) = conv(p(k,:),nullein([ms*ones(1,ns) symb ms*ones(1,ns)],sl-1));
end

% Spektren
% ========
ff = fft(y');
[fm,fn] = size(ff);
s  = abs(ff(1:round(br*fm/sl),:));
[sm,sn] = size(s);

% Darstellung
% ===========
fh1 = fullscreen('Impulsfolgen');
plot(1:length(y),y')
yl  = get(gca,'YLim'); dl = yl(2) - yl(1);
axis([(pb+ns)*sl+1 length(y)-(pb+ns)*sl yl+0.2*dl*[-1 1]]); 
axis off
set(gca,'Position',[0 0 1 1]);
legend('Rechteck','Gauss','RC Zeit','RC Freq','sinc','PR4')
set(fh1,'UserData',{zeros(1,8); 1.2*ones(1,8); {}},'keypressfcn','hervorhebung');

fh2 = fullscreen('Spektrum');
plot(br*(0:sm-1)/sm,s)
axis([0  br  10^-5  1.5*max(max(s))])
set(gca,'YScale','log')
title('Spektrum','Fontsize',fsiz)
xlabel('Frequenz  [Einheit: Schrittfrequenz]','Fontsize',fsiz)
legend('Rechteck','Gauss','RC Zeit','RC Freq','sinc','PR4')
set(fh2,'UserData',{zeros(1,8); 1.2*ones(1,8); {}},'keypressfcn','hervorhebung');
