function  srx = jasonrx(x,fig,mode)
% xtx = jasonrx(s,fig,mode) 
% demoduliert und dekodiert das 17-DFSK-Signal  x  nach dem Jason-Verfahren von 
% Alberto diBene.
%
% x   :  Empfangssignal mit der Abtastrate  fs = 11025 Hz und 
%        der Mittenfrequenz  f0 = 800 Hz.  
%        Die Student Edition von MATLAB empfngt in  x  direkt das um  f1 = -797.308 Hz
%        verschobene und auf die Abtastrate  fs9 = 10.76660156 Hz  dezimierte Signal.
%        Dies kann auch durch  mode = 1  in der Vollversion erzwungen werden. 
%        Die Student Edition kann einen String von maximal 15 Zeichen dekodieren.
%        Default :  Default von  jasontx plus Rauschen mit  Eb/N0 = 10 dB
%
% fig :  Binrvektor, der mit den ersten drei Komponenten angibt, welche Diagramme 
%        gewnscht werden:
%        (1) :  Bin-Kanle im Zeitbereich
%        (2) :  alle ermittelten Momentanspektren bereinander
%        (3) :  Zeitfrequenzebene als Contour-Plot 
%               (die Student Edition liefert hier bei mehr als 6 Zeichen einen Mesh-Plot)
%        (4) :  Audioausgabe von x mit der Abtastrate 11025 Hz bzw. 4000 Hz (mode 0 bzw. 1)
%        Default :  [0 0 0 0]
%
% mode:  mit  mode = 1  wird die Abtastrate von x auf  fs9 = 10.76660156 Hz  
%        eingestellt (siehe Erluterung des Parameters x)
%        Default :  0  (im Falle der Student Edition:  1)
%
% srx :  dekodierter String

% Autor: Klaus von der Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<3  mode = 0;         end
if nargin<2   fig = [0 0 0 0]; end
fig = [fig zeros(1,4-length(fig))];
if isstudent mode = 1;         end 
if nargin<1     x = add_awgn(jasontx,6/128,10); end
if length(x)<1  x = add_awgn(jasontx,6/128,10); end

% Konstanten
% ==========
fs   =11025;                  % Abtastfrequenz des Inputsignals
f0   =  800;                  % Mittenfrequenz (nur zusammen mit tl und pd ndern!)
tl   = 4456;                  % Lnge der Sinus-Tabelle
pd   = 1289;                  % Inkrement in der Tabelle
fftl = 128;                   % FFT-Lnge
dff  = 16;                    % Abstand der FFT-Berechnungen in Abtastungen
fle = round(fftl/dff);        % Schrittlnge in zff
fsiz = 12;                    % FontSize
win  = hamming(fftl)';        % FFT-Fenster

% Empfnger
% =========

if mode~=1                    % berspringen der Dezimationen
   
% Filterkoeffizienten
% ===================
k11 = 0.25000457;  k12 = 0.5; % Dezimationsfilter1
k21 = 0.25001827;  k22 = 0.5; % Dezimationsfilter2
k31 = 0.25007309;  k32 = 0.5; % Dezimationsfilter3
k41 = 0.25029254;  k42 = 0.5; % Dezimationsfilter4
k5  = [-0.03169162  -0.00000092   0.28168753   0.50000177  ...
        0.28168753  -0.00000092  -0.03169162];
k6  = [-0.03305166  -0.00002229   0.28298773   0.50003808  ...
        0.28298773  -0.00002229  -0.03305166];
k7  = [ 0.00856821   0.00000517  -0.05575100  -0.00001254  ...
        0.29725702   0.50001749   0.29725702  -0.00001254  ...
       -0.05575100   0.00000517   0.00856821];
k8  = [-0.00190593  -0.00487220  -0.00448401   0.00427751  ...
        0.01762466   0.01961151  -0.00402547  -0.04241810  ...
       -0.05355627   0.00597123   0.13471766   0.27012275  ...
        0.32820770   0.27012275   0.13471766   0.00597123  ...
       -0.05355627  -0.04241810  -0.00402547   0.01961151  ...
        0.01762466   0.00427751  -0.00448401  -0.00487220  ...
       -0.00190593];
k9  = [];
k10 = [];
  
  
% Sinus-Tabelle fr f1
% ====================
sintab = sin(2*pi*(0:tl-1)/tl);

% 2 Dezimationen
% ==============
x  = x(1:2*floor(length(x)/2));
y1 = k11*( x(1:2:end) + [ x(3:2:end) 0]) + k12*[ x(2:2:end) 0];
y1 = y1(1:2*floor(length(y1)/2));
y2 = k21*(y1(1:2:end) + [y1(3:2:end) 0]) + k22*[y1(2:2:end) 0];

% Frequenzversatz ins Basisband
% =============================
sn = sintab(mod(1+(1:length(y2))*pd),tl); % Sinusgenerator fr f1
z2 = sn.*y2;

% 8 Dezimationen
% ==============
z2  = z2(1:2*floor(length(z2)/2));
y3  = k31*(z2(1:2:end) + [z2(3:2:end) 0]) + k32*[z2(2:2:end) 0];
y3  = y3(1:2*floor(length(y3)/2));
y4  = k41*(y4(1:2:end) + [y4(3:2:end) 0]) + k42*[y4(2:2:end) 0];
y5  = filter(k5,1,y4);         % Dezimationsfilter5
z5  = y5(1:2:end);             % Dezimation
y6  = filter(k6,1,y5);         % Dezimationsfilter6
z6  = y6(1:2:end);             % Dezimation
y7  = filter(k7,1,y6);         % Dezimationsfilter7
z7  = y7(1:2:end);             % Dezimation
y8  = filter(k8,1,y7);         % Dezimationsfilter8
z8  = y8(1:2:end);             % Dezimation
y9  = filter(k9,1,y8);         % Dezimationsfilter9
z9  = y9(1:2:end);             % Dezimation
y10 = filter(k10,1,y9);        % Dezimationsfilter10
z10 = y10(1:2:end);            % Dezimation

else 
   z10 = x;
   fs  = 11025*2^-10;
end  % if mode==1

% FFT
% ===
kk = 1;
for k=1:floor((length(z10)-fftl)/dff)+1
   zffk = fft(z10(kk:kk+fftl-1).*win);
   zff(k,:) = zffk(1:fftl/2);
   kk = kk + dff;
end

% Matched Filter und Betrag
% =========================
wff = filter(ones(1,fle)/fle,1,abs(zff));

% Rekonstruktion des Schritt-Taktes
% =================================
wffk= wff(fle+1:end,:);
sqf = max((wffk.^2)');
sqf = sqf - mean(sqf);
cex = sqf*exp(i*2*pi*(0:length(sqf)-1)/fle)';
phi = angle(cex);
p   = round(phi/2/pi*fle):fle:length(wffk);
if p(1)<1  p = p(2:end); end
if p(end)>length(wffk)  p = p(1:end-1); end

% Datenentscheidung
% =================
for n=1:length(p)
   j     = p(n);
   cn    = filter([1 1 1],1,wffk(p(n),:));
   cm(n) = max(cn);
   ix(n) = min(find(cn==cm(n))) - 1;
end

% Differenzdekodierung
% ====================
dix = 1 + mod(round(diff(ix)/3),17);
dx  = dix(1:2*floor(length(dix)/2));
if sum(dx(1:2:end))-sum(dx(2:2:end))<0  dix = dix(2:end); end
for n=1:length(dix)/2
   nc = 8*dix(2*n-1)+dix(2*n)-50;
   if nc<32 | nc>95  nc = 31; end
   srx(n) = char(nc);
end

% Darstellung
% ===========
if fig(1)
   fh1 = fullscreen('Bin-Kanle im Zeitbereich','w',2);
   axes('Position',[0.03 0.15 0.94 0.7])
   plot(wffk,'LineWidth',2);
   line(p,cm,'LineStyle','none','Marker','*','Color','r','MarkerSize',10)
   xlabel('Abtastung','FontSize',fsiz)
   axis([1 length(wffk) 0 1.2*max(cm)])
   title('Alle Bins ber der Zeit','FontSize',fsiz)
end

if fig(2)
   fh2 = fullscreen('Spektrum','w',2);
   axes('Position',[0.03 0.15 0.94 0.7])
   plot(0:fftl/2-1,wffk','LineWidth',2);
   xlabel('Frequenz','FontSize',fsiz)
   axis([0 fftl/2 0 1.2*max(cm)])
   title('Alle Bins ber der Frequenz','FontSize',fsiz)
end

if fig(3)
      fh3 = fullscreen('Zeit-Frequenz-Ebene'); 
      axes('Position',[0 0 1 1])
   try    % array size limitation der Student Edition in contourf abfangen
      contourf(wff');  colormap copper
   catch
      set(gca,'Position',[0.05 0.1 0.9 0.9])
      mesh(wff');
      [m,n] = size(wff);
      axis([1 m 1 n 0 max(cm)])
      set(gca,'View',[-1 85])
   end
   
if fig(4) if mode==1  soundsc(x,4000); else soundsc(x,fs); end; end
   
end