function [ser,sa] = jasonser(ebn0,n)
% [ser,sa] = jasonser(ebn0,n)
% Berechnung der Symbol-Fehlerrate fr das Jason-Verfahren durch Simulation.
%
% ebn0 :  Vektor der Werte von Eb/N0, fr die die Simulation durchzufhren ist.
%
% n    :  Vektor der Anzahl der Stichproben fr die Werte von ebn0.
%         Ist n skalar, so wird er fr jeden Wert von ebn0 genommen.
%
% ser  :  Symbol-Fehlerrate fr die angegebenen Werte von ebn0.
%
% sa   :  Standardabweichung der Fehlerrate

% Autor:  Klaus von der Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<1  ebn0 = 0:12; end
if nargin<2     n = 10;   end
if length(n)==1 n = n*ones(size(ebn0)); end

% Simulation
% ==========
for a=1:length(ebn0)
   for k=1:n(a)
      txt  = char(32 + floor(64*rand(1,13)));
      rtx  = jasonrx(add_awgn(jasontx([txt ' '],0),6/128,ebn0(a)),[],1);
      if length(rtx)>13 rtx = rtx(2:end); end
      s(k) = sum(txt==rtx); 
   end;
   nc(a)  = length(txt)*n(a);      % Anzahl der gesendeten Zeichen
   nf(a)  = nc(a) - sum(s(1:n(a)));% Anzahl falsch empfangener Zeichen
   ser(a) = nf(a)/nc(a);           % Zeichen-Fehlerrate
   sa(a)  = sqrt(nf(a))/nc(a);     % Standardabweichung der Fehlerrate
   a,[ser' sa']
end

% Darstellung
% ===========
fh = fullscreen('Symbol Error Rate for Jason-17-DFSK','w',2);
errorbar(ebn0,ser,sa,'b*-')
title('Jason 17-DFSK','FontSize',13)
xlabel('E_b/N_0','FontSize',13)
ylabel('Symbol Error Rate','FontSize',13)
set(gca,'YScale','log')
if length(ebn0)>1 set(gca,'XLim',[min(ebn0) max(ebn0)],'XTick',ebn0); end