function  xtx = jasontx(s,fs,f0,z)
% xtx = jasontx(s,fs,f0) 
% generiert das 17-DFSK-Signal  xtx  nach dem Jason-Verfahren von 
% Alberto diBene fr die Abtastrate fs.
% Die Student Edition von MATLAB kann im Modus fs=0 einen String von 
% maximal 63 Zeichen verarbeiten.
%
% s  :   zu sendender String.  
%        s darf folgende Buchstaben, Ziffern und Zeichen enthalten:
%         !"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\]^_
%        Der String wird allerdings mit UPPER gewandelt, so dass 
%        auch Kleinschreibung mglich ist.
%        Dem String wird bei der Aussendung ein blank vorangestellt.
% fs :   Abtastrate in Hz.  Im Fall fs ~= 11025 wird die korrekte
%        Schrittfrequenz von 11025*2^-17 nicht przise eingehalten.
%        fs = 0 :  auf xtx wird das um  f1 = -797.308 Hz  verschobene und auf
%        die Abtastrate  fs9 = 10.76660156 Hz  dezimierte Signal ausgegeben.
%        Die Angabe von f0 ist in diesem Fall irrelevant.
%        (Default  fs = 11025 Hz;  Student Edition:  fs = 0)
% f0 :   Mittenfrequenz von Jason  (Default = 800.000 Hz)
% z  :   Wird fr z ein Vektor gegenseitig teilerfremder natrlicher Zahlen
%        eingesetzt, so erfolgt die Sinus-Generierung aus Tabellen dieser 
%        Lngen und anschliessender Synthese.  Im Grenzfall ist z nur eine
%        grosse Zahl, die die Lnge einer Tabelle angibt.
%        Fr z = 0 wird der Sinus direkt in MATLAB gerechnet.
%        (Default  z = [101 103 107 109])
%
% xtx :  reelles Jason-Signal

% Autor:  Klaus von der Heide,  e-mail:  v.d.heide@on-line.de

% Defaults und Konstanten
% =======================
ftl = 128;                             % FFT-Lnge im Empfnger
if nargin<4  z = [101 103 107 109]; end
if nargin<3 f0 = 800;               end
if nargin<2 if isstudent fs = 0;   else fs = 11025; end; end
if nargin<1  s = 'JASON-TEST! ';         end
if fs>0
   srl = round(fs*2^17/11025);         % Schrittlnge in Abtastungen
   bas = 0;                            % Ausgabe mit Trger f0 bei fs   
else
   srl = ftl;                          % Schrittlnge in Abtastungen
   bas = 1;                            % Ausgabe mit Trger 2.69165 Hz
   f0  = 11025/2^12;                   % Trgerfrequenz
   fs  = 11025/2^10;                   % Abtastrate  10.76660156 Hz
end

% Jeder Character wird umgesetzt in eine Folge von zwei Tondifferenzen.
% Die Tabelle ttab liefert zu jedem Character die Indices dieser Differenzen:
%  ===========================================================================
ttab = 99*ones(256,2);                 % vorbesetzen mit 99 fr "undefined"
ttab(32:95,:) = [9+floor((0:63)'/8)  1+mod((0:63)',8)];

% Stringprfung
% =============
if ismember(99,ttab(double(upper(s))))  error('Der String enthlt nicht erlaubte Zeichen.'); end

% Sequenz des Tonindex und der Frequenz
% =====================================
sseq = mod(cumsum(flach(ttab(double(upper([' ' s])),:))),17) - 8;
fseq = (f0 + 11025*sseq*3*2^-17)/fs;   % Sequenz der Frequenzen der 17-DFSK
f = nfach(fseq,srl);                   % Momentanfrequenz in jeder Abtastung

% FSK-Signal
% ==========
xtx = real(chinremdds(f,0,z));
