function mFSK_err(m,n)
% mFSK_err(m,n)
% Darstellung der Symbolfehlerwahrscheinlichkeit durch Simulation
% fr m-FSK bei inkohrenter orthogonaler Demodulation.
%
% m :  m-FSK. Fr m kann ein Vektor angegeben werden.
%      Default :  m = [2 4 8 16 32 64 128];
% n :  Anzahl der Simulationen mit jeweils 10000 Symbolen.
%      Default :  10

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<1  m = 2.^[1:7]; end
if nargin<2  n = 10; end

% Konstanten
% ==========
fsiz= 13;                  % FontSize
lw  = 1.5;                 % LineWidth
xdB = -2:0.5:10;           % Eb/No-Bereich [dB]
s   = 10.^(xdB/10);        % dasselbe linear (Signalleistung bei No = 1)
ns  = length(s);
nx  = 10000;               % Anzahl der Symbole pro Schleifendurchlauf
col = 'kbgrcym';
while size(col)<length(m)  col = [col; col]; end

% Berechnung der Symbolfehlerwahrscheinlichkeit durch Simulation
% ==============================================================
f = zeros(length(m),ns);
for j=1:length(m)
   for k=1:n
      r = max(randn(m(j)-1,nx).^2,[],1) - randn(1,nx).^2;  % No = 1.0
      for i=1:ns
         f(j,i) = f(j,i) + sum(r>(s(i)*log2(m(j)))); 
      end
   end
end

% Darstellung
% ===========
for k=1:length(m)  lg(k,:) = sprintf('%3dFSK',m(k)); end
hf = fullscreen('Symbolfehlerwahrscheinlichkeit fr m-FSK');
for j=1:length(m)
   line(xdB,f(j,:)/n/nx,'LineWidth',lw,'Color',col(j))
end
title('Symbolfehlerwahrscheinlichkeit fr m-FSK bei inkohrenter orthogonaler Demodulation',...
      'FontSize',fsiz)
legend(lg,3)
xlabel('E_b/N_0 [dB]','FontSize',fsiz)
ylabel('Symbolfehlerwahrscheinlichkeit','FontSize',fsiz)
set(gca,'YScale','log','FontSize',fsiz);
axis([xdB(1) xdB(end) 0.00001 1])
grid on

h2 = fullscreen('Bitfehlerwahrscheinlichkeit');
for j=1:length(m)
   s2b = (1+1/log2(m(j)))/2;
   line(xdB,f(j,:)/n/nx*s2b,'LineWidth',lw,'Color',col(j))
end
title('Bitfehlerwahrscheinlichkeit fr m-FSK bei inkohrenter orthogonaler Demodulation',...
      'FontSize',fsiz)
legend(lg,3)
xlabel('E_b/N_0 [dB]','FontSize',fsiz)
ylabel('Bitfehlerwahrscheinlichkeit','FontSize',fsiz)
set(gca,'YScale','log','FontSize',fsiz);
axis([xdB(1) xdB(end) 0.00001 1])
grid on
