function mPSK_err
% mPSK_err
% Darstellung der Bitfehlerwahrscheinlichkeit ber Eb/No 
% fr 4PSK bis 64PSK aufgrund einer Nherungsformel.
% Die Nherung ist fr Bitfehlerwahrscheinlichkeiten < 0.1,
% also im praktisch relevanten Bereich sehr gut.

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

fsiz= 13;            % FontSize
lw  = 1.5;           % LineWidth
xdB = -5:30;         % Eb/No-Bereich [dB]
x   = 10.^(xdB/10);  % dasselbe linear
m   = [4,8,16,32,64];
col = [0 0 1; 0 1 0; 1 0 0; 0 1 1; 1 0 1];
hf  = figure;
fullscreen('Bitfehlerwahrscheinlichkeit')
for k=1:length(m)
   line(xdB,erfc(sqrt(log2(m(k))*x).*sin(pi/m(k))),...
        'LineWidth',lw,'Color',col(k,:))
end
title('Bitfehlerwahrscheinlichkeit ber E_b/N_0 fr kohrente Demodulation',...
      'FontSize',fsiz)
legend('4PSK','8PSK','16PSK','32PSK','64PSK',3)
xlabel('E_b/N_0 [dB]','FontSize',fsiz)
ylabel('Bitfehlerwahrscheinlichkeit','FontSize',fsiz)
set(gca,'YScale','log','FontSize',fsiz);
axis([-5 30 0.000001 1])
grid on
