function x = mehrweg(f,m,sv,ph);
% m-Wege-Simulation fr eine Trgerfrequenz
%   f   :      Trgerfrequenz in Hz
%   m   :      Anzahl der Streupunkte
%   sv  :      Standardabweichung der Wegnderungen in m/s
% ph >0 :      zustzlich animierte Darstellung des Phasenverlaufs
% ph = [a,b] : animierte Darstellung mit view = [a,b]
% Der Aufruf mit den Defaultwerten ist ein gutes Beispiel

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<4  ph = 0;        end  
if nargin<3  sv = 1000000;  end  
if nargin<2   m = 5;        end  
if nargin<1   f = 10000000; end  % 10 MHz
%
% Konstanten
% ==========
fsz= 13;                 % FontSize
n  = 16384;              % Beschrnkung der Studentenversion auf n < 2^14
c  = 299792458;          % Lichtgeschwindigkeit
fs = 8000;               % Abtastrate fr Audioausgabe
sa = 0.3/sqrt(m);        % mittlere Amplitude der Streupunkte
p  = 10;                 % Anzahl der Sttzstellen pro Wellenlnge
dt = 1/f/p;              % Schrittweite im Zeitbereich
t  = (1:n)*dt;           % Zeitbereich
ss = 10;                 % Standardabweichung der Wege
%
% Simulation der m Wege
% =====================
a  = sa*rand(1,m);       % Amplituden der Wege
s  = ss*randn(1,m);      % Wege
v  = sv*randn(1,m);      % nderungen der Wege
%
% Summation der m Signale
% =======================
x = a(1)*sin(2*pi*f*(1 + v(1)/c)*(t - s(1)/c));
for k = 2:m
   x = x + a(k)*sin(2*pi*f*(1 + v(k)/c)*(t - s(k)/c));
end
xm = max(abs(x));
%
% Darstellung
% ===========
h = fullscreen('Mehrweg');
plot(t,x); 
set(gca,'XLim',[0,n*dt],'YLim',1.1*max(abs(x))*[-1 +1])
title('Fading bei Mehrwegeausbreitung mit bewegten Streuzentren','FontSize',fsz)
xlabel('Zeit [s]','FontSize',fsz)
ylabel('Amplitude','FontSize',fsz)
soundsc(x,fs)

if ph==0 break; end

% Animierte Darstellung
% =====================
y = real2analyt(x); 
z = y.*exp(-i*2*pi*f*t);
if length(ph)==2
   komplexanimat(z(30:5:n),[1 0 0 0 0 0],100,ph)
else
   komplexanimat(z(30:5:n),[1 0 0 0 0 0],100,[90 0])
end
axis off
mx = max(abs(x));
line([0 0],mx*[-1 +1],[0 0],'Color',0.5*[1 1 1])
line([0 0],[0 0],mx*[-1 +1],'Color',0.5*[1 1 1])
title('Ortskurve des Empfangssignals bei Mehrwegeausbreitung','FontSize',13)
