function  mfskerr(m)
% mfskerr(m)
% Berechnung und Darstellung der Symbol- und Bitfehlerwahrscheinlichkeit 
% fr m-FSK bei kohrenter Demodulation.
%
% m :  m-FSK. Fr m kann ein Vektor angegeben werden.
%      Default :  m = [2 4 8 16 32 64 128];

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Default
% =======
if nargin<1  m = 2.^[1:7]; end

% Konstanten
% ==========
fsiz= 13;                          % FontSize
lw  = 1.5;                         % LineWidth
col  = 'kbgrcymk';                 % Farben
while size(col)<length(m)  col = [col; col]; end
for k=1:length(m)  lg(k,:) = sprintf('%3dFSK',m(k)); end   % Legende
ebn0db = linspace(-2,10,1000);

% Symbolfehlerrate ber Eb/No
% ===========================
w2 = inline('erf(sqrt(10.^(ebn0db/10)/2))','ebn0db');
fh1 = fullscreen('Symbolfehlerrate');
for k=1:length(m)
   line(ebn0db,0.5*(1-(w2(ebn0db+10*log10(log2(m(k))))).^(m(k)-1)),'LineWidth',1.5,'Color',col(k))
end
line(ebn0db,0.5*erfc(sqrt(10.^(ebn0db/10))),'Color',0.7*[1 1 1],'LineWidth',2); % BPSK zum Vergleich
lg(length(m)+1,:) = 'BPSK  ';
legend(lg,3)
set(gca,'YScale','log','FontSize',fsiz);
grid on
title('Symbolfehlerrate fr MFSK bei kohrenter Demodulation','FontSize',fsiz)
xlabel('E_b/N_0 [dB]','FontSize',fsiz)
ylabel('Symbolfehlerwahrscheinlichkeit','FontSize',fsiz)
axis([ebn0db(1) ebn0db(end) 10^-5 1])

% Bitfehlerrate ber Eb/No
% ========================
fh2 = fullscreen('Bitfehlerrate');
for k=1:length(m)
   s2b = (1+1/log2(m(k)))/2;  % Umrechnungsfaktor 
   line(ebn0db,s2b*0.5*(1-(w2(ebn0db+10*log10(log2(m(k))))).^(m(k)-1)),'LineWidth',1.5,'Color',col(k))
end
line(ebn0db,0.5*erfc(sqrt(10.^(ebn0db/10))),'Color',0.7*[1 1 1],'LineWidth',2)  % BPSK zum Vergleich
legend(lg,3)
%for k=1:length(m)  % nicht erreichbare Grenzen bei Demodulation
%   s2b = (1+1/log2(m(k)))/2;  % Umrechnungsfaktor 
%   line(ebn0db,s2b*0.5*(1-(w2(ebn0db+3+10*log10(log2(m(k))))).^(m(k)-1)),'LineStyle',':','Color',col(k))
%end
set(gca,'YScale','log','FontSize',fsiz);
grid on
title('Bitfehlerrate fr MFSK bei kohrenter Demodulation','FontSize',fsiz)
xlabel('E_b/N_0 [dB]','FontSize',fsiz)
ylabel('Bitfehlerwahrscheinlichkeit','FontSize',fsiz)
axis([ebn0db(1) ebn0db(end) 10^-5 1])


