function  mfskerr3(m)
% mfskerr3(m)
% Berechnung und Darstellung der Symbol- und Bitfehlerwahrscheinlichkeit 
% fr m-FSK bei kohrenter orthogonaler Demodulation.
%
% m :  m-FSK. Fr m kann ein Vektor angegeben werden.
%      Default :  m = [2 4 8 16 32 64 128];

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Default
% =======
if nargin<1  
   m = 2.^[1:7]; 
end

% Konstanten
% ==========
fsiz= 13;                          % FontSize
lw  = 1.5;                         % LineWidth
col  = 'kbgrcymk';                 % Farben
while size(col)<length(m)  col = [col; col]; end
for k=1:length(m)  lg(k,:) = sprintf('%3dFSK',m(k)); end   % Legende
ebn0db = linspace(-2,10,1000);
x  = 10.^(ebn0db/10); 

% Symbolfehlerrate ber Eb/No
% ===========================
fh1 = fullscreen('Symbolfehlerrate','w');
for k=1:length(m)
   line(ebn0db,1-(1-0.5*erfc(sqrt(0.5*x*log2(m(k))))).^(m(k)-1),'LineWidth',lw,'Color',col(k))
end
set(gca,'YScale','log')
grid on
title('Symbolfehlerrate fr MFSK bei kohrenter Demodulation','FontSize',fsiz)
xlabel('E_b/N_0 [dB]','FontSize',fsiz)
ylabel('Symbolfehlerwahrscheinlichkeit','FontSize',fsiz)
axis([ebn0db(1) ebn0db(end) 10^-5 1])
legend(lg,3)


% Bitfehlerrate ber Eb/No
% ========================
fh2 = fullscreen('Bitfehlerrate');
for k=1:length(m)
   s2b = (1+(log2(m(k))-1)/2)/log2(m(k));  % Umrechnungsfaktor 
   line(ebn0db,s2b*(1-(1-0.5*erfc(sqrt(0.5*x*log2(m(k))))).^(m(k)-1)),'LineWidth',lw,'Color',col(k))
%   line(ebn0db,m(k)*0.25*erfc(sqrt(0.5*x*log2(m(k)))),'LineWidth',lw,'Color',col(k)) % Nherung
end
line(ebn0db,0.5*erfc(sqrt(10.^(ebn0db/10))),'Color',0.7*[1 1 1],'LineWidth',1)  % BPSK zum Vergleich
line(ebn0db,erfc(sqrt(10.^(ebn0db/10))),'Color',0.7*[1 1 1],'LineWidth',3)  % BPSK zum Vergleich
set(gca,'YScale','log')
grid on
title('Bitfehlerrate fr MFSK bei kohrenter Demodulation','FontSize',fsiz)
xlabel('E_b/N_0 [dB]','FontSize',fsiz)
ylabel('Bitfehlerwahrscheinlichkeit','FontSize',fsiz)
axis([ebn0db(1) ebn0db(end) 10^-5 1])
lg(length(m)+1,:) = 'BPSK  ';
lg(length(m)+2,:) = 'DBPSK ';
legend(lg,3)
