function x0 = mpsk_noise(m,EbNodB,n,a)
% x0 = mpsk_noise(m,EbNodB,n,a)
% Signalraumdarstellung von m-PSK im Rauschen von Eb/N0 = EbNodB [dB].
% Optional ist die Anzahl der Punkte n.  Default ist n = 15000.
% Der Gesamtwinkel 2*pi - a wird in m Sektoren geteilt und die 
% Symbole werden an den Trennlinien platziert. 

% Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de

% Konstanten und Defaults
% =======================
fsiz = 15;                                    % FontSize
if nargin<4  a = 0;      end
if nargin<3  n = 15000;  end
if nargin<2  EbNodB = 6; end
if nargin<1  m = 2;      end
g  = 100;                                     % Filtergrad des Hilbertfilters
nn = n + g;

% Hibertfilter
% ============
b = remez(g,[.025 .975],[1 1],'Hilbert');

% Rauschen
% ========
r  = add_awgn(zeros(1,nn),1,EbNodB);          % reell
ra = delay(r,floor(g/2)) + i*filter(b,1,r);   % analytisch
ra = ra(g+1:nn);                              % Einschwingen weg

% Signal
% ======
if a~=0    dp = a/2+(2*pi-a)/m/2;
   if m==2 dp = dp + pi/2; end
else       dp = 0;
end
sa = exp(i * ((2*pi-a)/m * floor(m*rand(1,n))+dp));  % m-PSK

% Signal + Rauschen
% =================
sr = sa + ra;
mx = max([real(sr),imag(sr)]);

% Ausgabe
% =======
if nargout>0  x0 = sr; break; end

% Darstellung
% ===========
hs = fullscreen('Signalraum');
line(real(sr'),imag(sr'),'LineStyle','none','Marker','.')
line([-mx,0;mx,0],[0,-mx;0,mx],'LineStyle','-','Color','r')
w = 0:pi/90:2*pi;
line(cos(w),sin(w),'LineStyle','-','Color','r') % Einheitskreis
axis([-mx,mx,-mx,mx]); axis square; axis off
title(sprintf('Signalraum:  %2d-PSK  bei  E_b/N_0 = %4.1f dB',...
      m,EbNodB),'FontSize',fsiz)
