function nichtlinear(p,f)
% nichtlinear(p,f)
% Diese Funktion stellt das Eingangs- und das Ausgangsspektrum 
% dar fr ein System, dessen Ein/Ausgabeverhalten als Reihe 
% mit den Koeffizienten p gegeben ist.
% Das Verhalten des Systems ist gegeben durch
%            length(p)
%        y =  Summe   p(k)*x^k
%             k = 1
% f ist ein Vektor von Frequenzen, aus denen (in gleicher Amplitude)
% das Eingangssignal zusammengesetzt ist.

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
% Konstanten und Defaults
% =======================
fsz= 13;                               % FontSize
n  = 4096;                             % Anzahl der Punkte
mf = max(f);                           % hchste Frequenz
fs = 8*mf;                             % Abtastfrequenz fr die Simulation
t  = 1:n;                              % Zeitbereich
nl = 120;                              % Rauschebene 80 dB
win= kaiser(n,0.1102*(nl-8.7))';       % Kaiserfenster
%
% Simulation
% ==========
x  = sum(sin(2*pi*f'/fs*t));           % Eingabesignal
y  = polyval([reverse(p),0],x);        % Ausgabesignal
xf = abs(fft(x.*win));                 % Eingangsspektrum
yf = abs(fft(y.*win));                 % Ausgangsspektrum
xf = xf/max(abs(xf));                  % Normierung
yf = yf/max(abs(yf));                  % Normierung
%
% Darstellung
% ===========
fh = fullscreen('NichtLinear');
subplot(2,1,1); plot(fs*(0:n/2-1)/n,20*log10(xf(1:n/2)))
title(sprintf('%s\n%s','Verhalten eines nichtlinearen Systems im Frequenzbereich',...
              'Spektrum des Input-Signals'),'FontSize',fsz)
xlabel('Frequenzbereich','FontSize',fsz)
ylabel('Betrag [dB]','FontSize',fsz)
axis([0 fs/2 -100 0])
subplot(2,1,2); plot(fs*(0:n/2-1)/n,20*log10(yf(1:n/2)))
title('Spektrum des Output-Signals','FontSize',fsz)
xlabel('Frequenzbereich','FontSize',fsz)
ylabel('Betrag [dB]','FontSize',fsz)
axis([0 fs/2 -100 0])
%
% Sound
% =====
fs = 8000;
soundsc(x,fs); pause(1)
soundsc(y,fs); pause(1)
sound(0.8*(y-x)/max(abs(y-x)),fs); pause(1)

