%
%
%11.4.  Verzahnung (Interleaving)%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
% Bei vielen Kanlen treten Fehler zeitlich lokal in sogenannten Bndeln (engl. burst) auf.  
% Besonders magnetische und optische Speichermedien und Funkkanle haben diese 
% Eigenschaft.  Auf solchen Kanlen benutzte Kodes mssen Fehlerbndel bis zu einer 
% vorgegebenen Lnge korrigieren knnen.  Eine verbreitete Methode hierzu ist das 
% Verzahnen (interleaving) von Kodewrtern.
%
% Beispiel:   Je  {\fontname{Courier}m}  Kodewrter des  {\fontname{Courier}(7,4)}-Hamming-Kodes sollen die Zeilen einer  {\fontname{Courier}m*7}-Matrix 
% bilden.  Diese Matrix ist der eigentliche Block des Kodes.  Die Matrix wird spaltenweise 
% bertragen und am Empfangsort spaltenweise in die Matrix eingegeben.  Die Dekodierung 
% erfolgt dann zeilenweise.
%
%% Das folgende MATLAB-Skript erwartet die Eingabe der Anzahl  {\fontname{Courier}m}  der Hamming-Kodewrter 
%% pro Block (z.B. 16) sowie die Lnge des Fehlerbndels (z.B. 16)
%
 % Information und ihre Codierung
k = 4; n = 7;  % Parameter des Hamming-Kodes
c = inputdlg('Anzahl der Hamming-Kodewrter pro Block','Tastatureingabe'); 
m = eval(c{1});
c = inputdlg('Lnge des Fehlerbndels','Tastatureingabe'); 
fblaenge = eval(c{1});
infowort = randb(m*k);                   % Information
G = [1 0 0 0 1 0 1; 0 1 0 0 1 1 1; 0 0 1 0 1 1 0; 0 0 0 1 0 1 1];
codematr = mod( reshape(infowort,m,k)*G ,2);   % Kodierung
codewort = reshape(codematr,1,m*n);      % Block-Kodewort

 % Kanalsimulation durch Fehlerbndel der Lnge  {\fontname{Courier}fblaenge} 
fbanfang = ceil((m*k-fblaenge)*rand);    % Anfang des Fehlerbndels
fwort = zeros(1,m*n);
fwort(fbanfang+[0 fblaenge-1])   = 1;    % Fehlerbndel: Anfang und Ende
fwort(fbanfang+(1:(fblaenge-2))) = randb(fblaenge-2); % Fehlerbndel
fcodwort = mod(codewort+fwort,2);        % Anbringen des Fehlers

 % Decodierung und Korrektur
empfmatr = reshape(fcodwort,m,n);        % einlesen in Matrix
H = [G(:,5:7);eye(3)];                   % Prfmatrix
s = mod( empfmatr*H ,2)                  % Syndrome
fbit = [0 7 6 4 5 1 3 2];                % Zuordnung Syndrom => Fehlerstelle
fmat = zeros(m,n);
for k=1:m  fb = fbit(1+binmat2num(s(k,:))); if fb  fmat(k,fb) = 1; end; end
korrmat  = xor(empfmatr,fmat);           % Korrerktur
korrinfo = flach(korrmat(:,1:4)');       % korrigierte Information

 % Ausgabe ins Kommandofenster
infobits = binmatout(infowort)           % zu sendende Informationsbits
codmatrix= binmatout(codematr)           % Codematrix aus 8 (7,4)-Codewrtern
codebits = binmatout(codewort)           % Spalten der Codematrix konkateniert
empfbits = binmatout(fcodwort)           % empfangene Bits
fehlbits = binmatout(codewort~=fcodwort) % fehlerhafte Bitpositionen 
korrbits = binmatout(korrinfo)           % korrigierte Information
infofehl = binmatout(korrinfo~=infowort) % fehlerhafte Bitpositionen der Information
Anzahlfehler = sum(korrinfo~=infowort)   % Anzahl der Bitfehler nach der Korrektur
%
% Das Prinzip der Verzahnung kann bei allen Kodes angewandt werden.  Besonders lange 
% Fehlerbndel knnen korrigiert werden, wenn der benutzte Kode selbst schon Fehlerbndel 
% der Lnge  {\fontname{Courier}r}  korrigieren kann.  Dann kann die Verzahnung von  {\fontname{Courier}m}  solchen Kodewrtern 
% Fehlerbndel der Lnge  {\fontname{Courier}m*r}  korrigieren, sofern nicht an anderer Stelle noch ein Fehler 
% vorkommt.  Bei der Audio-CD werden Fehlerbndel bis zur Lnge ca. 4000 Bits vollstndig 
% korrigiert.  Bei Fehlerbndeln bis zu 12300 kann zeitlich punktuell interpoliert werden, 
% was vllig unhrbar ist (7.7 mm breiter Kratzstreifen auf der CD).  Ist die CD jedoch 
% groflchig beschdigt, hilft die Verzahnung nicht.
%
%
%% Aufgabe 11.4   Je 32 Informationsbits sollen folgendermassen kodiert werden:
%%
%% (1)  Es wird ein 16-Bit CRC angefgt, sodass sich ein (48,32)-Kode ergibt.
%%
%% (2)  Je 12 der 48 Bits werden mit dem (23,12)-Golay-Kode kodiert, der 
%%      3 Bits beliebiger Lage korrigieren kann.
%%
%% (3)  Die 4 Golay-Kodewrter werden verzahnt bertragen.
%%
%% Nach der Dekodierung und Korrektur wird der CRC verwendet, um zu prfen, ob ein 
%% Dekodierfehler vorliegt.
%%
%% Ermitteln Sie folgende Eigenschaften des Kodes:
%%
%% (a)  Welche Fehlerbndellnge kann der Kode korrigieren?
%%
%% (b)  Wieviele Bitfehler kann der Kode bei beliebiger Lage sicher korrigieren?
%%
%% (c)  Wie gross ist die Wahrscheinlichkeit eines Dekodierfehlers bei 
%%      der Kanalbitfehlerrate  {\fontname{Courier}p = 0.1}?
%%
%% (d)  Wie gross ist die Wahrscheinlichkeit, dass ein Dekodierfehler 
%%      unentdeckt bleibt?
%%
%% (e)  Wie gross ist die Bitfehlerrate bei den bertragenen Informationsbits?
%%
%