%
%
%11.6.  Viterbi-Algorithmus%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
% Im Falle von Faltungskodes gibt es keine feste Blocklnge.  Beim Soft-Dekodieren muss 
% man deshalb die Empfangssequenz vom Anfang bis zum Ende als eine zu dekodierende 
% Einheit betrachten.  Die Dekodierung erfolgt durch:
%
% {\bf}  Generierung smtlicher mglichen Informationsbitsequenzen und fr jede dieser Sequenzen:
%
%     {\bf}  Erzeugung des zugehrigen Sendemusters durch Kodierung mit dem bekannten 
%         Faltungskode
%
%     {\bf}  Bestimmung des euklidischen Abstandes zwischen dem Sendemuster und der 
%         aktuellen analogen Empfangssequenz.
%
%     {\bf}  Diejenige Informationsbitsequenz wird als die dekodierte angenommen, bei der der
%         so berechnete Anstand zwischen Sendemuster und Empfangssequenz am kleinsten ist.
%
% Diese Methode ist insofern optimal, als man dabei jeden bekannten systematischen Effekt, 
% der das Sendesignal beeinflusst, bercksichtigen kann.  Ein Beispiel dafr ist die 
% Intersymbolinterferenz. 
%
% Mit der Funktion  {\fontname{Courier}entfaltdemo}  werden nachfolgend einige Bilder generiert:
%
%% Erluterung zur Funktion im Kommandofenster:
help entfaltdemo
%
% Faltung von 12 Informationsbits mit Kode  {\fontname{Courier}r = 1/2}  und Constraint Length  {\fontname{Courier}9} ,  
% keine Intersymbolinterferenz, rauschfrei: 
entfaltdemo(faltpoly(2,9),[1],randb(12),[-1 +1],0.0)
%
% Das selbe mit weissem Rauschen  {\fontname{Courier}\sigma = 1.0} : 
entfaltdemo(faltpoly(2,9),[1],randb(12),[-1 +1],1.0)
%
% Faltung von  {\fontname{Courier}10}  Informationsbits mit Kode  {\fontname{Courier}r = 1/2}  und Constraint Length  {\fontname{Courier}5} ,  
% Intersymbolinterferenz  {\fontname{Courier}0.3}  von direkt benachbarten Abtastungen, rauschfrei: 
entfaltdemo(faltpoly(2,5),[0.3 1 0.3],randb(10),[-1 +1],0.0)
%
% Faltung von  {\fontname{Courier}10}  Informationsbits mit Kode  {\fontname{Courier}r = 1/4}  und Constraint Length  {\fontname{Courier}7} ,  
% Intersymbolinterferenz  {\fontname{Courier}0.3}  von direkt benachbarten Abtastungen, 
% weisses Rauschen mit  {\fontname{Courier}\sigma = 1.0} : 
entfaltdemo(faltpoly(4,7),[0.3 1 0.3],randb(10),[-1 +1],1.0)
%
% Die Bilder zeigen folgendes:
%
% (1)  Der Minimalabstand der Kodes ist gross
%
% (2)  Es liegt zwar kein sog. perfekter Kode vor, bei dem alle Kodewrter den selben 
%       Abstand voneinander haben, jedoch streuen die Abstnde nur etwa im Bereich 
%       Minimalabstand{\fontname{Courier}*(1..3)}
%
% (3)  Die Abstandsverteilungen sind ein Charakteristikum des Kodes.  Im rauschfreien 
%       Fall sind sie bei allen Informationsbitmustern  {\fontname{Courier}u}  gleich.
%
% (4)  Im Falle von krftigem Rauschen scheinen die zu Abstandsnachbarn gehrenden 
%       Informationsbitmuster kaum korreliert.  Im Falle eines Dekodierfehlers knnte 
%       also die dekodierte Information als zufllig angesehen werden.  Das gilt aber 
%       nur fr den hier untersuchten, in der Praxis aber nicht vorkommenden Fall, 
%       dass die Anzahl zu kodierender Informationsbits nicht wesentlich grsser als 
%       die Constraint Length ist. 
%
% Die Methode der Dekodierung durch Korrelation smtlicher mglichen Kodewrter mit 
% dem empfangenen Wort erfordert leider einen grossen Rechenaufwand.  Besteht die 
% Informationsbitsequenz aus  {\fontname{Courier}L}  Bits, so sind  {\fontname{Courier}2^L}  Sendemuster zu untersuchen.  
% {\fontname{Courier}L}  ist in der Regel gross  {\fontname{Courier}(10^2 .. 10^5)}.  Auf direkte Weise ist das Verfahren 
% wegen der Komplexitt praktisch nicht durchfhrbar. 
%
% A.J.Viterbi fand 1967 einen Algorithmus, der die oben angegebene Aufgabe exakt lst, 
% jedoch mit wesentlich geringerem Aufwand.
%
% Der Viterbi-Algorithmus wartet nicht den Empfang des letzten Bits ab sondern arbeitet 
% schrittweise.  Die Komplexitt wird gedrckt auf  {\fontname{Courier}k*2^k} , wo  {\fontname{Courier}k}  die Constraint-Lnge ist. 
% Der Algorithmus ist also besonders effizient fr kleine Constraint-Lngen.  
% {\fontname{Courier}k = 10}  ist heute etwa die Grenze des praktisch Machbaren.  Wir werden sehen, 
% dass die Qualitt eines Faltungskodes fast nur von der Constraint-Lnge abhngig ist.  
% Wirklich gute Faltungskodes knnen auch mit diesem Algorithmus nicht dekodiert werden.
%
% Der Faltungskodierer besteht aus  {\fontname{Courier}m}  FIR-Filtern im  {\fontname{Courier}GF(2)}  mit je  {\fontname{Courier}k}  binren Koeffizienten:
%
faltstruktur
%
% Das Statusregister kann fr alle  {\fontname{Courier}m}  Kodierer gemeinsam verwendet werden. 
% Es gibt also  {\fontname{Courier}2^k}  Zustnde.  Da es sich um ein Schieberegister handelt, liegt ein 
% festes Zustands-Diagramm vor.  Den schrittweisen zeitlichen Verlauf der Zustandsbergnge 
% stellt man zweckmssig im sogenannten Netz-Diagramm  (engl. trellis diagram) dar .  
% Vertikal sind hierin alle mglichen Zustnde aufgetragen und horizontal die Zeit.  Die 
% mglichen und die aktuellen bergnge sind unterschiedlich darzustellen.  Das Diagramm 
% beginnt links im Anfangszustand Null.  Bei der Kodierung von  {\fontname{Courier}R}  Bits sind am Ende 
% noch  {\fontname{Courier}k}  Nullen anzufgen (sog. trellis tail), damit der Zustand wieder bei Null endet. 
%
% Das folgende Bild zeigt vertikal die 8 mglichen Zustnde bei der Constraint Length 
% von 3 sowie in Grau die mglichen Zustandsbergnge des Schieberegisters.  Grn 
% eingetragen ist der aktuelle Weg fr die Bitfolge   {\fontname{Courier}0 1 1 0 1 0 0 0} .
%
trellisdiag(3,2,[0 1 1 0 1 0 0 0]);
%% Das Bild ist mit den Tasten - und + seitlich zu verschieben.
%
% Der Dekodierer muss in jedem Zeitschritt alle bis dahin noch mglichen Wege durch das 
% Netz-Diagramm nachvollziehen und bewerten.  Enden  {\fontname{Courier}m}  Wege in demselben Zustand,
% so wird von diesen  {\fontname{Courier}m}  Wegen nur noch der Weg mit dem bis dahin kleinsten Abstand 
% zur Empfangsfolge akzeptiert.  {\fontname{Courier}m}  ist die Stufigkeit.  Es fhren in jedem Zeitschritt 
% genau die  {\fontname{Courier}m}  Wege zusammen, deren letzte  {\fontname{Courier}cl}  Symbole gleich und das Symbol 
% davor verschieden sind.  Sie unterscheiden sich nur in Symbolen, die auf den noch zu 
% bearbeitenden Teil des Empfangssignals keinen Einfluss mehr haben knnen wegen der 
% begrenzten Lnge  {\fontname{Courier}cl}  der Faltungspolynome, d.h. die Entscheidung fr einen der Wege 
% hngt von den letzten  {\fontname{Courier}cl}  Symbolen gar nicht ab.
%
% Das folgende Bild veranschaulicht das zeitliche Fortschreiten des Algorithmus fr die 
% Constraint Length von  {\fontname{Courier}} 2.
%
%% Der Zeitschritt wird durch Tastendruck auf der Tastatur ausgelst. Im Fall der 
%% Vereinigung von Wegen ist die Ermittlung des besten Weges durch einen weiteren 
%% Tastendruck zu veranlassen:
%
trellisviterbi
%
% Fr alle zu dem selben Zustand fhrenden Wege werden mit der Entscheidung fr den 
% besten Weg die um mehr als  {\fontname{Courier}k}  Zeitschritte zurckliegenden Symbole bezglich dieses 
% Endzustands entschieden.  Das bedeutet aber nicht, dass die so weit zurckliegenden 
% Symbole endgltig schon entschieden werden, denn im allgemeinen gibt es konkurrierende
% Wege, die fr sich die Vergangenheit festgelegt haben.  Wenn spter zwischen den 
% Konkurrenten zu entscheiden ist, wird sich herausstellen, dass deren Vergangenheiten 
% verschieden sein knnen. 
%
% Dies wird in folgendem Bild dargestellt.
%
%% Mit der Leertaste werden der Reihe nach noch mgliche Wege eingeblendet:
%
trelliswege;
%
% Drei Vereinigungen mssen im obigen Bild entschieden werden.  Es verbleibt danach ein 
% grner, ein roter und ein blauer Weg, unter denen erst spter entschieden werden kann. 
%
% Im Fall von Kodes ber  {\fontname{Courier}GF(q)}  ist  {\fontname{Courier}r \leq q} .  In jedem Zeitschritt sind also maximal  
% {\fontname{Courier}q^{k+1}}  Wege zu bewerten.  Die Abstnde dieser Wege sind jeweils bis zum letzten 
% Zeitschritt schon berechnet.  In jedem Schritt mssen also im binren Fall  {\fontname{Courier}2^{k+1}}  mal 
% je: Subtraktion, Quadrat und Vergleich berechnet werden plus Aufwand fr Verwerfen 
% und Generieren von Wegen.
%
% Prinzipiell ist die Dekodierung abgeschlossen, wenn das Netzdiagramm zum Schluss im 
% Zustand Null endet.  Da es nur noch einen zulssigen Zustand gibt, kann es nur noch 
% einen Weg mit minimalem Abstand geben.  Fr die Praxis ist es wichtig zu wissen, ob 
% nicht schon vor dem Netzende ein Teil der Information fertig dekodiert ist.  Statistische 
% Untersuchungen zeigen, dass praktisch alle jeweils im Schritt  {\fontname{Courier}t}  noch berlebenden 
% Wege fr die Schritte  {\fontname{Courier}t - 5k}  dieselbe Vergangenheit haben.  Man braucht die 
% berlebenden Wege also nur bis zu dieser Lnge speichern.
%
% Die folgende Graphik veranschaulicht noch einmal den Algorithmus fr die Generatormatrix
%
% G = [ 1 0 1 ; 1 1 1 ]  %<'FontName',MSVFORMFONT>
%
%% Die ersten drei Zeittakte sind durch beliebigen Tastendruck zu veranlassen.  Nach 
%% Beendigung der Dekodierung erscheint der einzig verbliebene Weg im Trellisdiagramm 
%% in rot (das dauert eine Weile):
%
G = faltpoly(2,3);             % Faltungspolynom
info = [0 1 0 0 0 1 1 0 1 0];  % zu kodierendes Bitmuster
x = 2*faltcode(info,G,0,2)-1;  % Faltungkode
y = x + 0.5*randn(size(x));    % verrauschtes Empfangswort
viterbi(G,x,[-1 +1],1)         % Viterbi-Dekodierung
%
% Zur Demonstration der Leistungsfhigkeit der Faltungskodes dient die Funktion  {\fontname{Courier}faltcodesim} :
%
help faltcodesim
%
% Kern der Funktion ist:
%
%  g = faltpoly(ir,k);               % Kodierungspolynome     %<'FontName',MSVFORMFONT>
%  x = randb(n);                     % zufllige Information  %<'FontName',MSVFORMFONT>
%  c = faltcode(x,g,1);              % Kodierung              %<'FontName',MSVFORMFONT>
%  y = add\_awgn(2*c-1, 1/ir,ebnodb); % Kanalrauschen          %<'FontName',MSVFORMFONT>
%  z = viterbi(g,y);                 % Decodierung            %<'FontName',MSVFORMFONT>
%  x0= sum(z~=x),                    % Anzahl der Bitfehler   %<'FontName',MSVFORMFONT>
%
% Das Bild von faltcodesim zeigt oben das Histogramm des empfangenen Signals, 
% welches bei kleinen  {\fontname{Courier}E_b/N_0}  keine deutliche Trennung der Binrsymbole erkennen lsst. 
% Unten ist jeweils das Sende- und Empfangssignal im Zeitbereich dargestellt:
%
faltcodesim(2,9,100,1.5)
%
faltcodesim(4,10,1000,1.2)
%
% Alternativ kann die Funktion  viterbitest benutzt werden:
%
help viterbitest
%
viterbitest(faltpoly(2,9),0.8,1000)
%
viterbitest(faltpoly(4,10),1.1,1000)
%
% Bei hohen Datenraten muss der Viterbi-Dekodierer in Hardware realisiert werden. 
% Der Realisierungsaufwand hngt dann wesentlich von der Signalreprsentation ab. 
% blicherweise wird eine Festkomma-Reprsentation in nur 3 Bits gewhlt.  Damit 
% erreicht man gegenber der harten Datenentscheidung (Reprsentation in 1 Bit) 
% schon fast den ganzen mglichen Gewinn der weichen Entscheidung.  Die Reprsen-
% tation des Signals im Dekodieralgorithmus wird im Abschnitt  11.9  behandelt.
%
%
%% Aufgabe 11.6a   Ermitteln Sie mit der Funktion  faltfrate2  die Lage in dem durch  plot\_code\_gain  
%% gezeichneten Diagramm an der Stelle  E_b/N_0 = 4 dB  fr folgende Faltungskodes:   
%% (2,3), (2,5), (2,7), (2,9), (3,5), (4,5)
%%
help faltfrate2
%%
%% Aufgabe 11.6b   Unter der einfachen, aber realistischen Annahme, dass jeder Dekodierfehler 
%% eine Sequenz von  cl  Bits  zu Rauschen macht, wo  cl  die Constraint Length ist, ergibt 
%% sich als Standardabweichung der mit  faltfrate  ermittelten Bitfehlerrate  br  der 
%% Wert  {\fontname{Courier}sqrt(cl*br/(2*n))}.
%% Mit welchem  {\fontname{Courier}n}  muss man simulieren, um eine relative Genauigkeit von  20%  (Standardabweichung) 
%% fr die Bitfehlerrate zu erreichen bei  {\fontname{Courier}br = 10^{-k}}  mit  {\fontname{Courier}k = 1..9} ?
%% (Formel herleiten und erst dann Werte einsetzen)
%%
%% Aufgabe 11.6c   Folgende Funktion generiert triviale Faltungskodes der Constraint Length  {\fontname{Courier}cl}  
%% und der Koderate {\fontname{Courier}2^-(cl-2)}  durch Erzeugung smtlicher Binrmuster der Lnge  {\fontname{Courier}cl - 2}  
%% und Voranstellen sowie Anfgen je einer 1:
%%
cl = 7;
faltpolygross(cl)
%%
%% Lokalisieren Sie die Bitfehlerrate des durch  faltpolygross(8) gegebenen Kodes mit  faltfrate2  
%% bei  E_b/N_0 = 0 dB  und  2 dB .  Zur Umrechnung von E_b/N_0 nach sigma dient:
%%
help ebn2sigma
%%
%% Sehen Sie sich die Signalverteilung und das Signal im Zeitbereich mit  viterbitest an! 
%% (Tippen Sie h fr Hilfe zur Zoom-Funktion).
%%
%% Offensichtlich ist dieser Kode wesentlich besser als alle bisher behandelten, allerdings 
%% auf Kosten sehr grosser Bandbreite.
%
