%
%
%14.3.5  Datensicherung fr Kurzwellenkanal: Pactor2 %<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-16,'Color',MSVTITLCOLOR>
%
%
%
%% Dieser Abschnitt ist vorerst kaum mehr als eine Stichwortsammlung.
%% Eine Simulation des Verfahrens in MATLAB ist in Arbeit 
%% (unten schon mal eine Kostprobe) 
%
%
% \bfEntwurfsziele
%
% Pactor2 ist eine von deutschen Funkamateuren entwickelte Betriebsart, die inzwischen 
% kommerziell weltweit benutzt wird.  Insbesondere wird sie bei praktisch allen Mailboxen 
% auf den Kurzwellenbndern des Amateurfunks und bei E-Mail-Verkehr von Schiffen aus 
% wegen der ausserordentlichen Zuverlssigkeit eingesetzt.
%
% Pactor2 liegen die folgenden Entwurfsziele zugrunde:
%
% (1)  Digitale Datenbertragung in Halbduplex von Punkt zu Punkt mit schneller 
%       Umschaltung der bertragungsrichtung (1 Sekunde) fr flotten Chat
%
% (2)  Automatische Umschaltung in einen Data-Mode zur bertragung grsserer 
%       Datenmengen in eine Richtung (4 Sekunden-Pakete)
%
% (2)  Hchste Datensicherheit auch bei extrem schlechten Kanlen (bis zu 
%       minutenlangem vollstndigen Ausfall des Kanals in beiden Richtungen)
%
% (3)  Optimale Anpassung der bertragungsparameter an schnell variierende 
%       Kanalbedingungen
%
% (4)  Die Zeitbedingungen (ARQ) sind an die Laufzeiten bei internationalen 
%       Funkverbindungen auf Kurzwelle angepasst (auch der "lange" Weg z.B. 
%       Hamburg - LosAngeles ber Neuseeland muss mglich sein, weil hufig besser)
%
% (5)  Bandbreitebedarf unabhngig von der aktuellen Datenrate 500 Hz entsprechend 
%       den blichen Schmalbandfiltern von Kurzwellen-Sende-Empfngern
%
% (6)  Reiner FEC-Mode mglich
%
%
% \bfGrundprinzip
%
% Pactor2 benutzt zur Datensicherung eine Kombination von FEC und ARQ.
%
%
% \bfStuktur der Pakete
%  
% Die Pakete bestehen aus Kopf, Datenblock, Status und CRC
%
% Der Kopf ist nicht in den Faltungskode einbezogen.
%    
% Fr den 16-Bit-CRC wird das Polynom nach CCITT benutzt.
%
%
% \bfKomprimierung
%
% Je nach Datenaufkommen und Einstellung (MODE 0..2). wird ASCII, Huffmann oder 
% Pseudo-Markoff Komprimierung vorgenommen.  Aber auch bei Einstellung ASCII werden 
% mehrfach wiederholte Zeichen nicht einfach nacheinander ausgegeben.
%
%
% \bfKodierung
%
% Der vom Komprimierer kommende Bitstrom  {\fontname{Courier}b[i]}  wird mit dem  {\fontname{Courier}(18,9,12)}-Faltungscode 
% der Rate 2 codiert, dessen Polynome generiert werden durch
%
faltpoly(2,9)
%
% Kodiert wird der Datenblock zusammen mit dem Status und CRC.
%
%
% \bfVerzahnung
%   
% Der fertig kodierte Bitstrom wird spaltenweise in eine Matrix geschrieben und diese 
% zeilenweise ausgesendet.
%    
% Die Verzahnung ist bei den beiden Pakettypen unterschiedlich:
%
% \bfStandard Mode
%
%    A       SP      @       SP      @     Status        ASCII-Text  %<'FontName',MSVFORMFONT>
% 1000001000000100000000100000010000000010   ?           Bitstrom    %<'FontName',MSVFORMFONT>
% 
% 11 1 1111    11 1 1111       11 1 1111     ?           Faltung mit %<'FontName',MSVFORMFONT>
%       11 1 1111       11 1 1111       11 1 1111        Polynom 1   %<'FontName',MSVFORMFONT>
% -----------------------------------------------                    %<'FontName',MSVFORMFONT>
% 1101010011011000101111110101100010111111???????        Code Teil 1 %<'FontName',MSVFORMFONT>
% Spalte1 A B     Spalte2 A B     Spalte3 A                          %<'FontName',MSVFORMFONT>
%
%
% 1   111 1    1   111 1       1   111 1     ?           Faltung mit %<'FontName',MSVFORMFONT>
%       1   111 1       1   111 1       1   111 1        Polynom 2   %<'FontName',MSVFORMFONT>
% -----------------------------------------------                    %<'FontName',MSVFORMFONT>
% 1000110010111110011101100011111001110110???????        Code Teil 2 %<'FontName',MSVFORMFONT>
%        .       .       .       .       .       .                   %<'FontName',MSVFORMFONT>
% Spalte5 B Spalte 6 A B  Spalte 7 A B                               %<'FontName',MSVFORMFONT>
%
%
% 10010001    Kopf  A                                                %<'FontName',MSVFORMFONT>
%
% 111011010   Block A                                                %<'FontName',MSVFORMFONT>
% 100100010                                                          %<'FontName',MSVFORMFONT>
% 011101110                                                          %<'FontName',MSVFORMFONT>
% 111111111                                                          %<'FontName',MSVFORMFONT>
% 011101100                                                          %<'FontName',MSVFORMFONT>
% 101001110                                                          %<'FontName',MSVFORMFONT>
% 011011110                                                          %<'FontName',MSVFORMFONT>
% 011100010                                                          %<'FontName',MSVFORMFONT>
%
%
% 00010011    Kopf B                                                 %<'FontName',MSVFORMFONT>
%
% 101110001   Block B                                                %<'FontName',MSVFORMFONT>
% 111001110                                                          %<'FontName',MSVFORMFONT>
% 001101101                                                          %<'FontName',MSVFORMFONT>
% 110001111                                                          %<'FontName',MSVFORMFONT>
% 110110001                                                          %<'FontName',MSVFORMFONT>
% 001111110                                                          %<'FontName',MSVFORMFONT>
% 000101111                                                          %<'FontName',MSVFORMFONT>
% 000100010                                                          %<'FontName',MSVFORMFONT>
%
% Die nicht genannten Spalten enthalten den CRC
%
%
% Data Mode
%
%    @       SP      @       SP      v       SP      @       SP      ASCII-Text  %<'FontName',MSVFORMFONT>
% 000000100000010000000010000001000110111000000100000000100000010000 Bitstrom    %<'FontName',MSVFORMFONT>
%
%       11 1 1111       11 1 1111  11 1 1111   11 1 1111       11 1  Faltung mit %<'FontName',MSVFORMFONT>
%              11 1 1111       11 1 1111                11 1 1111    Polynom 1   %<'FontName',MSVFORMFONT>
%                                   11 1 1111                                    %<'FontName',MSVFORMFONT>
%                                     11 1 1111                                  %<'FontName',MSVFORMFONT>
%                                      11 1 1111                                 %<'FontName',MSVFORMFONT>
%                                       11 1 1111                                %<'FontName',MSVFORMFONT>
% ------------------------------------------------------------------------------ %<'FontName',MSVFORMFONT>
% 000000110101100010111111010110001110101010111100101111110101100010 Code Teil 1 %<'FontName',MSVFORMFONT>
% Spalte1 A B     Spalte2 A B     Spalte3 A B     Spalte4 A B  ...               %<'FontName',MSVFORMFONT>
%
%       1   111 1       1   111 1  1   111 1   1   111 1       1   1 Faltung mit %<'FontName',MSVFORMFONT>
%              1   111 1      1   111 1                1   111 1     Polynom 2   %<'FontName',MSVFORMFONT>
%                                   1   111 1                                    %<'FontName',MSVFORMFONT>
%                                     1   111 1                                  %<'FontName',MSVFORMFONT>
%                                      1   111 1                                 %<'FontName',MSVFORMFONT>
%                                       1   111 1                                %<'FontName',MSVFORMFONT>
% ------------------------------------------------------------------------------ %<'FontName',MSVFORMFONT>
% 000000100011111001110110001111100001111001000010011101100011111001 Code Teil 2 %<'FontName',MSVFORMFONT>
%        .       .       .       .       .       .       .       .               %<'FontName',MSVFORMFONT>
% Spalte21 A B    Spalte22 A B   Spalte23 A B    Spalte24 A B  ...               %<'FontName',MSVFORMFONT>
%
%
% 0000100001                                  Kopf A                             %<'FontName',MSVFORMFONT>
%
% 0111101111111111110000000100000000000010    Block A                            %<'FontName',MSVFORMFONT>
% 0010000000000000000101011011111111111101                                       %<'FontName',MSVFORMFONT>
% 0111111111111111110101011011111111111110                                       %<'FontName',MSVFORMFONT>
% 0101111101111111110001111111011111111110                                       %<'FontName',MSVFORMFONT>
% 0111111111111111110100100000100000000011                                       %<'FontName',MSVFORMFONT>
% 0101111111111111111001111011011111111100                                       %<'FontName',MSVFORMFONT>
% 1111101111111111111011111011111111111101                                       %<'FontName',MSVFORMFONT>
% 1101111101111111110000000000100000000011                                       %<'FontName',MSVFORMFONT>
%
%
% 010001001001                                Kopf B                             %<'FontName',MSVFORMFONT>
%
% 0010000000000001100000000000000000011110    Block B                            %<'FontName',MSVFORMFONT>
% 1101111111111111000100100100000000000001                                       %<'FontName',MSVFORMFONT>
% 0010010000000000011011011111111111100111                                       %<'FontName',MSVFORMFONT>
% 1111101111111110111011011101011111110111                                       %<'FontName',MSVFORMFONT>
% 1111111111111111011011011011111111101001                                       %<'FontName',MSVFORMFONT>
% 0010010000000000011011011011111111111000                                       %<'FontName',MSVFORMFONT>
% 0000000000000000101011111111111111110000                                       %<'FontName',MSVFORMFONT>
% 000000000000000100000000000000000001001                                        %<'FontName',MSVFORMFONT>
%    
%    
% \bfModulation
%    
% 2-Trger-DPSK                                    %<'FontName',MSVFORMFONT>
% Schrittfrequenz = 100 Hz                         %<'FontName',MSVFORMFONT>
% Schrittversatz zwischen beiden Trgern 5 ms      %<'FontName',MSVFORMFONT>
%   
%    
% \bfARQ
%    
% Timing
% Steuerworte:  {\fontname{Courier}6}  Kodeworte eines perfekten nichtlinearen Kodes 
% mit  {\fontname{Courier}n = } ,  {\fontname{Courier}Abstand = }
%
%
% \bfSimulation
%
%% Dies sollte mehrfach wiederholt werden um zu zeigen, dass bisweilen ein CRC-Fehler 
%% auftritt.  Als Sound wird zunchst das unverrauschte Sendesignal ausgegeben,
%% danach das zur Dekodierung verwendete Empfangssignal:
fa    = 4000;     % Abtastrate
mark  = 1000;     % Mark-Trgerfrequenz
space = 800;      % Space-Trgerfrequenz
sigma = 0.8;      % Standardabweichung des Kanalrauschens
x     = pactor2tx('Abcde',fa,mark,space,sigma); % Signal
pactor2rx(x,fa,mark,space);  % Empfnger mit Dekodierung
%
% Zum Empfang des Blockes muss der Empfnger in dieser Simulation den Header 
% detektieren und danach den Block dekodieren (FEC-Verfahren).  Das Matched-Filter 
% zum Raised-Kosinus verursacht erhebliche Intersymbolinterferenz (zu sehen im 
% Empfangssignal).
%% Die Intersymbolinterferenz wird zur Zeit noch nicht bercksichtigt.
%% Die Simulation von ARQ ist noch nicht fertig.
%
