%
%
%1.3.2  Direkte Digitale Synthese (DDS)%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-8,'Color',MSVTITLCOLOR>
%
%
%
% Dieser Abschnitt hat zwei Aufgaben:  
%
% (a)  die ausfhrliche Behandlung eines wichtigen Teilsystems jedes modernen 
%       Kommunikationssystems
%
% (b)  die Einfhrung wichtiger Begriffe und Zusammenhnge an einem berschaubaren 
%       praktischen Beispiel
%
% Unter dem Begriff  {\bfDirekte Digitale Synthese} (DDS) wird allgemein die digitale Berechnung 
% von quidistanten Werten der Sinusfunktion verstanden.  Die Berechnung muss dabei so 
% effizient sein, dass Sinusschwingungen hoher Frequenz in Realzeit erzeugt werden knnen. 
% Die Abtastfrequenz ist fest vorgegeben.  Die Frequenz der zu erzeugenden Schwingung muss 
% dagegen sehr przise einstellbar sein.  Natrlich knnen nur Frequenzen bis zur Hlfte 
% der Abtastfrequenz generiert werden.
%
% {\bfBeispiel:} 
% Generierung der Schwingung    {\fontname{Courier}sin(2*pi*1.931*t+0.371)}   fr die Abtastfrequenz  {\fontname{Courier}100 Hz}:
%
abtastbild('sin(2*pi*1.931*t+0.371)',100,[0,1]);
%
% {\bfBeispiel:}
% Generierung der Schwingung    {\fontname{Courier}sin(2*pi*1.931*t+0.371)}   fr die Abtastfrequenz  {\fontname{Courier}3 Hz} 
% (Nyquist-Bedingung verletzt):
%
abtastbild('sin(2*pi*1.931*t+0.371)',3,[0,1]);
%
% In letzteren Fall gibt es ein Alias von tieferer Frequenz:
%
abtastbild('sin(2*pi*1.931*t+0.371)',3,[0,1]);    h(1) = gcf;
abtastbild('sin(2*pi*1.069*t-0.371+pi)',3,[0,1]); h(2) = gcf;
for k = 1:10  figure(h(1+mod(k,2))); pause(0.2); end
%
% Jede Struktur zur Realisierung der DDS  besteht aus zwei Teilstrukturen:
% 
%    *  fr die Berechnung des Sinus-Argumentes
% 
%    *  fr die Berechnung der Sinusfunktion
%
% Das Sinus-Argument, also die Phase, wird in einem Phasenakkumulatorregister  {\fontname{Courier}pa}  reprsentiert.  
% Zum Inhalt dieses Phasenakkumulatorregisters wird in jedem Takt der Abtastfrequenz  {\fontname{Courier}f_s}  
% ein fr jede zu generierende Frequenz  {\fontname{Courier}f}  festes Phaseninkrement  {\fontname{Courier}dp}  hinzuaddiert:
%
%     pa(k+1) = (pa(k) + dp) mod 2\pi         %<'FontName',MSVFORMFONT>
%
%          dp = 2\pi f/fs                     %<'FontName',MSVFORMFONT>
%
% Die Zusammenhnge werden in folgendem Bild erlutert:
%
ddsgraph
%
% Die Realisierung erfolgt blicherweise durch ein einfaches Schaltwerk, dessen Zustandsregister 
% der Phasenakkumulator mit  {\fontname{Courier}n}  Bits ist.  Als Addierer modulo  {\fontname{Courier}2\pi}  wird einfach ein 
% n-Bit-Addierer verwendet.  Wird der Inhalt des Registers  {\fontname{Courier}pa}  als unsigned Integer interpretiert, 
% so entspricht der Wert  {\fontname{Courier}2^n}  dem vollen Kreis  {\fontname{Courier}2\pi}  und  {\fontname{Courier}0}  dem Winkel {\fontname{Courier}0}.  Dementsprechend 
% ergibt sich die Reprsentation von  {\fontname{Courier}dp}  zu
%
%          rdp = dp*2^n/2\pi = f/fs * 2^n   %<'FontName',MSVFORMFONT>
%
% Die Beziehung  {\fontname{Courier}f/fs = dp/2\pi = rdp/2^n}  lsst sich direkt dem folgenden Bild entnehmen:
%
ddsgraph(1)
%
% {\bfBeispiel:}   {\fontname{Courier}fs = 8000 Hz;  f = 440 Hz;  n = 32;}  Hieraus ergibt sich:
%
%            rdp = 440/8000 * 2^{32} = 23622320.3   %<'FontName',MSVFORMFONT>
%
% Der Addierer ist auf  {\fontname{Courier}n}  Bits begrenzt.  {\fontname{Courier}rdp}  muss eine ganze Zahl sein.  Der Wert ist also zu 
% runden.  Die Rundung hat zur Folge, dass die generierte Frequenz von der gewnschten etwas 
% abweicht.  Der Fehler von  {\fontname{Courier}rdp}  ist maximal  {\fontname{Courier}1/2} .  Daraus ergibt sich der maximale 
% Fehler der Frequenz zu
%
%            df = fs/2^{n+1}   %<'FontName',MSVFORMFONT>
%
% Die Berechnung der Sinusfunktion erfolgt ber eine gespeicherte Tabelle.  Der 
% Realisierungsaufwand dieser Tabelle hngt exponentiell ab von der Anzahl der 
% Adressbits, die dem Phasenakkumulator-Register entnommen werden.  Andererseits 
% ist das Raster der generierbaren Frequenzen umgekehrt proportional zur Tabellenlnge.  
% {\fontname{Courier}n}  ist deshalb fast immer so gro zu whlen, da  {\fontname{Courier}N = 2^n}  als Adressraum unrealistisch 
% ist.  bliche DDS-Realisierungen nehmen nur die  {\fontname{Courier}m}  signifikantesten von den  {\fontname{Courier}n}  Bits 
% des  Phasenakkumulatorregisters als Adressbits.  Durch das Fortlassen der unteren  
% {\fontname{Courier}n - m}  Bits des Phasenakkumulatorregisters ergibt sich natrlich ein Fehler. 
%
% Wesentlich besser als das einfache Fortlassen der unteren  {\fontname{Courier}n - m}  Bits ist die 
% Approximation des Sinus durch eine Taylor-Reihe.  Die Taylor-Reihe ist im Falle der 
% Sinusfunktion leicht zu realisieren, weil die Ableitungen des Sinus aus derselben 
% Tabelle zu entnehmen sind.  Mit  {\fontname{Courier}s = sin(x_0)}  und  {\fontname{Courier}c = cos(x_0)}  ist die 
% Taylor-Entwicklung dritten Grades um  {\fontname{Courier}x_0}  z.B.
%
%    sin(x_0+\deltax) = s + \deltax*c - \deltax^2*s/2 - \deltax^3*c/6   %<'FontName',MSVFORMFONT>
%
% {\fontname{Courier}x_0}  ergibt sich aus den oberen  {\fontname{Courier}m}  Bits von  {\fontname{Courier}pa},  {\fontname{Courier}dx}  aus den verbleibenden Bits. 
%
% Die Genauigkeit der Approximation hngt von  {\fontname{Courier}\deltax}  ab.  Der Maximalwert 
% von  {\fontname{Courier}\deltax}  wird durch den Abstand der tabellierten Werte, also durch die Grsse 
% der Tabelle festgelegt.  Die Funktion  {\fontname{Courier}sinprec}  stellt den Fehler der Sinusberechnung 
% ber dem gesamten Bereich des Phasenakkumulators dar fr drei Methoden: 
% 1 :  nur Tabellennachschlag (nchst liegender tieferer Wert) 
% 2 :  lineare Interpolation
% 3 :  Taylor-Entwicklung dritten Grades
% Parameter sind die Lnge der Sinustabelle und der Methodenindex. 
% Angenommen wird jeweils der oben beschriebene einfache Fall, dass  
% {\fontname{Courier}0 <= DX < 2\pi/Tabellenlnge}. 
%
sinprec(16,1);
%
sinprec(16,2);
%
sinprec(16,3);
%
sinprec(64,1);
%
sinprec(64,2);
%
sinprec(64,3);
%
sinprec(256,3);
%
% Der maximale Fehler ergibt sich zu:
%
%                Tabellenlnge          %<'FontName',MSVFORMFONT>
% Methode     16       64       256     %<'FontName',MSVFORMFONT>
% --------------------------------------%<'FontName',MSVFORMFONT>
%    1       4e-1     1e-1      2e-2    %<'FontName',MSVFORMFONT>
%    2       2e-2     1e-3      8e-5    %<'FontName',MSVFORMFONT>
%    3       1e-3     3e-6      5e-9    %<'FontName',MSVFORMFONT>
%
% Um die Genauigkeit der Reprsentation von 24-Bit Festkomma oder Short Real 
% mit 23-Bit-Mantisse zu erreichen, muss die Taylor-Reihenentwicklung benutzt 
% werden mit einer Tabelle von wenigstens 128 Werten fr eine Sinusschwingung.
%
%% bung 1.3.2 Es soll eine DDS entworfen werden fr die ROM-Wortbreite = 10 Bit  
%% und  n = 32 .  Wie gross muss  {\fontname{Courier}m}  fr die drei Verfahren jeweils gewhlt werden, 
%% damit der Fehler in der selben Grssenordnung liegt wie der Quantisierungsfehler 
%% der Ausgabe?
%
help sinprec
%