%
%
%2.1  Generelle Systemeigenschaften%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-4,'Color',MSVTITLCOLOR>
%
%
%
% Ein idealer Kanal ist linear und zeitinvariant.  Ein solches System wird kurz {\bfLTI-System} 
% genannt (Linear Time Invariant):
%
% {\bfLinearitt} eines Systems bedeutet:
%
% Gegeben zwei Eingabesignale  {\fontname{Courier}x(t)}  und  {\fontname{Courier}y(t)}  fr das System sowie die zugehrigen 
% Antworten des Systems  {\fontname{Courier}X(t)}  und  {\fontname{Courier}Y(t)}.  Dann heisst das System linear, wenn fr 
% alle reellen Zahlen  {\fontname{Courier}a}  und  {\fontname{Courier}b}  gilt:  Die Antwort des Systems auf das zusammengesetzte 
% Signal   {\fontname{Courier}s(t) = a*x(t) + b*y(t)}   ist   {\fontname{Courier}S(t) = a*X(t) + b*Y(t)}.
%
% {\bfZeitinvarianz} bedeutet:
%
% Sei  {\fontname{Courier}X(t)}  die Antwort des Systems auf das Eingangssignal  {\fontname{Courier}x(t)}.  Dann ist die 
% Antwort des LTI-Systems auf das Eingangssignal  {\fontname{Courier}x(t+a)}  gegeben durch  {\fontname{Courier}X(t+a)}.
%
% LTI-Systeme lassen sich auf verschiedene Weisen beschreiben.  Am einfachsten ist 
% die Angabe der komplexen bertragungsfunktion  {\fontname{Courier}C(j\omega)}, wo  {\fontname{Courier}j}  die imaginre Einheit 
% und  {\fontname{Courier}\omega = 2\pif}  die Kreisfrequenz ist.  Das Ein/Ausgabeverhalten eines LTI-Systems 
% ist dann im Frequenzbereich gegeben durch
%
%              Y(j\omega) = C(j\omega)*X(j\omega).  %<'FontName',MSVFORMFONT>
%
% {\fontname{Courier}X(j\omega)}  und  {\fontname{Courier}Y(j\omega)}  sind hier die Fouriertransformierten von Eingabesignal  {\fontname{Courier}x(t)}  
% und Systemantwort  {\fontname{Courier}y(t)}.
%
% Oft wird anstelle der Darstellung der komplexen Funktion  {\fontname{Courier}C(j\omega)}  in der komplexen 
% Ebene mit Realteil und Imaginrteil die Darstellung in Polarkoordinaten bevorzugt:
%
%              C(j\omega) = A(\omega) e^{jP(\omega)}  %<'FontName',MSVFORMFONT>
%
% Die reelle nicht negative Funktion  {\fontname{Courier}A(\omega)}  gibt das Amplitudenverhalten des Systems 
% an und die reelle Funktion  {\fontname{Courier}P(\omega)}  die Phasendrehung in Abhngigkeit von  {\fontname{Courier}\omega}.
%
% Das angegebene Verhalten lsst sich durch inverse Fourier-Transformation in den 
% Zeitbereich transformieren.  Dort ergibt sich die Antwort des Systems auf das 
% Eingabesignal  {\fontname{Courier}x(t)}  als Faltung von  {\fontname{Courier}x(t)}  mit der sog. Impulsantwort  {\fontname{Courier}h(t)}  des Systems.
%
% Ein triviales Beispiel:
% konstante Amplitude fr alle  {\fontname{Courier}\omega}:         {\fontname{Courier}A(\omega) = 1}
% linear von  {\fontname{Courier}\omega}  abhngige Phasendrehung:  {\fontname{Courier}P(\omega) = -\omegaT}
% Die Impulsantwort im Zeitbereich ergibt sich durch inverse 
% Fouriertransformation (Resultat im Kommandofenster):
%
syms w t T;            % Erklrung als symbolische Variable 
A = 1;                 % konstanter Amplitudengang 
P = -T*w;              % linearer Phasengang 
C = A*exp(j*P);        % komplexe bertragungsfunktion 
IA = ifourier(C,w,t)   % Impulsantwort des Systems  
%
% Die Faltung eines Eingangssignals  {\fontname{Courier}x(t)}  mit der Impulsantwort  {\fontname{Courier}Dirac(t-T)}  ergibt das 
% Systemverhalten im Zeitbereich:
%
%        y(t) = x(t-T)  %<'FontName',MSVFORMFONT>
%
% Das ist also eine einfache Verzgerung um den Betrag  {\fontname{Courier}T}.
%
% Entsprechend ist die Impulsantwort eines Kanals mit Echo die Summe von Dirac-Funktionen, 
% z.B.
%
%        h(t) = 0.8*Dirac(t-t_0) + 0.5*Dirac(t-t_1)  %<'FontName',MSVFORMFONT>
%
% Hierzu ein praktischer Versuch:
% Zunchst wird das Original ausgegeben, dann die Antwort des Kanals
%
load 'sprache.mat';   % ldt ein Sample auf die Variable x
sound(x,8000); pause(1)
n = 1500;             % Vergerung 1500 Samples bei 8000 Samples/s
sound(conv(x,[0.8 zeros(1,n) 0.5]),8000)
%
% Und noch einer mit  {\fontname{Courier}100} Wegen unterschiedlicher Verzgerung bis maximal  {\fontname{Courier}1 s}  
% sowie zuflligen Amplituden multipliziert mit  {\fontname{Courier}exp(-Sampleindex/3000)} , was eine 
% Zeitkonstante von  {\fontname{Courier}0.375 s}  bedeutet:
%
load 'sprache.mat';   % ldt ein Sample auf die Variable x
m = 100;              % Anzahl der Sreuzentren
h = zeros(1,8000);    % Impulsantwort zunchst Null 
v = floor(8000*rand(1,m)) + 1;  % m Verzgerungen in Samples
a = randn(1,m);                 % m Amplituden
for k=1:m  h(v(k)) = a(k)*exp(-v(k)/3000); end % Impulsantwort
y = conv(x,h);        % Faltung im Zeitbereich
soundsc(y,8000)       % Audioausgabe
%
%
%% bung 2.1  Die (nichtkausale) Impulsantwort eines LTI-Systems sei im Zeitbereich 
%% gegeben durch
%%
syms t;
IA = exp(-t^2);
%%
%% 1. Wie lautet die bertragungsfunktion   {\fontname{Courier}C(j\omega)} ?
%% 2. Wie lautet der Amplitudenfrequenzgang {\fontname{Courier}A(\omega)} ?
%% 3. Wie lautet der Phasenfrequenzgang     {\fontname{Courier}P(\omega)} ?
%
% Musterlsung (im Kommandofenster):
%
lsg_2_1
%
%

