%
%
%2.2.1  Rauschen%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
% Die Strke einer additiven Strung kann durch ihre Leistung oder durch ihre Amplitude 
% angegeben werden oder bei Impulsstrungen durch die Hufigkeit ihres Auftretens. 
%
%  
% {\bf 2.2.1.1  Additives weisses Gaussches Rauschen}
% {\bf             (Additive White Gaussian Noise, AWGN)}
%
% Unkorrelierte Gauss-verteilte Strungen besitzen ein gleichverteiltes Spektrum:
%
n  = 16384;                 % Lnge des Strvektors (beliebig)
fs = 8000;                  % Abtastrate
rt = randn(1,n);            % normalverteilte Strung
rf = fft(rt);               % FFT der Strung
h1 = fullscreen('Spektrum');
plot((1:n)/n,abs(rf))       % Spektrum der Strung
set(gca,'XLim',[0,1/2],'YScale','log')
xlabel('Frequenzbereich (relativ zur Abtastfrequenz)')
sound(rt/max(abs(rt)),fs)   % normalverteiltes Rauschen
%
% AWGN ist im Zeitbereich normalverteilt:
%
h2 = fullscreen('Verteilung im Zeitbereich');
hist(rt,-4:0.1:+4)
set(gca,'XLim',[-4.1 +4.1])
%
% AWGN ist im Frequenzbereich normalverteilt:
%
h2 = fullscreen('Verteilung im Frequenzbereich');
subplot(1,2,1); 
hist(real(rf),-400:10:+400); title('Realteil')
set(gca,'XLim',[-400 +400])
subplot(1,2,2);
hist(imag(rf),-400:10:+400); title('Imaginrteil')
set(gca,'XLim',[-400 +400])
%
% Die Leistung  {\fontname{Courier}P}  ist Energie/Zeit.  Im zeitdiskreten Fall hat man also  
% {\fontname{Courier}P = f_s  * Energie/Abtastschritt} . 
% Wir werden im folgenden die auf  {\fontname{Courier}f_s = 1}  normierte Leistung betrachten.
%
% Fr AWGN gilt dann:   {\fontname{Courier}P = \sigma^2}
%
% Meistens ist anstelle der absoluten Leistung des Rauschens ihre relative Grsse zur 
% Leistung des Nutzsignals gefragt.  Dieses Verhltnis wird Signal-Rauschverhltnis (SNR) 
% genannt.  Es wird blicherweise in dB angegeben:
%
%       SNR = 10*log10(Nutzleistung/Strleistung)  %<'FontName',MSVFORMFONT>
%
%% bung 2.1.1  Das Nutzsignal sei eine Sinusschwingung der Amplitude 1.0 
%% und dieses sei gestrt durch AWGN mit  \sigma = 0.1.  Wie gross ist SNR (in dB)?
%
%
% {\bf2.2.1.2  Pulsstrungen}
%
% Impulsstrungen knnen im Zeitbereich regelmssig auftreten.  Dies ist z.B. der Fall bei 
% Funkstrungen durch RADAR-Gerte oder Benzinmotoren.  Elektrostatische Entladungen 
% sind dagegen meist zufllig verteilt.
%
% Regelmssige Impulse:
%
n  = 16000;
fp = 10;                    % Impulsfrequenz (Hz)
fs = 8000;                  % Abtastrate
s  = zeros(1,n);            % Null-Signal
tp = 1:round(fs/fp):n;      % Zeitpunkte fr Impulse
s(tp) = 1;                  % Impulse
sf = fft(s);                % FFT der Strung
sound(s,fs)
%
% Das Strspektrum ist Frequenz-diskret:
%
h1 = fullscreen('Spektrum');
plot((1:n)/fs,abs(sf))      % Spektrum der Strung
set(gca,'XLim',[0,1/2],'YScale','log')
xlabel('Frequenzbereich (relativ zur Abtastfrequenz)')
%
% Das Spektrum eines einzelnen Dirac-Pulses kontinuierlich und konstant:
%
n  = 16384;
s  = zeros(1,n);
s(ceil((n-1)*rand)) = 1;
sf = fft(s);
h1 = fullscreen('Spektrum');
plot((1:n)/fs,abs(sf))      % Spektrum der Strung
set(gca,'XLim',[0,1/2],'YLim',[0.1,10],'YScale','log')
xlabel('Frequenzbereich (relativ zur Abtastfrequenz)')
%
% Unregelmssige Impulse:
%
n  = 16384;
fp = 10;                    % mittlere Impulsfrequenz
fs = 8000;                  % Abtastrate
s  = zeros(1,n);            % Null-Signal
tp = ceil((n-1)*rand(1,round(n*fp/fs))); % Zeitpunkte fr Impulse
s(tp) = 1;                  % Impulse
sound(s,fs)
%
% Impulsbndel:
%
n  = 16384;
fs = 8000;                  % Abtastrate
fb = 3;                     % mittlere Bndelfrequenz
fp = 10;                    % mittlere Impulsfrequenz im Bndel
bl = 0.05*fs;               % mittlere Bndellnge
s  = zeros(1,n);            % Null-Signal
tb = ceil(n*(rand(1,round(n*fb/fs)))); % Zeitpunkte fr Bndel
tp = [];
for k = 1:length(tb) tp = [tp,tb(k)+ceil((2*bl*rand)*rand(1,round(n*fp/fs)))]; end
s(tp(find(tp<=n))) = 1;     % Impulse
sound(s,fs)
%
%% bung 2.1.2  Das Nutzsignal sei eine Sinusschwingung der Amplitude 1.0 
%% und dieses sei gestrt durch regelmssige Impulse der Frequenz  {\fontname{Courier}fp = 0.001*fs}  
%% und der Amplitude 10.  Wie gross ist das SNR (in dB)?
%
%
% Impulsformen:
%
% Bislang wurden nur Einheitsimpulse angenommen.  Natrlich kann die Amplitude zufllig 
% sein.  Mglich sind auch bestimmte Impulsformen.  Diese lassen sich generieren durch 
% Faltung der oben jeweils in dem Samplevektor  {\fontname{Courier}s}  erzeugten Impulsfolgen mit der 
% Impulsantwort eines entsprechenden Filters:
%
[b,a] = butter(5,0.3);
h2 = fullscreen('Impulsantwort'); impz(b,a)
%
%% Klicken Sie nun zunchst oben auf das gewnschte Impulsmuster, um den 
%% Samplevektor  {\fontname{Courier}s}  zu erzeugen und anschliessend hier zur Faltung mit 
%% der Impulsantwort:
%
ss = filter(b,a,s);
sound(ss,fs)
%
%
