%
%
%2.3 Frequenzabhngige Eigenschaften%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-8,'Color',MSVTITLCOLOR>
%
%
%
% Kanle sind nie im gesamten Spektrum nutzbar.  Es gibt immer eine obere Frequenzgrenze. 
% Diese wird durch Dmpfung des bertragungsmediums oder andere Eigenschaften bestimmt. 
% Dadurch ergibt sich ein Amplitudenfrequenzgang  {\fontname{Courier}A(\omega)}  des Systems, der oberhalb einer 
% gewissen Frequenz zu klein wird gegenber Strungen.
%
% Ausser dem Amplitudenfrequenzgang ist der Phasenfrequenzgang bei digitaler bertragung 
% eine wichtige Grsse.  Da jedoch das menschliche Gehr fr Phasenverschiebungen 
% unempfindlich ist, spielt der Phasengang bei analoger bertragung keine Rolle.  Fr analoge 
% bertragung entworfene Kanle sind deshalb nicht problemlos fr digitale bertragung geeignet.
%
% Der Phasenfrequenzgang ist gegeben durch  
% {\fontname{Courier}P(\omega) = angle(C(j\omega))}  ,  wo   {\fontname{Courier}angle(a) = arctan(real(a)/imag(a))}.
%
% Fhrt man mit beliebigen Fahrzeug beginnend zur Zeit  {\fontname{Courier}t_0 = 0} , so kann man zur Zeit  {\fontname{Courier}t}  zwei 
% Geschwindigkeiten unterscheiden:  die bis  {\fontname{Courier}t}  gemittelte Durchschnittsgeschwindigkeit und die zur 
% Zeit  {\fontname{Courier}t}  momentane Geschwindigkeit.  Entsprechendes definiert man mit dem Phasenfrequenzgang:
%
% Die Phasenlaufzeit ist  {\fontname{Courier}\tau_P = - P(\omega)/\omega}     (durchschnittlich)
%
% Die Gruppenlaufzeit ist  {\fontname{Courier}\tau_G = - d P(\omega)/d\omega}  (punktuell bei \omega)
%
% Bei linearem Phasengang sind die beiden Grssen natrlich gleich.  Sind die Laufzeiten 
% verschieden, der Phasengang also nichtlinear, so verzerrt das System die Signalformen.
%
% Ein sehr einfaches Modell eines Fernsprechkanals liefert die folgende Funktion:
%
fernsprechkanal;
%
% Dieser Kanal ist fr analoge Sprachbertragung entworfen und dafr vllig ausreichend:
%
%% Hier hren wir ein Sprachsignal vor und anschliessend nach Passieren des Fernsprechkanals:
load 'sprache.mat';          % ldt ein Sample auf die Variable x
sound(x/max(abs(x)),8000); pause(1)
[b,a] = fernsprechkanal;     % Kanalmodell
y = filter(b,a,x);           % Signal nach Kanal
sound(y/max(abs(y)),8000)
%
% Bei der digitalen bertragung im Basisband stren die Verzerrungen jedoch erheblich:
%
[b,a,fs] = fernsprechkanal;  % Kanalmodell
r = 1000;                    % Baudrate [Symbole/Sekunde]
k = round(fs/r);             % Anzahl Samples pro Symbol
x = nfach([0 1 0 0 0],k);    % ein Rechtecksignal
y = filter(b,a,x);           % nach dem Kanal
fh= fullscreen('Digital'); 
plot(1000*(0:5*k-1)/fs,[x;y]')
xlabel('Zeit [Millisekunden]','FontSize',12)
axis([0 1000*(5*k-1)/fs -1.1 +1.1])
legend('Original','nach Passieren des Kanals')
set(gcf,'UserData',{zeros(1,8); 1.2*ones(1,8); {}},'KeyPressFcn','hervorhebung');
%
% Schaltet man dagegen mit dem Rechtecksignal ein Sinussignal, den sog. Trger, 
% so sind die Verzerrungen vergleichsweise gering.  Dies ist einer der Grnde fr 
% die Benutzung von modulierten Tnen zur bertragung ber das Fernsprechnetz:
%
[b,a,fs] = fernsprechkanal;  % Kanalmodell
r = 300;                     % Baudrate [Symbole/Sekunde]
k = round(fs/r);             % Anzahl Samples pro Symbol
f = 1500;                    % Trgerfrequenz in Hz
s = nfach([0 1 0 0 0],k);    % ein Rechtecksignal
t = ((1:length(s))-1)/fs;    % Zeitbereich
x = s.*sin(2*pi*f*t);        % mit Rechteck geschalteter Sinus
y = filter(b,a,x);           % nach dem Kanal
fh= fullscreen('Digital'); 
plot(1000*t,[x;y]')
xlabel('Zeit [Millisekunden]','FontSize',12)
axis([0 1000*t(length(t)) -1.1 +1.1])
legend('Original','nach Passieren des Kanals')
set(gcf,'UserData',{zeros(1,8); 1.2*ones(1,8); {}},'KeyPressFcn','hervorhebung');
%% Mit den Zifferntasten 1 und 2 lassen sich die beiden Linien hervorheben.
%
%
%% bung 2.3  In welchem Bereich darf die Trgerfreuenz liegen, ohne dass gravierende 
%% Verzerrungen auftreten?  Selektieren Sie das oben stehende MATLAB-Skript und tippen 
%% Sie dann den Buchstaben c , um das Skript in den Editor zu holen.  Dort kann es 
%% nach beliebiger nderung unter Tools/run gestartet werden.
%
% Die Kanaleigenschaften sind bei Kupferkabeln und Glasfasern zeitunabhngig. 
% Bei Funkkanlen gibt es u.U. sehr starke Zeitabhngigkeiten.  Bei interkontinentalen 
% Kurzwellenkanlen bestimmt z.B. der lngs des Weges unterschiedliche Sonnenstand 
% jeweils die lokale bei tieferen Frequenzen zunehmende Dmpfung und andererseits 
% die lokal oberste nutzbare Frequenz.  Dadurch ist meist, wenn berhaupt, nur ein 
% schmales Frequenzfenster offen, welches sich permanent im Bereich von ca. 
% 5 MHz ... 25 MHz verschiebt.
%
