%
%
%2.4  Fading%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
% Unter Fading werden mehr oder weniger regelmssige Amplitudenschwankungen verstanden. 
% Diese beruhen nicht auf Dmpfungserscheinungen sondern meistens auf der Interferenz 
% mehrerer Ausbreitungswege.  Gibt es z.B. zwischen Sender und Empfnger zwei Wege mit 
% gleicher Dmpfung, so addieren sich die beiden Wellen am Empfangsort.  Unterscheiden 
% sich die Weglngen gerade um eine halbe Wellenlnge oder um ungerade Vielfache davon, 
% so lschen sich beide Komponenten aus.  Zu einer Verdopplung der Amplitude kommt es 
% dagegen, wenn die Weglngen sich um Vielfache der ganzen Wellenlnge unterscheiden. 
% Neben den Amplitudenschwankungen ist das durch Mehrwegeausbreitung entstehende Fading 
% charakterisiert durch eine nur als Zufallsprozess bekannte Phase.
%
% Im Falle unvernderlicher Wege bleibt auch die Amplitude am Empfangsort unverndert. 
% Es gibt dann jedoch ein Fading im Frequenzbereich, denn die Wellenlnge ist  {\fontname{Courier}\lambda = c/f } , 
% wo  {\fontname{Courier}c}  die Lichtgeschwindigkeit und  {\fontname{Courier}f}  die Frequenz ist.
%
% Den Fall zweier Wege  {\fontname{Courier}s_1}  und  {\fontname{Courier}s_2}  mit gleicher Dmpfung kann man leicht formal behandeln:
%
% Am Empfangsort addieren sich zwei Schwingungen:
%
% s(f,t) = cos(2\pif(t - s_1/c)) + cos(2\pif(t - s_2/c))           %<'FontName',MSVFORMFONT>
%
%        = cos(2\pif(t - (s_1+s_2)/(2c)))*2*cos(2\pif(s_1-s_2)/c)  %<'FontName',MSVFORMFONT>
%
%          ---- Schwingung in t ----  ---- Amplitude ----          %<'FontName',MSVFORMFONT>
%
% Offenbar ist die Amplitude von  {\fontname{Courier}f}  abhngig.  Es ist blich, nur positive Amplituden 
% zuzulassen und das Vorzeichen als Phasendrehung um  {\fontname{Courier}\pi}  in der eigentlichen Schwingung zu 
% bercksichtigen.  Damit ergibt sich der Amplitudengang zu 
%
%         a(f) = 2*abs(cos(2\pif(s_1-s_2)/c))  %<'FontName',MSVFORMFONT>
%
% Ein Beispiel fr Zweiwegeausbreitung bei 900 MHz (Handy):
%
f  = 900000000:1000:910000000;   % Frequenzbereich [MHz]
s1 = 1000;        % Weg 1 [m]
s2 = 1200;        % Weg 2 [m]
c  = 299792458;   % Lichtgeschwindigkeit [m/s]
a  = 2*abs(cos(2*pi*f*(s1-s2)/c));
fh = fullscreen('Frequenzfading');
plot(f,a); axis([min(f) max(f) 0 2.2])
title('Fading im Frequenzbereich','FontSize',13)
xlabel('Frequenz','FontSize',13)
ylabel('Amplitude','FontSize',13)
%
% Das folgende Diagramm zeigt die Lage der Minima fr den Kurzwellenbereich ber der 
% Wegdifferenz bei Zweiwegeausbreitung.
%
zweiweg
%
% Wenn die Weglngen sich in der Zeit ndern, so gibt es das typische Fading im 
% Zeitbereich.  Die Funktion mehrweg simuliert  {\fontname{Courier}m}  Wege, die sich mit zuflligen 
% Geschwindigkeiten der Standardabweichung  {\fontname{Courier}sv}  ndern:
%
% Ein typisches Beispiel mit 5 Wegen:
%%  (dieses mehrfach aufrufen!)
mehrweg;
%
% Mit dem letzten Parameter der Funktion mehrweg kann man den Phasengang sichtbar machen:
%
mehrweg(10000000,5,1000000,1);
%
%% Dieses Bild ist ein 3D-Bild, das mit der Maus gedreht werden kann, aber erst wenn 
%% sich das Bild nach der Animation neu aufgebaut hat (bei selektiertem Bild h tippen fr Hilfe).
%
% Sehr viele schnell vernderliche Wege fhren zu komplexem Fading:
mehrweg(10000000,50,10000000,1);
%
% Bei Mobilfunk mit fahrendem Fahrzeug ist dieses Fading realistisch.  Im Falle 
% analoger Technik (AM oder FM) tritt das Fadingerusch direkt als Strsignal auf.  
% Digitale Verfahren versuchen das Fading durch Fehlerkorrektur auszugleichen.
%
% Das Fading wurde oben einmal im Frequenzbereich dargestellt  {\fontname{Courier}(zweiweg)}  und danach 
% fr vernderliche Wege im Zeitbereich  {\fontname{Courier}(mehrweg)} .  Die Amplitude ist tatschlich 
% eine Funktion von Zeit und Frequenz.  Man nennt ihre Darstellung ber der 
% Zeit-Frequenz-Ebene das Fadingdiagramm.  Einfache, aber typische Situationen zeigt 
% das folgende Bild, das mehrfach aufgerufen werden sollte, um die Palette der 
% Mglichkeiten zu erfassen:
%
fadingsim(14000000,14060000,60,6,1,100000);
%
% Die Parameter sind im Kopf der Funktion selbst erlutert.  Benutzt werden fr die 
% obige Simulation:
% Frequenzbereich:        14000000...14060000 Hz   %<'FontName',MSVFORMFONT>
% Zeitbereich fr die Darstellung:         60 s    %<'FontName',MSVFORMFONT>
% Anzahl der Wege:                          6      %<'FontName',MSVFORMFONT>
% Standardabweichung der Wegnderungen:     1 m/s  %<'FontName',MSVFORMFONT>
% Standardabweichung der Weglngen:    100000 m    %<'FontName',MSVFORMFONT>
%
% Die Art der Granularitt dieses Diagramms bestimmt wesentlich die Modulationsart 
% und die Datensicherung.  Im Beispiel ist das Fading langsam mit nderungen im 
% Bereich von mehreren Sekunden.  Dies liegt an der geringen nderung der Wege in 
% der Grssenordnung von  {\fontname{Courier}1 m/s} .  Schnellere nderungen der Weglngen und noch 
% grssere Wegdifferenzen fhren zu feiner granulierten Fadingdiagrammen:
%
%% (der Zeitbereich ist hier nur noch 10 Sekunden!)
fadingsim(14000000,14060000,10,6,10,1000000);
%
% Beim Mobilfunk fhrt die hohe Fahrzeuggeschwindigkeit im Zusammenhang mit der hohen 
% Frequenz zu sehr feiner Granulation:
%
%% (der Zeitbereich ist hier nur noch 100 Millisekunden!)
fadingsim(900000000,901000000,0.1,10,30,500);
%
% Ordentlicher Empfang ist offensichtlich nur in Perioden von maximal 3 Millisekunden 
% mglich.
%
% Bezahlen muss man bei der Benutzung von Funkstrecken fr die in Anspruch genommene 
% Flche im Fadingdiagramm, nmlich Bandbreite mal Zeit der Benutzung.  Bei den derzeit 
% gltigen Preisen etwa fr UMTS-Frequenzbereiche ist es von grsster Wichtigkeit, 
% diese Flche optimal zu nutzen.  Dies ist das Thema des gesamten Kurses.  
% Etwas vorgreifen soll die folgende bungsaufgabe:
%
%% bung 2.4   Es sind ber einen Kurzwellenkanal kodierte Wrter von 256 Bits zu 
%% bertragen.  Pro Bit soll die Flche  {\fontname{Courier}10 ms * 100 Hz}  belegt werden. 
%% Es ist anhand der mit dem nachfolgenden Aufruf erzeugten Simulationsbilder abzuschtzen, 
%% ob das Wort insgesamt die Form  {\fontname{Courier}10 ms * 25.6 kHz}  oder besser  {\fontname{Courier}2.56 s * 100 Hz}  haben sollte. 
%% Es wird dabei angenommen, dass jedes Wort, welches einen schwarzen Bereich anschneidet, 
%% wiederholt werden muss.
%
fadingsim(14000000,14025600,10,3,2,100000);
%
