%
%
%4.1  Inkohrente AM-Demodulation%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-6,'Color',MSVTITLCOLOR>
%
%
%
% Demodulation von AM bedeutet die Rckgewinnung der Amplitude aus dem modulierten 
% Signal.  Analoge Demodulatoren ermitteln die Spitzenwerte jeder Schwingung und 
% schicken dieses mit der Trgerfrequenz abgetastete PCM-Signal durch ein Tiefpassfilter, 
% welches die Trgerfrequenz und hhere Anteile sperrt.  Auch ein digitaler Demodulator 
% kann diesen Weg beschreiten.  Wo aber digitale Demodulatoren eingesetzt werden, 
% werden fast immer auch digitale Daten bertragen.  Dabei ist es, wie sich im 
% Kapitel 5 zeigen wird, von grossen Vorteil, alle Signale analytisch zu fhren.  
% Wir gehen deshalb jetzt davon aus, dass das modulierte Signal schon als analytisches 
% vorliegt, d.h. in Form zweier Signale, nmlich fr den Realteil und den Imaginrteil.
%
% Die folgende Animation zeigt ein analytisches AM-Signal in der komplexen Ebene:
%
n  = 16000;                     % Anzahl Samples
fs = 8000;                      % Abtastrate
t  = (0:n-1)/fs;                % diskreter Zeitbereich
s0 = sin(2*pi*440*t);           % Trgerschwingung reell
s1 = 0.4*sin(2*pi*3*t);         % Basisbandsignal reell
x  = (0.5 + s1).*s0;            % AM reell
sound(x,fs);                    % Audioausgabe
xa = real2analyt(x,30);         % AM analytisch
komplexanimat(xa(1:6000),[1 0 0 0 0 0],999,[90 0])
ca = gca;
%% Nach dem Ende der Animation verschwindet das Bild kurz und baut sich wieder auf.  
%% Erst danach fortfahren!  Die Blickrichtung kann mit den folgenden Skripten 
%% gewhlt werden.
%
% Realteil:
set(ca,'View',[0 90])
%
% Imaginrteil:
set(ca,'View',[0 0])
%
% Komplexe Ebene:
set(ca,'View',[90 0])
%
% Die Amplitude ist beim analytischen Signal zu jedem Zeitpunkt durch den Betrag 
% der kompexen Zahl gegeben.  Die Demodulation erfolgt also einfach durch 
% Betragsbildung und Subtraktion des Offsets von  {\fontname{Courier}0.5} :
%
y  = abs(xa) - 0.5;
fh = fullscreen('AM-Demod'); 
subplot(3,1,1); plot(t,real(s1)); title('Basisbandsignal')
subplot(3,1,2); plot(t,real(x));  title('AM-Signal')
subplot(3,1,3); plot(t,y);        title('demoduliertes Signal')
%
%
% Die folgenden drei Skripte geben Aussteuerungsbeispiele.
%
% Vollausgesteuert:
amplmod(50,'0.7*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)',1);
%
% Halbausgesteuert: 
amplmod(50,'0.7*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)',0.5);
%
% bersteuert:
amplmod(50,'0.7*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)',1.5);
%
% Im Fall der bersteuerung (sog. bermodulation) kann der Hllkurven-Demodulator 
% das Signal nicht korrekt rekonstruieren.
%
% Im allgemeinen wird die AM technisch in der Form
%
%          x(t) = abs(1 + s(t))*sin(2*\pi*f_0*t + p),  %<'FontName',MSVFORMFONT>
%
% erzeugt und gesendet.  Am Resultat des Hllkurvendemodulators ndert sich dadurch 
% nichts.  Die Funktion  {\fontname{Courier}abs}  ist jedoch im Falle von Nulldurchgngen nichtlinear.
% Dadurch wird das ausgesendete Spektrum bei bermodulation sehr breit.
%
% Der oben besprochene einfache Algorithmus zur Demodulation der AM ist ein 
% inkohrentes Verfahren.  Er bentigt keinerlei przise Parameter des Senders. 
% Dadurch ist er robust gegen Fehlschtzung der Trgerfrequenz.  Im Falle von 
% Frequenz-selektivem Fading ist allerdings die Trgerschwingung dem Fading 
% ausgesetzt.  Das fhrt zu katastrophalen Verzerrungen.  Diese lassen sich 
% vermeiden durch kohrente Demodulation. 
%
% Wir simulieren die Verzerrungen durch einen Nulldurchgang der Trgeramplitude. 
% Diesen erzeugen wir durch Subtraktion eines Trgers mit entsprechendem Fading. 
% Es wird ein konstanter Ton von {\fontname{Courier}440 Hz} auf einen Trger von  {\fontname{Courier}3000 Hz} 
% moduliert.  Zunchst erklingt der inkohrent demodulierte Ton ohne simuliertes 
% Trger-Fading, danach mit Fading.
%
n  = 16000;                     % Anzahl Samples
fs = 8000;                      % Abtastrate
t  = (0:n-1)/fs;                % diskreter Zeitbereich
s0 = sin(2*pi*3000*t);          % Trgerschwingung 
s1 = 0.4*sin(2*pi*440*t);       % Basisbandsignal
x  = (0.5 + s1).*s0;            % AM 
xa = real2analyt(x,30);         % AM analytisch
y  = abs(xa) - 0.5;             % Demodulation
sound(y,fs); pause(2)           % Audioausgabe ohne Fading
xf = x - s0.*(1:n)/n;           % AM mit Trger-Fading
xb = real2analyt(xf,30);        % AM analytisch
z  = abs(xb) - 0.5;             % Demodulation
sound(z,fs); pause(2)           % Audioausgabe mit Fading
%
% Das Frequenz-selektive Fading ist typisch fr Mehrwege-Ausbreitung, das zeitlich 
% vernderliche Fading beruht auf der Bewegung von Sender oder Empfnger oder 
% Streuzentren.
%