%
%
%4.3  PM-Demodulation%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
% Prinzipiell lsst sich die (analytische) Phasenmodulation 
%
%      x(t) = exp(i(2\pif_0t + s(t)*p))     %<'FontName',MSVFORMFONT>
%
% direkt umkehren nach
%
%      s(t) = -(2\pif_0t + i*ln(x(t)))/p  %<'FontName',MSVFORMFONT>
%
% Einen FM-Demodulator erhlt man durch nachfolgende zeitliche Ableitung.
%
%
% Wir besprechen hier eine der Realisierung nhere Variante.  Um die momentane Phase 
% des Modulationssignals bestimmen zu knnen, ist die Kenntnis der Trgerphase 
% erforderlich.  Die Demodulation der Phasenmodulation ist also kohrent.  Wie bei der 
% kohrenten Demodulation der AM gehen wir aus vom analytischen Modulationssignal. 
% Durch Multiplikation mit dem konjugiert komplexen des als bekannt vorausgesetzten 
% analytischen Trgersignals wird das Modulationssignal ins Basisband verschoben. 
% Die Phase dieses Signals ist das demodulierte Signal:
%
% analytisches PM-Signal:   exp(i(2\pif_0t + s(t)*p))  %<'FontName',MSVFORMFONT>
% Trger konjugiert:        exp(-i2\pif_0t)            %<'FontName',MSVFORMFONT>
% Produkt:                  exp(i s(t)*p)              %<'FontName',MSVFORMFONT>
%
f0 = 50;  fs = 512;           % Trgerfrequenz und Abtastfrequenz
x  = phasenmod(f0);           % ein PM-Testsignal reell
xa = real2analyt(x);          % PM-Testsignal analytisch
ya = xa.*exp(-i*2*pi*f0*(0:length(xa)-1)/fs); % ins Basisband
s  = unwrap(angle(ya(17:length(ya))));        % Demodulation
s  = s - pi*round(mean(s)/pi);% in Bereich -pi ... + pi bringen    
fh = fullscreen('PM-Demod'); plot(s)          % Darstellung
%
% Der Vergleich mit dem korrekten Signal zeigt, dass die Demodulation korrekt ist:
%
phasenmod(f0);
%
% Einige Versuche zur Phasenmodulation:
%
% Phasenhub =  \pm\pi  bei Signalamplitude  \pm1  %<'FontName',MSVFORMFONT> 
phasenmod(50,'0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)',pi,50);
%
% Ein guter Demodulator lst die Mehrdeutigkeiten (hier rotiert die Phase zwischen  {\fontname{Courier}-8\pi}  und  {\fontname{Courier}+8\pi}):
phasenmod(100,'sin(2*pi*3*t)',8*pi);
%
% Phasenhub =  \pm22  leichte bersteuerung       %<'FontName',MSVFORMFONT>
phasenmod(50,'0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)',22,50);
%
% Phasenhub =  \pm31  starke bersteuerung        %<'FontName',MSVFORMFONT>
phasenmod(50,'0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)',31,50);
%
% Falsche Frequenz                                %<'FontName',MSVFORMFONT>
phasenmod(50,'0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)',pi,50.5);
%
% Falsche Frequenz                                %<'FontName',MSVFORMFONT>
phasenmod(50,'0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)',pi,49.5);
%
