%
%
%4.4  FM-Demodulation%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
% Die Demodulation von FM kann nach sehr unterschiedlichen Prinzipien erfolgen.
%
% Analoge Demodulatoren beseitigen meistens zunchst jeglichen AM-Anteil.  Dann 
% wird die FM durch Differenzieren in eine AM-FM-Kombination gewandelt und 
% die AM inkohrent demoduliert. 
%
% Bisweilen wird auch eine PLL auf dem FM-Signal synchronisiert.  Das zur Regelung 
% des Oszillators gewonnene Signal ist dann das demodulierte Signal.  Dies wird im 
% Abschnitt 7.2 diskutiert.  Wir betrachten hier nur den direkten Weg genauer:
%
% Zur Demodulation von FM ist die momentane Frequenz zu bestimmen.  Liegt 
% das modulierte Signal in analytischer und zeitdiskreter Form vor, so ist die 
% Momentanfrequenz proportional zur Winkelgeschwindigkeit des modulierten Signals 
% in der komplexen Ebene, also proportional zum Winkelabstand der jeweils benachbarten 
% Samples.  Hiervon ist der der Trgerfrequenz entsprechende Winkelabstand zu 
% subtrahieren.  Daraus ergibt sich folgender Demodulator:
%
f0 = 50;                           % Trgerfrequenz in Hz
x  = freqmod(f0); fs = 512;        % ein FM-Testsignal mit fs = 512 Hz
xa = real2analyt(x);               % FM-Testsignal analytisch
ph = unwrap(angle(xa));            % Winkel ohne 2*pi-Sprnge
s  = diff(ph) - 2*pi*f0/fs;        % Winkelgeschwindigkeit
fh = fullscreen('FM-Demod');  
plot(s); line([0 length(x)],[ 0 0],'Color','k') % Darstellung des demodulierten Signals
%
% Das Bild enthlt einen Einschwingvorgang, der durch die Verzgerung des 
% Hilberttransformators  (hier 15 Abtastschritte)  und durch die Differenzenbildung 
% verursacht wird. 
%
% Das tatschlich gesendete Signal ist in folgendem Bild gegeben:
%
freqmod(f0);
%
% Ist die Trgerfrequenz nur ungenau bekannt, so fhrt dies zu einem konstanten 
% Versatz des dekodierten Signals.  Bei Sprache und Musik spielt das keine Rolle, 
% da wegen der unteren Hrschwelle von ca. 20 Hz mit einem entsprechenden Hochpass 
% der konstante Anteil entfernt werden kann.
%
% Hier ein Versuch mit   {\fontname{Courier}f_0 = 50}   beim Modulieren und   {\fontname{Courier}f_1 = 58}   beim Demodulieren:
%
x  = freqmod(50); fs = 512;        % ein FM-Testsignal mit fs = 512 Hz
xa = real2analyt(x);               % FM-Testsignal analytisch
ph = unwrap(angle(xa));            % Winkel ohne 2*pi-Sprnge
s  = diff(ph) - 2*pi*58/fs;        % Winkelgeschwindigkeit
fh = fullscreen('FM-Demod');  
plot(s); line([0 length(x)],[ 0 0],'Color','k') % Darstellung des demodulierten Signals
%
% Die Funktion  {\fontname{Courier}freqmod}  benutzt intern einen von Kammeyer vorgeschlagenen digitalen 
% FM-Demodulator.  Nachfolgend noch einige Beispiele:
%
% {\fontname{Courier}Frequenz falsch}
freqmod(50,'0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)',0.03,40);
%
% {\fontname{Courier}Frequenz falsch}
freqmod(50,'0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)',0.03,60);
%
% {\fontname{Courier}Hub falsch}
freqmod(50,'0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)',0.03,50,0.2);
%
% {\fontname{Courier}Maximaler Hub}
freqmod(50,'0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)',0.05);
%
%% Bild stehen lassen und mit folgendem durch hin- und herklicken vergleichen.
%
% {\fontname{Courier}Sehr kleiner Hub}
freqmod(50,'0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)',0.005);
%
% {\fontname{Courier}bersteuerung}
freqmod(50,'0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)',0.8);
%
% Die Frequenzmodulation ist wegen der Unntigkeit einer genauen Trgersynchronisation 
% einerseits und wegen der guten Unterdrckung von Amplitudenstrungen andererseits 
% eine sehr robuste Modulationsart.
%
%% bung 4.4  Untersuchen Sie die bersteuerung der FM mit der zuerst genannten direkten 
%% Demodulation.  Vergrssern Sie dazu schrittweise den Modulationsindex in folgendem Script. 
%% Was fhrt zu der Verzerrung im demodulierten Signal ?
%%
m  = 0.1;                          % Modulationsindex
freqmod(50,'2*(t>0.5)-1',m);       % Signaldarstellung: die Sprungfunktion 
x  = freqmod(50,'2*(t>0.5)-1',m);  % zur Berechnung des Sendesignals
fs = 512;                          % Abtastfrequenz
xa = real2analyt(x);               % FM-Testsignal analytisch
ph = unwrap(angle(xa));            % Winkel ohne 2*pi-Sprnge
s  = diff(ph) - 2*pi*58/fs;        % Winkelgeschwindigkeit
fh = fullscreen('FM-Demod');  
plot(s); line([0 length(x)],[ 0 0],'Color','k') % Darstellung des demodulierten Signals
%%
%% Lsung:
%%
lsg_4_4
%