%
%
%5.  Grundbegriffe der Digitalen bertragung%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-12,'Color',MSVTITLCOLOR>
%
%
%
% Dieses Kapitel soll die wesentlichen Begriffe der digitalen Datenbertragung 
% einfhren und einen berbick bringen ber Probleme und Lsungsmethoden.  Die 
% genauere Diskussion der einzelnen Themen ist den nachfolgenden Kapiteln vorbehalten.
%
%
% \bfDigitale vs. analoge bertragung
%
% In den vorigen Kapiteln wurden Zeit-kontinuierliche nicht quantisierte Signale  {\fontname{Courier}s(t)}  
% im Basisband oder moduliert bertragen.  Unter digitaler bertragung verstehen wir 
% die bertragung diskreter Information mithilfe einer quantisierten Reprsentation, 
% die die Rekonstruktion der diskreten Information auch unter Strungen in spezifiziertem 
% Rahmen ermglicht.  Es geht also darum, endlich viele analoge, im Zeit- und Frequenz-
% bereich beschrnkte Signale als Reprsentationen fr zu bertragende Symbole 
% auszuwhlen. 
%
% \bfSymbole
%
% Zunchst betrachten wir die sequentielle bertragung von Symbolen einer Symbolmenge  {\fontname{Courier}S} . 
% Im einfachsten Fall ist  {\fontname{Courier}S}  die binre Menge, z.B. mit den Symbolen  {\fontname{Courier}S = {-1, +1}}. 
%
% \bfStufigkeit
%
% Die Anzahl der Symbole in  {\fontname{Courier}S}  nennt man die Stufigkeit der Reprsentation.
%
% \bfSchrittfrequenz, Baudrate
%
% Die Anzahl der pro Zeiteinheit gesendeten Symbole heisst Schrittfrequenz.
% Man nennt sie auch Baudrate.  Die Einheit ist
%
%         Bd = Baud = Symbole / Sekunde  %<'FontName',MSVFORMFONT>
%
% Das folgende Bild zeigt eine Sequenz von  {\fontname{Courier}n = 32}  Symbolen, die insgesamt 
% in  {\fontname{Courier}t_{ges} = 3.333 ms}  durchlaufen wird:
%
fh = fullscreen('2-stufig');
n  = 32;                     % Anzahl der gezeigten Symbole
T  = 50;                     % Lnge der Symbole in Abtastschritten
plot(nfach(randb(n,[-1 +1]),T));
line([0 n*T],[0 0],'Color',0.7*[1 1 1],'LineStyle',':')
line(T*[1 1]'*(1:n),0.1*[-1 +1]'*ones(1,n),'Color','k','LineWidth',2)
set(gca,'YLim',5*[-1 1]); axis off
drawarr([T*n/3 -3],[T*(n/3+9.6) -3],'k',2,T/2)
text(T*(n/3+4),-2.8,'Zeit','Fontsize',13)
text(T*(n/3+0.2),-3.2,'(Pfeillnge = 1 Millisekunde)','Fontsize',12,'Color',0.5*[1 1 1])
line(T*[1 1]'*(1:5),[0.1 +2]'*ones(1,5),'Color','m','LineWidth',2)
text(T*1,2.2,'Symboltakt','Fontsize',13,'Color','m')
line(T*[1 1]'*(15:16),[0.1 +2]'*ones(1,2),'Color','r','LineWidth',2)
drawarr([T*15.5 1.9],[T*15 1.9],'r',2,T/3) 
drawarr([T*15.5 1.9],[T*16 1.9],'r',2,T/3) 
text(T*14.3,2.2,'Schritt','Fontsize',13,'Color','r')
line(T*[-1 -1; 1 1]-2*T,[-1 +1; -1 +1],'Color','g','LineWidth',2)
text(-3.2*T,2.2,'Stufen','Fontsize',13,'Color','g')
%
% Die Stufigkeit ist offensichtlich  {\fontname{Courier}2} .  Die Schrittfrequenz ist  {\fontname{Courier}n/t_{ges} = 9600 Baud}.
%
% Zur korrekten Interpretation am Empfangsort ist die Kenntnis des Schritt-Taktes 
% erforderlich.  Man unterscheidet zwei Verfahren:
%
% {\bfSynchrone bertragung}:   der Schritt-Takt ist genau bekannt, z.B. durch parallele
% bertragung des Taktes oder durch geeignete Wahl der Symbolreprsentation.
%
% {\bfAsynchrone bertragung}:  die Schrittfrequenz ist mit einer gewissen Toleranz bekannt, 
% aber nicht die Phase.  Die Phase wird durch eine erste Flanke festgelegt.  Der Empfnger
% besitzt also eine Uhr, die zur seriellen bertragung mehrerer Symbole zunchst mit dem 
% ersten Symbol gestellt werden muss.
%
% Beide Verfahren werden im Kapitel 8 ausfhrlich behandelt.
%
% \bfDatenentscheidung
%
% Typisch fr die Datenbertragung ist die Reprsentation durch zeitkontinuierliche 
% analoge Signale.  Der Interpretationsschritt auf der Empfngerseite vom durch die 
% Schrittsynchronisation schon zeitdiskreten analogen Signal zur digitalen Reprsentation 
% heisst Datenentscheidung.  Diese Datenentscheidung kann im Fall eines gestrten Kanals 
% ein anderes als das gesendete Datum liefern.  
%
% \bfbertragungsgeschwindigkeit
%
% Die bertragungsgeschwindigkeit wird in  {\fontname{Courier}Bit/Sekunde}  gemessen.  Im Falle zweistufiger 
% bertragung ist sie dem Betrage nach gleich der Baudrate.  Bei  {\fontname{Courier}m-}stufiger bertragung 
% werden pro Symbol jedoch  {\fontname{Courier}log2(m)} Bits bertragen, so dass gilt:
%
%       bertragungsgeschwindigkeit = Baudrate * Bits / Symbol  %<'FontName',MSVFORMFONT>
%
% Ein Beispiel fr vierstufige Symbole zeigt das folgende Bild:
%
m  = 4;                      % Stufigkeit
n  = 32;                     % Anzahl der gezeigten Symbole
T  = 50;                     % Lnge der Symbole in Abtastschritten
fh2 = fullscreen(sprintf('%2d-stufig',m));
plot(nfach(randx(n,2*((1:m)-(1+m)/2)/(m-1)),T));
line([0 n*T],[0 0],'Color',0.7*[1 1 1],'LineStyle',':')
line(T*[1 1]'*(1:n),0.1*[-1 +1]'*ones(1,n),'Color','k','LineWidth',2)
set(gca,'YLim',5*[-1 1]); axis off
drawarr([T*n/3 -3],[T*(n/3+9.6) -3],'k',2,T/2)
text(T*(n/3+4),-2.8,'Zeit','Fontsize',13)
text(T*(n/3+0.2),-3.2,'(Pfeillnge = 1 Millisekunde)','Fontsize',12,'Color',0.5*[1 1 1])
line(T*[1 1]'*(1:5),[0.1 +2]'*ones(1,5),'Color','m','LineWidth',2)
text(T*1,2.2,'Symboltakt','Fontsize',13,'Color','m')
line(T*[1 1]'*(15:16),[0.1 +2]'*ones(1,2),'Color','r','LineWidth',2)
drawarr([T*15.5 1.9],[T*15 1.9],'r',2,T/3) 
drawarr([T*15.5 1.9],[T*16 1.9],'r',2,T/3) 
text(T*14.3,2.2,'Schritt','Fontsize',13,'Color','r')
line(T*[-1;1]*ones(1,m)-2*T,[1;1]*[2*((1:m)-(1+m)/2)/(m-1)],'Color','g','LineWidth',2)
text(-3.2*T,2.2,'Stufen','Fontsize',13,'Color','g')
%
% Als erste einfache Beispiele digitaler Modulation nehmen wir AM und FM,die dann 
% Amplitude-Shift-Keying (ASK) bzw. Frequency Shift Keying (FSK) genannt werden:
%
% {\fontname{Courier}AM}
n = 10;                         % Anzahl der gezeigten Symbole
T = 100;                        % Lnge der Symbole in Abtastschritten
s = nfach(randb(n,[-1 +1]),T);  % abgetastete Symbole
amplmod(50,s,1);
%% Wegen zuflliger Wahl der Bits mehrfach aufrufen!
%
% {\fontname{Courier}FM}
n = 10;                         % Anzahl der gezeigten Symbole
T = 100;                        % Lnge der Symbole in Abtastschritten
s = nfach(randb(n,[-1 +1]),T);  % abgetastete Symbole
freqmod(50,s,0.02);
%
% Deutlich zu sehen ist hier, dass die Modulation nur der besseren physikalischen 
% bertragung dient.  Nach der Demodulation erhlt man im Idealfall das analoge 
% Basisbandsignal zurck.  Aus diesem mssen an den korrekten Zeitpunkten durch 
% Datenentscheidung die gesendeten Symbole ermittelt werden.
%
%
%
%% bung 5.  Gegeben sei ein Kanal, der mit der Abtastrate  {\fontname{Courier}f_a = 8000 Hz}  simuliert wird.  
%% Es ist ASCII-Text zu bertragen (max. 200 Zeichen).  Es sind Empfnger in MATLAB zu 
%% realisieren fr zwei Mglichkeiten:
%%
%%  (1) Die ASCII-Zeichen werden durch 256 Stufen im Intervall  {\fontname{Courier}-1...+1}  reprsentiert. 
%%      Die Baudrate ist  {\fontname{Courier}f_b = 100 Bd}. 
%%      Die Sendung erfolgt durch
%%
fa = 8000;  fb = 100;
x1 = nfach(double('Dies ist der zu sendende Text')/128-0.5,round(fa/fb));
%%
%%  (2) Die ASCII-Zeichen werden 2-stufig als Bitstrom entsprechend hherer 
%%      Baudrate  {\fontname{Courier}f_b = 800 Bd}  bertragen. 
%%      Die Sendung erfolgt durch
%
fa = 8000;  fb = 800;
x2 = nfach(2*str2binvec('Dies ist der zu sendende Text')-1,round(fa/fb));
%%
%% Der Kanal kann gestrt werden durch (auch andere Werte fr  {\fontname{Courier}r}  probieren)
%%
sigma = 0.05;                       % Standardabweichung des Rauschens im Sample
if ~ismember('x1',who) x1 = 0; end  % x1 definieren falls noch nicht vorhanden
if ~ismember('x2',who) x2 = 0; end  % x2 definieren falls noch nicht vorhanden
r  = sigma*randn(1,max([length(x1),length(x2)])); % Rauschen simulieren
x1 = x1 + r(1:length(x1));          % Kanalrauschen addieren
x2 = x2 + r(1:length(x2));          % Kanalrauschen addieren
%%
%% Der Schritt-Takt sei beim Empfnger bekannt.  Zur Strungsminimierung werde vor 
%% der Datenentscheidung das Integral ber den jeweiligen Schritt berechnet durch
%% {\fontname{Courier}sum}  ("Vektor der Samples im Schritt")/"Anzahl der Samples pro Schritt".
%%
%% Vergleichen Sie die Ergebnisse.
%
%% Musterlsungen: (Funktionen im Editor ansehen)
lsg_5_1(8000,100,x1)  % Lsung fr Fall (1)
%
lsg_5_2(8000,800,x2)  % Lsung fr Fall (2)
%

