%
%
% 5.2. Zeit- und Frequenzbereich%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
%  Die physikalische Reprsentation der Symbole ist analog und 
%  zeitkontinuierlich. Reiht man rechteckfrmige Symbole von 
%  Schrittlnge aneinander, was man Pulscodemodulation (PCM) 
%  nennt, so ergibt sich ein sehr breites Spektrum, das Frequenz-
%  multiplex mehrerer paralleler bertragungen ber das selbe 
%  Medium ausschliesst. PCM ist deshalb nur dort einsetzbar, 
%  wo jeweils zur Zeit nur eine bertragung ber das Medium 
%  stattfinden soll. Dies gilt fr Busse in Rechnern, Ethernet 
%  und die Telefonleitung im Halbduplexbetrieb, jedoch nicht 
%  fr Funkkanle, die immer bandbegrenzt sind. 
%
%  Zur Illustration betrachten wir zunchst ein einziges Symbol 
%  im Zeitbereich und seine Fouriertransformierte im Frequenz-
%  bereich:
%
syms t f; 
D = fourierplot('-Heaviside(t-1/2)+Heaviside(t+1/2)',t,f,[-2,+2],[-100,+100])
a = get(findobj('Name','Funktion'),'children'); 
if iscell(a) set(a{1},'ylim',[-0.5,1.5]); else set(a(1),'ylim',[-0.5,1.5]); end
%
%  Und nun eine Bitsequenz: 
%
syms t f; 
D = fourierplot('-Heaviside(t-2)+Heaviside(t-1)-Heaviside(t-5)+Heaviside(t-4)-Heaviside(t-8)+Heaviside(t-6)',t,f,[0,10],[-50,50])
a = get(findobj('Name','Funktion'),'children');
if iscell(a) set(a{1},'ylim',[-0.5,1.5]); else set(a(1),'ylim',[-0.5,1.5]); end
%
%
%  Wird umgekehrt - fr Frequenzmultiplex optimal - ein 
%  rechteckfrmiges Spektrum verlangt, so ergibt sich durch 
%  inverse Fouriertransformation ein zeitlich unendlich 
%  ausgedehnter Impuls, was in jedem Fall unbrauchbar ist.
%  Um das ideale Rechteckspektrum zu approximieren, sind 
%  zeitlich lange, der sinc-Funktion hnliche Impulse notwendig.
%  Die zu benachbarten Symbolen gehrenden Impule mssen sich 
%  erheblich berlappen, um akzeptable Schrittfrequenzen zu 
%  erzielen. Das folgende Kapitel 6 ist dem Problem der Form
%  der Impulse gewidmet.
%  
%  Das selbe Problem tritt in abgeschwchter Form bei Zeit-
%  multiplexverfahren auf. Wenn mehrere Sender zeitlich
%  nacheinander das selbe Medium benutzen, so muss man ein 
%  breites Spektrum akzeptieren, also eine berlappung der 
%  benachbarten Kanle bei Frequenzmultiplex oder eine 
%  berlappung der Zeitsgnale.
%
%  Frequenzmultiplex ist nur mglich unter Einsatz geeigneter 
%  Modulationsverfahren. Am bersichtlichsten sind die Spektral-
%  verhltnisse bei den Varianten der Amplitudenmodulation 
%  (Kapitel 3). Als Beispiel nehmen wir DSB (bzw. QAM mit 
%  verschwindendem zweiten Signal). Moduliert wird der Trger 
%  der Frequenz  {\fontname{Courier}f0}  mit einem sog. Nyquistpuls  {\fontname{Courier}sin(a*t)/(a*t)} 
%
f0 = 2.5;    % Trgerfrequenz
b  = 0.4;    % Breite des Frequenzbandes
a  = pi*b;   % Pulskonstante: halbe Breite des Frequenzbandes in w 
syms  t w;   % symbolische Variable 
A = fourierplot(cos(2*pi*f0*t)*sin(a*t)/(a*t),t,w,(10/a)*[-1,1],4*pi*f0*[-1,1])
%
%  Es handelt sich um ein reelles Signal. Der Realteil der 
%  Fouriertransformierten ist deshalb eine gerade Funktion. 
%  Beim Spektrum betrachtet man nur nicht negative Frequenzen.
%
