%
%
%6.5.1.  Rechteckimpuls%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
% \bfZeitbereich
%
% Im Abschnitt 6.1 wurde der Rechteckimpuls als Summe zweier Sprungfunktionen beschrieben. 
% Dies wird mit folgendem Bild graphisch erlutert.  Die Linien wurden der Deutlichkeit 
% halber leicht gegeneinander versetzt:
%
t  = -10:0.01:10;                     % Zeitbereich der Darstellung
fh1= fullscreen('Rechteckimpuls');
plot(t,[heaviside(t+3);heaviside(t-3)+0.01;heaviside(t+3-0.1)-heaviside(t-3-0.1)-0.01]'); 
axis([t(1) t(length(t)) -0.5 1.5])
set(gcf,'UserData',{zeros(1,8); 1.2*ones(1,8); {}},'KeyPressFcn','hervorhebung');
title('Rechteckimpuls als Differenz zweier Sprungfunktionen','FontSize',13)
%
%%  Die einzelnen Graphen knnen mit den Zifferntasten 1...3 hervorgehoben werden.
%
% Die zeitliche Ausdehnung des Rechtecks ist genau ein Schritt.
%
%
% \bfFrequenzbereich
%
% Symbolisch ergibt sich die Fouriertransformierte:
%  
syms t w T;
rpuls = 'Heaviside(t+T)-Heaviside(t-T)';
P = simplify(fourier(rpuls,t,w))
%%  Resultat im Kommandofenster:  P = 2*sin(T*w)/w
%
% Eine numerische Auswertung liefert:
%
T = 1;                                % halbe Impulsbreite
W = -50:0.1:50;                       % Frequenzbereich der Darstellung
k = 0;  clear('x')
for w = W  k = k+1;  x(k) = eval(P);  end
fh2 = fullscreen('Fouriertransformierte');
plot(W,x)
%
% Aus der Fouriertransformierten ergibt sich das Spektrum durch Betragsbildung:
%
syms t w T;  rpuls = 'Heaviside(t+T)-Heaviside(t-T)';
P = simplify(fourier(rpuls,t,w));
T = 1;  W = -50:0.1:50;  k = 0;  clear('x')
for w = W  k = k+1;  x(k) = eval(P);  end
fh2 = fullscreen('Fouriertransformierte'); plot(W,abs(x))
%
% Die Ausdehnung im Spektralbereich ist unendlich.  Jede Bandbegrenzung fhrt zu einer 
% Verformung des Impulses.  Insbesondere hat eine harte Begrenzung im Spektralbereich 
% berschwingungen der Impulsform im Zeitbereich zur Folge (Gibbs-Effekt).  Die beiden 
% folgenden Bilder demonstrieren diesen Effekt am Beispiel eines periodischen Rechtecks:
%
[fh(1),fh(2)] = fourectdemo;
xlabel('Zeit','FontSize',13); ylabel('Bandbreite','FontSize',13)
for k=1:5 pause(0.2); figure(fh(1+mod(k,2))); end
%
%% Das 3D-Bild ist mit der Maus drehbar.  Beim 2D-Bild knnen die den verschiedenen 
%% Bandbreiten entsprechenden Linien mit den Zifferntasten 1...8 hervorgehoben werden.
%
% Der Gibbs-Effekt besagt, dass jede harte Beschrnkung der Bandbreite - und sei diese 
% beliebig gross, aber endlich - so gibt es im Zeitbereich grosse berschwinger an den 
% Flanken. 
%
% Die berschwinger werden vermieden durch Kosinus-Roll-Off-Flanken.  Wegen ihrer 
% Wichtigkeit werden diese in einem eigenen Abschnitt 6.5.5 behandelt.
%
% Einen Ausschnitt aus einem aktuellen Spektrum liefert das folgende Bild:
%
%% Benutzen Sie die Taste y zum Umschalten der Skalierung ln/log!
s = 20;                           % Anzahl der Abtastungen pro Schritt 
p = ones(1,s);                    % Rechteckimpuls 
impulsfolge(randx(100,[-1 +1]),p,s,1);
%
%
% \bfFrequenz-Bandbreite-Produkt
%
pl = 0.002;  % Impulsdauer 2 ms
fa = 8000;   % Abtastfrequenz 8 kHz
dt = 4*pl;   % zeitliche Auflsung der Momentanspektren 4 Schritte
p  = nfach([0 0 1 0 0],fa*pl);
zeitspecgraph(p,fa,fa*dt,1);
%
pl = 0.002;  % Impulsdauer 2 ms
fa = 8000;   % Abtastfrequenz 8 kHz
dt = 1*pl;   % zeitliche Auflsung der Momentanspektren 1 Schritt
p  = nfach([0 0 1 0 0],fa*pl);
zeitspecgraph(p,fa,fa*dt,1);
%
%
% \bfAugendiagramm
%
% Das Augendiagramm hat die maximal mgliche zeitliche ffnung eines ganzen Schrittes 
% und in dieser Breite auch den maximalen Abstand der Stufen.  Ein Fehler der 
% Schrittsynchronisation von bis zu enem halben Schritt kann deshalb toleriert werden 
% ohne Einbussen im Strabstand.  Dies gilt natrlich nur, solange das Rechteck ohne 
% irgend eine Filterung beim Empfnger ankommt.  Das folgende Bild zeigt das 
% Augendiagramm fr den Fall von zwei Stufen:
%
augendiagramm(nfach(randb(16,[-1 +1]),100),1000,10,1.3,0.5)
%
%
% \bfIntersymbolinterferenz
%
% Der Rechteckimpuls hat nur eine zeitliche Ausdehnung von genau einem Schritt. 
% Eine Intersymbolinterferenz tritt deshalb nicht auf.  Allerdings ist zu bedenken, 
% dass jede Beschrnkung der Bandbreite die Impulsform verndert und damit 
% Intersymbolinterferenz erzeugen kann.  Wir zeigen dies im folgenden Bild:
%
x = nfach(randb(100,[-1 +1]),100);  % 100 Rechtecksymbole
g = 400; b = fir1(g,0.06);          % Tiefpassfilter
y = filter(b,1,x);                  % Filterung
y = y(g+1:length(y));               % Enschwingvorgang fortwerfen
augendiagramm(y,1000,10,1.3,0.5)
%
%
% \bfZusammenfassung
%
% Zeitausdehnung:           genau 1 Schritt  %<'FontName',MSVFORMFONT>
% Spektralausdehnung:       unendlich        %<'FontName',MSVFORMFONT>
% Zeit-Bandbreite-Produkt:  gross            %<'FontName',MSVFORMFONT>
% Intersymbolinterferenz:   keine            %<'FontName',MSVFORMFONT>
% zeitliche Augenffnung:   ganzer Schritt   %<'FontName',MSVFORMFONT>
%