%
%
%6.5.3.  Gaussimpuls%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
% \bfZeitbereich
%
% Der Gauss-Impuls ist im Prinzip im Zeitbereich unendlich ausgedehnt.  Die Exponential-
% funktion konvergiert jedoch so schnell nach Null, dass der Gauss-Impuls in der Praxis 
% zeitlich beschrnkt ist auf den Bereich von  {\fontname{Courier}\pm 2}  Schritten.  Dort hat der auf die 
% Amplitude 1 normierte Impuls den Wert 
%
exp(-pi^2)          % = 5.1723e-005
%
% Der Gaussimpuls wird in folgendem Bild dargestellt: 
%
schritt = 20;       % Anzahl der Abtastungen pro Schritt
b = 3;              % das Bild soll den Bereich +- b Schritte darstellen
puls = exp(-(pi*(-b*schritt:b*schritt)/schritt/2).^2);
fh = fullscreen('Gauss-Impuls'); 
plot(2*b*((1:length(puls))-0.5)/length(puls)-b,puls)
%
%
% \bfFrequenzbereich
%
% Der Gauss-Impuls hat die einmalige Eigenschaft, dass er im Zeitbereich und im 
% Frequenzbereich dieselbe Form hat.  Dies ist leicht symbolisch zu zeigen:
%
syms t w;
p = exp(-1/2*t^2);
P = fourier(p,t,w)
%% Das Resultat steht im Kommandofenster
%
% MATLAB versagt seinen Dienst leider schon bei der einfachen Skalierung
%
%   syms t w T;             %<'FontName',MSVFORMFONT>
%   p = exp(-1/2*(t/T)^2);  %<'FontName',MSVFORMFONT>
%   P = fourier(p,t,w)      %<'FontName',MSVFORMFONT>
%
% Dies msste liefern:
%
%   P = (2\pi)^{1/2} exp(-1/2*(T\omega)^2)   %<'FontName',MSVFORMFONT>
%
% Die Symmetrie in Zeit- und Frequenzbereich hat minimales Zeit-Bandbreite-Produkt 
% zur Folge.  Der Gauss-Impuls nutzt die Zeit-Frequenz-Flche also optimal aus.
%
% Einen Ausschnitt aus einem aktuellen Spektrum liefert das folgende Bild:
%
%% Benutzen Sie die Taste y zum Umschalten der Skalierung ln/log!
b = 100;                          % halbe Breite des Fensters in Schritten
s = 20;                           % Anzahl der Abtastungen pro Schritt 
p = exp(-(pi*(-b*s:b*s)/s/2).^2); % Gauss-Funktion 
impulsfolge(randx(100,[-1 +1]),p,s,1);
%
%
% \bfFrequenz-Bandbreite-Produkt
%
pl = 0.002;      % Schrittlnge 2 ms
fa = 8000;       % Abtastfrequenz 8 kHz
dt = 4*pl;       % zeitliche Auflsung der Momentanspektren 4 Schritte
schritt = fa*pl; % Anzahl der Abtastungen pro Schritt
p  = exp(-(pi*(-2*schritt:2*schritt)/schritt/2).^2); % Gaussimpuls
zeitspecgraph(p,fa,fa*dt,1);
%
pl = 0.002;      % Schrittlnge 2 ms
fa = 8000;       % Abtastfrequenz 8 kHz
dt = 1*pl;       % zeitliche Auflsung der Momentanspektren 1 Schritt
schritt = fa*pl; % Anzahl der Abtastungen pro Schritt
p  = exp(-(pi*(-2*schritt:2*schritt)/schritt/2).^2); % Gaussimpuls
zeitspecgraph(p,fa,fa*dt,1);
%
pl = 0.002;      % Schrittlnge 2 ms
fa = 8000;       % Abtastfrequenz 8 kHz
dt = pl/2;       % zeitliche Auflsung der Momentanspektren 1/2 Schritt
schritt = fa*pl; % Anzahl der Abtastungen pro Schritt
p  = exp(-(pi*(-2*schritt:2*schritt)/schritt/2).^2); % Gaussimpuls
zeitspecgraph(p,fa,fa*dt,1);
%
%
% \bfAugendiagramm
%
% Das Augendiagramm hat zwar die optimale zeitliche ffnung, zeigt aber starke 
% Intersymbolinterferenz:
%
s = 20;                           % Anzahl der Abtastungen pro Schritt
fa= 1000;  fs = fa/s;             % Abtastfrequenz und Schrittfrequenz
y = impulsfolge(randx(50,[-1 +1]),'gauss',s);
augendiagramm(y,fa,fs,1.3)
%
%
% \bfIntersymbolinterferenz
%
% Siehe Augendiagramm.
%
%
% \bfZusammenfassung
%
% Zeitausdehnung:           theoretisch unendlich, praktisch  {\fontname{Courier}\pm 2}  Schritte  %<'FontName',MSVFORMFONT>           
% Spektralausdehnung:       wie Zeitausdehnung               %<'FontName',MSVFORMFONT>          
% Zeit-Bandbreite-Produkt:  minimal (theoretisches Minimum)  %<'FontName',MSVFORMFONT>  
% Intersymbolinterferenz:   ja                               %<'FontName',MSVFORMFONT>
% zeitliche Augenffnung:   nahezu ganzer Schritt            %<'FontName',MSVFORMFONT>  
%