%
%
%6.5.5.  Kosinus-Roll-Off-Filter%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
% \bfZeitbereich
%
% Fordert man Intersymbolinterferenzfreiheit, so muss die Impulsform Nullstellen an 
% allen Datenentscheidungspunkten besitzen ausser an einer einzigen Stelle, wo der 
% Impuls den Wert 1 haben sollte fr identische bertragung der Information.  Man 
% nennt diese Bedingung die erste Nyquist-Bedingung.  Mit dem Sinc-Impuls haben wir 
% einen Impuls kennengelernt, der diese Bedingungen erfllt. Sowohl ein beiderseitiges 
% Begrenzen wie auch ein Fenstern der Sinc-Funktion ndert an der Erfllung der ersten 
% Nyquist-Bedingung nichts, wenn das Fenster auch dort den Wert 1 hat, wo der Impuls 
% abgetastet werden soll.  Sehr gebruchlich sind Impulse der Form
%
% p(t) = sin(\pi*f_s*t)/(\pi*f_s*t) * cos(\pi*r*f_s*t)/(1 - (2*r*f_s*t)^2)  %<'FontName',MSVFORMFONT>
%
% Hierin sind  {\fontname{Courier}f_s}  die Schrittfrequenz und  {\fontname{Courier}r}  der sog. Roll-off-Faktor.   {\fontname{Courier}r}  kann gewhlt 
% werden im Bereich   {\fontname{Courier}0 \leq r \leq 1} .  Bei   {\fontname{Courier}r = 0}   ergibt sich fr  {\fontname{Courier}p}  offenbar die Sinc-Funktion. 
%
% \bfFrequenzbereich
%
% Der Sinn dieser Impulsform wird erst klar durch Transformation in den Frequenzbereich. 
% Es ergibt sich:
%
%     P(f) = 1   fr  f \leq (1-r)*f_s/2   %<'FontName',MSVFORMFONT>
%
%     P(f) = 0   fr  f \geq (1+r)*f_s/2   %<'FontName',MSVFORMFONT>
%
%     andernfalls:
%
%     P(f) = (1 + cos(\pi*(f/(f_s/2) + r - 1)/(2*r)))/2   %<'FontName',MSVFORMFONT>
%
% In MATLAB-Syntax:
%
r  = 0.2;             % Roll-off-Faktor
fs = 1;               % Schrittfrequenz
b  = 10;              % Breite des Zeitbereichs in Schritten
n  = 500;             % Anzahl der Punkte im Diagramm
t  = b*(-n:n)/n;      % Zeitbereich
f  = fs*(0:n-1)/n;    % Frequenzbereich
p  = sin(pi*fs*t)./(pi*fs*t).*cos(pi*r*fs*t)./(1-(2*r*fs*t).^2);
P  = (f<=(1-r)*fs/2)+(f>(1-r)*fs/2).*(f<(1+r)*fs/2).*(1+cos(pi*(f/(fs/2)+r-1)/(2*r)))/2;
fh1= fullscreen('Impuls im Zeitbereich'); plot(t,p); set(gca,'YLim',[-0.3 +1.2])
fh2= fullscreen('Impuls im Frequenzbereich');  
plot([-reverse(f) f],[reverse(P) P]); set(gca,'YLim',[-0.2 +1.2])
%
% Die einfache Form des Impulses im Frequenzbereich mit der sog. Kosinus-roll-off-Flanke 
% ermutigt zur Erzeugung des Impulses durch ein Tiefpassfilter mit entsprechender Flanke. 
% Man generiert also Dirac-Funktionen an den entsprechenden Stellen im Schritt-Takt und 
% schickt dieses Signal durch ein Kosinus-roll-off-Filter.
%
% Fr den Entwurf von Kosinus-roll-off-Filtern gibt es fertige Routinen:
%
schritt = 10;   % Anzahl Abtastungen pro Schritt
r   = 0.1;      % Roll-off-Faktor
fh3 = fullscreen('Cos-roll-off-Filter');
b   = firrcos(60,1/schritt/2,r,1,'rolloff');  % Entwurf eines Cos-roll-off-Filters
filterplot(b,0,1,'lin',0,1.2)
%
% Wir benutzen das Filter mit einer Testsequenz von Bits:
%
s = [nullein(randx(50,[-1 +1]),schritt-1),zeros(1,schritt-1)];
x = filter(b,1,s);  % Filtern
x = x(6*schritt+1:length(x));
fh4 = fullscreen('Impulsfolge'); plot(x)
%
%
% \bfAugendiagramm
%
% Das Augendiagramm fr die oben berechnete Impulsfolge ist:
%
augendiagramm(x,1,1/schritt,1.3)
%
%
% \bfIntersymbolinterferenz
%
% Die Konstruktion des Filters erfolgte unter der Vorgabe der Freiheit von Intersymbol-
% interferenz.  Das aktuelle Augendiagramm zeigt dies (hoffentlich) perfekt.
%
%
% \bfZusammenfassung
%
% Zeitausdehnung:           abhngig vom Roll-off-Faktor   %<'FontName',MSVFORMFONT>                    
% Spektralausdehnung:       abhngig vom Roll-off-Faktor   %<'FontName',MSVFORMFONT>    
% Zeit-Bandbreite-Produkt:  abhngig vom Roll-off-Faktor   %<'FontName',MSVFORMFONT>  
% Intersymbolinterferenz:   keine                          %<'FontName',MSVFORMFONT>
% zeitliche Augenffnung:   abhngig vom Roll-off-Faktor   %<'FontName',MSVFORMFONT>     
%