%
%
%7.5.  Synchronisation bei Blockbertragung%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-10,'Color',MSVTITLCOLOR>
%
%
%
% Im Fall der sporadischen bertragung einzelner Datenblcke ist eine Trgerregelung 
% ungeeignet wegen ihres Einschwingverhaltens.  Besser ist es, das analoge Signal des 
% gesamten Blocks digital aufzuzeichnen und anschliessend die Analyse vorzunehmen. 
% Dies kann so weit gehen, dass die Datenentscheidung fr die gesamte Information des 
% Blockes durch eine einzige ersetzt wird, die nach dem Maximum-Likelihood-Prinzip 
% arbeitet.  Dies hat sehr grosse Vorteile.  Insbesondere wird man frei von allen 
% Anforderungen an die Impulsform wie z.B. Intersymbolinterferenz.  Wir kommen auf 
% diese Thematik zurck im Kapitel 13.  Hier soll zunchst nur die Rekonstruktion der 
% Trgerschwingung fr den gesamten Block behandelt werden.  Dabei wird an dieser Stelle 
% der Schwerpunkt auf das prinzipielle Verfahren gelegt und nicht auf die effiziente 
% Realisierung.
%
% Im folgenden Skript wird in der Variablen  {\fontname{Courier}s}  eine zufllige Folge von  {\fontname{Courier}100} Binrsymbolen mit 
% Raised-Cosine-Impulsform bei der Schrittfrequenz  {\fontname{Courier}400 Baud}  generiert.  Dieses Signal wird 
% in DSB auf einen Trger der Frequenz  {\fontname{Courier}f_0 = 1000 Hz}  moduliert (Variable  {\fontname{Courier}x}).  Der Kanal 
% wird durch krftiges weisses Rauschen simuliert ({\fontname{Courier}x_n}).  Das modulierte Signal wird zunchst 
% ohne, dann mit Rauschen als Sound ausgegeben.  Es folgt die Simulation des Empfngers.  
% Zur Transformation ins Basisband wird die Frequenz  {\fontname{Courier}f_1}  benutzt.  Diese ist gegenber  {\fontname{Courier}f_0}  
% um einen zuflligen konstanten Betrag falsch und weist ausserdem eine zufllige lineare 
% Frequenzwanderung auf.  Das analytische Basisbandsignal wird mit einem FIR-Tiefpass 
% gefiltert.  Das Resultat  {\fontname{Courier}z}  wird durch eine Animation in der komplexen Ebene dargestellt.  
% Obwohl dieses Signal wegen seiner Drehung aufgrund des Trgerfrequenzfehlers nicht zur 
% Datenentscheidung geeignet ist, werden die entsprechenden Abtastpunkte rot hervorgehoben.  
% Zur Bestimmung der Trgerphase wird  {\fontname{Courier}z^m  (m=2)}  berechnet und ebenfalls als Animation dargestellt.  
% Ausserdem gibt es ein Bild mit der Phase  {\fontname{Courier}angle(z^m)}  ber der Zeit.  In diesen Graphen (blau) 
% wird ein Polynom (hier zweiten Grades) nach der Methode der kleinsten Quadrate eingepasst (rot).  
% Der  {\fontname{Courier}m}-te Teil dieses Winkels ist der Phasenfehler  {\fontname{Courier}p_f}  von  {\fontname{Courier}f_1}.  Eine Multiplikation von  {\fontname{Courier}z}  
% mit  {\fontname{Courier}exp(-ip_f)}  liefert das korrigierte Signal  {\fontname{Courier}zz} .  Dieses wird wieder als Animation dargestellt.  
% Es sollte ausser durch Rauschen bedingte Unruhe keine Drehung mehr zeigen und eine 
% korrekte Datenentscheidung ermglichen.
%
m  = 2;                      % Anzahl der Stufen
as = 100;                    % Anzahl der Symbole im Block
fa = 8000;                   % Abtastfrequenz
fs = 400;                    % Schrittfrequenz
f0 = 1000;                   % Trgerfrequenz
r  = 0.3/(m-1);              % Standardabweichung des weissen Rauschens
p  = 2*pi*rand;              % beliebige Phase
g  = 60;                     % Filtergrad fr Empfangsfilter
s  = impulsfolge(randx(as,-1:2/(m-1):+1-eps),'RC',fa/fs);
t  = (0:length(s)-1)/fa;     % Zeitbereich
x  = s.*cos(2*pi*f0*t);      % Modulation (DSB)
df = 50*randn + 20*randn*t;  % Zeit-varianter Dopplereffekt in Hz
x  = x.*exp(i*(p + df.*t));  % Dopplereffekt anbringen
xn = x + r*randn(size(x));   % Addition von weissem Kanalrauschen
soundsc(real(x),fa); pause(ceil(as/fs))
soundsc(real(xn),fa);
f1 = 1000;                   % Trgerfrequenz zur Transformation ins Basisband
y  = xn.*exp(i*2*pi*f1.*t);  % Transformation ins Basisband
b  = fir1(g,1.9*fs/fa);      % Entwurf des Empfangsfilters
z  = filter(b,1,y);          % Empfangsfilter
zsq= z.^2;                   % Quadrat
komplexanimat(z,[1 0 0 0 0 1],10,[90 0],round(g/2+1+fa/fs:fa/fs:length(z)))
title('Signal nach dem Empfangsfilter','FontSize',13); set(gcf,'Name','z')
komplexanimat(zsq,[1 0 0 0 0 1],10,[90 0],round(g/2+1+fa/fs:fa/fs:length(z)))
title('z^m','FontSize',13); set(gcf,'Name','z^m')
[bt,at] = ellip(2,0.5,60,0.01); % alternativ: bt=fir1(g,0.01),1,zsq); at=1;
tsq = filter(bt,at,zsq);     % Glttung von zsq (sonst geht unwrap nicht)
fh2 = fullscreen('Phase'); plot(t,unwrap(angle(tsq)))
set(gca,'XLim',[2*g length(zsq)]/fa)
k = 2*g:length(t);  kk = g+300:length(t);
c = polyfit(t(kk),unwrap(angle(tsq(kk))),2);
line(t(k),polyval(c,t(k)),'Color','r')
zz = z(k-g/2+1).*exp(-i*(polyval(c,t(k)))/2);
komplexanimat(zz,[1 0 0 0 0 1],10,[90 0],round(1+fa/fs:fa/fs:length(zz)))
title('Signal nach der Trgerphasenkorrektur','FontSize',13); set(gcf,'Name','Korrektur')
fh1= fullscreen('Blocksync');
axes('Position',[0 0 1 1])
plot(t,[s+6;real(x)+3;real(xn);real(z)-3;real(zsq)-6;[zeros(1,g-1) real(zz) zeros(1,g)]-9]');
line([zeros(1,6);ones(1,6)],[1 1]'*(-9:3:+6),'Color',0.7*[1 1 1],'LineStyle',':')
set(gca,'XLim',[0,t(length(t))]); axis off
legend('Impulssequenz','Signal','Signal plus Rauschen','Signal nach Empfangsfilter','m-te Potenz','Impulssequenz nach Korrektur')
%
%% Die obige Simulation sollte mehrfach wiederholt werden, da der simulierte 
%% Frequenzfehler bisweilen sehr klein ausfllt.
%
% Die obige Simulation benutzt DSB-Modulation.  Dies ist quivalent zu einer PSK
% mit nicht-kontinuierlicher Phase und wegen der Impulsform auch nicht konstanter 
% Amplitude.  Eine PSK mit kontinuierlicher Phase und konstanter Amplitude erhlt 
% man durch Ersetzung der Modulation in obigem Skript durch PSK:
%
m  = 2;                      % Anzahl der Stufen
as = 100;                    % Anzahl der Symbole im Block
fa = 8000;                   % Abtastfrequenz
fs = 400;                    % Schrittfrequenz
f0 = 1000;                   % Trgerfrequenz
r  = 0.1/(m-1);              % Standardabweichung des weissen Rauschens
p  = 2*pi*rand;              % beliebige Phase
g  = 60;                     % Filtergrad fr Empfangsfilter
s  = impulsfolge(randx(as,-1:2/(m-1):+1-eps),'RC',fa/fs);
t  = (0:length(s)-1)/fa;     % Zeitbereich
x  = cos(2*pi*f0*t+(1-1/m)*pi*s);  % PSK-Modulation mit kontinuierlicher Phase
df = (50*randn + 20*randn*t);  % Zeit-varianter Dopplereffekt in Hz
x  = x.*exp(i*(p + df.*t));  % Dopplereffekt anbringen
xn = x + r*randn(size(x));   % Addition von weissem Kanalrauschen
soundsc(real(x),fa); pause(ceil(as/fs))
soundsc(real(xn),fa);
f1 = 1000;                   % Trgerfrequenz zur Transformation ins Basisband
y  = xn.*exp(i*2*pi*f1.*t);  % Transformation ins Basisband
b  = fir1(g,4*fs/fa);        % Entwurf des Empfangsfilters
z  = filter(b,1,y);          % Empfangsfilter
zsq= z.^m;                   % m-te Potenz
komplexanimat(z,[1 0 0 0 0 1],10,[90 0],round(g/2+1+fa/fs:fa/fs:length(z)))
title('Signal nach dem Empfangsfilter','FontSize',13); set(gcf,'Name','z')
komplexanimat(zsq,[1 0 0 0 0 1],10,[90 0],round(g/2+1+fa/fs:fa/fs:length(z)))
title('z^m','FontSize',13); set(gcf,'Name','z^m')
[bt,at] = ellip(2,0.5,60,0.005); % alternativ: bt=fir1(g,0.01),1,zsq); at=1;
tsq = filter(bt,at,zsq);     % Glttung von zsq (sonst geht unwrap nicht)
fh2 = fullscreen('Phase'); plot(t,unwrap(angle(tsq)))
set(gca,'XLim',[2*g length(zsq)]/fa)
k = 2*g:length(t);  kk = g+300:length(t);
c = polyfit(t(kk),unwrap(angle(tsq(kk))),2);
line(t(k),polyval(c,t(k)),'Color','r')
zz = z(k-g/2+1).*exp(-i*(polyval(c,t(k)))/m);
komplexanimat(zz,[1 0 0 0 0 1],10,[90 0],round(1+fa/fs:fa/fs:length(zz)))
title('Signal nach der Trgerphasenkorrektur','FontSize',13); set(gcf,'Name','Korrektur')
fh1= fullscreen('Blocksync');
axes('Position',[0 0 1 1])
plot(t,[s+6;real(x)+3;real(xn);real(z)-3;real(zsq)-6;[zeros(1,g-1) real(zz) zeros(1,g)]-9]');
line([zeros(1,6);ones(1,6)],[1 1]'*(-9:3:+6),'Color',0.7*[1 1 1],'LineStyle',':')
set(gca,'XLim',[0,t(length(t))]); axis off
legend('Impulssequenz','Signal','Signal plus Rauschen','Signal nach Empfangsfilter','m-te Potenz','Impulssequenz nach Korrektur')
%
%
%% bung 7.5   Beide Skripte knnen fr beliebige  {\fontname{Courier}m}  verwendet werden.
%% Testen Sie den Fall  {\fontname{Courier}m = 4  und  m = 16}.
%%
%% Was bedeuten  DSB  mit  m = 4   und   PSK  mit  m = 4 ?