%
%
% 8.3. Gewhrleistung von Symbolwechseln%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-10,'Color',MSVTITLCOLOR>
%
%
%
% Die Rekonstruktion des Schritttaktes erfordert im Spektrum des Empfangssignals eine 
% Komponente bei der Schrittfrequenz.  Das ist, wie schon im letzten Abschnitt gezeigt, 
% nicht bei jeder Impulsform gegeben.  Zustzlich gibt es aber das Problem, dass nicht 
% jede Symbolfolge eine solche Komponente liefert.  Wir zeigen das an der Folge von 
% 100 gleichen Symbolen (alle {\fontname{Courier}1}) :
%
s  = ones(1,100);      % 100 Symbole, alle +1
n  = 3000;
rc = impulsfolge(s,'RC').^2;    frc = fft([rc,zeros(1,n-length(rc))]);
gs = impulsfolge(s,'Gauss').^2; fgs = fft([gs,zeros(1,n-length(gs))]);
re = impulsfolge(s,'Rect').^2;  fre = fft([re,zeros(1,n-length(re))]);
si = impulsfolge(s,'Sinc').^2;  fsi = fft([si,zeros(1,n-length(si))]);
tr = impulsfolge(s,'Tri').^2;   ftr = fft([tr,zeros(1,n-length(tr))]);
sp = abs([frc;fgs;fre;fsi;ftr]');
sp = sp(2:502,:);
fh = fullscreen('Q-Spektrum');
plot(20*(0:500)/n,sp)
set(gcf,'KeypressFcn','hervorhebung','UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}})
axis([0,3.3,1,400])
legend('1 Raised Cosine','2 Gauss','3 Rechteck','4 Sinc','5 Dreieck')
title('Spektrum des Quadrates einer Folge von 100 gleichen Symbolen (alle 1) bei verschiedenen Impulsformen','FontSize',13)
xlabel('Frequenz/Schrittfrequenz','FontSize',13)
%
% Beim Raised-Cosine-Impuls ergibt sich in diesem Fall wie beim Rechteck-Impuls eine 
% konstante 1, so dass eine Rekonstuktion des Schritttaktes nicht mglich ist.  Bei 
% Benutzung des Raised-Cosine-Impulses muss man also gewhrleisten, dass gengend 
% hufige Symbolwechsel vorkommen.  Man kann also nicht jede beliebige binre 
% Reprsentation irgendeiner Information ungendert mit der Raised-Cosine-Impulsform 
% bertragen.  Man muss eine Kodierung vornehmen.  Die einfachste fr diesen Zweck ist 
% das Bit-Stopfen (bitstuffing).  Dabei wird auf der Senderseite nach jeweils  {\fontname{Courier}n}  aufeinander 
% folgenden gleichen Symbolen  {\fontname{Courier}a}  das zu  {\fontname{Courier}a}  komplementre Symbol eingefgt. 
% Der Empfnger beseitigt nach der Datenentscheidung jeweils das auf  {\fontname{Courier}n}  gleiche 
% Symbole folgende Symbol.
%
% Im folgenden Beispiel werden wieder 100 gleiche Symbole (alle {\fontname{Courier}1})  benutzt, jedoch mit 
% Bitstuffing nach je 8 gleichen Symbolen.
%
s  = bitstuffing(0,8,ones(1,100),[-1 +1]);      % 100 Symbole, alle +1
n  = 3050;
rc = impulsfolge(s,'RC').^2;    frc = fft([rc,zeros(1,n-length(rc))]);
gs = impulsfolge(s,'Gauss').^2; fgs = fft([gs,zeros(1,n-length(gs))]);
re = impulsfolge(s,'Rect').^2;  fre = fft([re,zeros(1,n-length(re))]);
si = impulsfolge(s,'Sinc').^2;  fsi = fft([si,zeros(1,n-length(si))]);
tr = impulsfolge(s,'Tri').^2;   ftr = fft([tr,zeros(1,n-length(tr))]);
sp = abs([frc;fgs;fre;fsi;ftr]');
sp = sp(2:502,:);
fh = fullscreen('Q-Spektrum');
plot(20*(0:500)/n,sp)
set(gcf,'KeypressFcn','hervorhebung','UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}})
axis([0,3.3,1,400])
legend('1 Raised Cosine','2 Gauss','3 Rechteck','4 Sinc','5 Dreieck')
title('Spektrum des Quadrates einer Folge von 100 gleichen Symbolen (alle 1) bei verschiedenen Impulsformen','FontSize',13)
xlabel('Frequenz/Schrittfrequenz','FontSize',13)
%
% Offenbar gibt es jetzt auch beim Raised-Cosine-Impuls eine Frequenzkomponente an der 
% Schrittfrequenz.  Beim Rechteck- und beim Sinc-Impuls hilft das Bitstuffing nicht.
%
% Der Extremfall des Bitstuffing ist der Fall  {\fontname{Courier}n = 1} , d.h. nach jeder  {\fontname{Courier}1}  wird eine  
% {\fontname{Courier}0}  und nach jeder  {\fontname{Courier}0}  eine  {\fontname{Courier}1}  eingefgt.  Man nennt dies Manchester-Kodierung.
%
% Beispiel:
bitfolge = [1 1 1 0 1 0 0 1]
bitstuffing(0,1,bitfolge,[0 1])
%% Resultat im Kommandofenster
%
% Die Manchester-Kodierung erlaubt die sichere Synchronisation des Schritttaktes, allerdings 
% auf Kosten hherer Bandbreite.
%
% Bei der Datenbertragung wird hufig eine Datensicherung durch Kodierung vorgenommen. 
% In diesem Fall wird man, falls die gewhlte Impulsform das erfordert, den Kode so auslegen, 
% dass gengend hufige Symbolwechsel vorkommen.
%
%
%% bung 8.3.1.  Wiederholen Sie bung 8.2.1 unter Einsatz des Bitstuffing. 
%% Verwenden Sie hierbei die Funktion  bitstuffing  oder/und geeignete Bitmuster wie z.B.
symb = 2*[1 1 0 0 1 1 0 0 1 1 0 0 1 1 0 0 1 1 0 0 1 1 0 0 1 1] - 1
%
%% Folgende Fragen sind zu beantworten:
%% c.  Wird das Maximum des Spektrums an der Schrittfrequenz deutlicher?
%% d.  Werden andere Maxima geschwcht oder gar krftiger?
%
%
%% bung 8.3.2.  Die folgenden Aufrufe testen das Verhalten unter sehr starkem Rauschen. 
%
sendbits  = bitstuffing(0,3,randx(40,[-1 +1]),[-1,+1]);
[s,r0,r1] = schrittsync( 100, 100.3, sendbits, 1.0, 1, 0.1);
syncfehler= sum(r0~=sendbits)
bitfehler = sum(r1~=sendbits)
%
sendbits  = nfach(2*[nullein(ones(1,8),1),0]-1,3);
[s r0,r1] = schrittsync( 100, 100.3, sendbits, 1.0, 1, 0.1);
syncfehler= sum(r0~=sendbits)
bitfehler = sum(r1~=sendbits)
%
%% Wo liegt das Problem des letzten Aufrufs?
%
% {\bfHinweis}:  In der Praxis ist die Schrittfrequenz sehr viel genauer bekannt als die hier 
% angenommenen 10%.  Dann gelingt die Schrittsynchronisation auch bei stark verrauschten 
% Signalen wesentlich sicherer.
%
%
%% bung 8.3.3.  Ein schnes Beispiel fr DSB mit Manchester-Kodierung ist die 
%% Telemetrie des P3-D-Satelliten AO-40.  Man findet smtliche Information hierzu 
%% ausgehend von der AMSAT-DL-homepage:  www.amsat-dl.org
%% Ein Empfnger fr kurze Sequenzen, die einen Blockanfang enthalten, ist in der 
%% Funktion  p3drx2  realisiert. 
%% Ein Datenblock steht in der Datei p3dsk.wav.  Es ist der Beginn des letzten vom 
%% Autor dieses Skripts aufgenommenen Datenblocks vor dem vermutlich durch ein 
%% schadhaftes Ventil des Bordtriebwerkes verursachten Endes der Satellitenkommunikation 
%% am 13.12.2000.  Der Block enthlt ASCII-Text. 
%% (Satellitenentfernung: ca. 25000 km;  Empfangsantenne: Dipol 1 m Draht;
%% Obwohl wesentliche Komponenten, u.a. drei Sender, mehrere Antennen und zwei 
%% Triebwerke bei der Explosion zerstrt wurden, konnte der Satellit 14 Tage spter 
%% wieder aktiviert werden, siehe AMSAT-DL)
%%
%% 1. Ermitteln Sie die Trgerfrequenz auf drei Stellen nach dem Komma, 
%% so dass die Trgerphase an Anfang und Ende der Sequenz gleich ist.
%% Die sichtbare langsame Schwankung der Trgerphase wird durch 
%% Ungenauigkeiten des Empfngeroszillators verursacht, mit dem das 
%% Signal von 145898.0 kHz nach ca. 1.5 kHz umgesetzt wurde.  Die 
%% schnelle Schwankung dagegen ist bedingt durch das hrbare Rauschen.
%% (Jetzt stehen nur noch Sender auf  2.4 GHz  und auf  24 GHz  zur 
%% Verfgung.  Die Genauigkeit ist dabei wesentlich schlechter)
%%
%% 2. Ermitteln Sie den Fehler der Schrittfrequenz
%%
%% 3. Ermitteln Sie den maximalen Doppler-Effekt auf die Schrittfrequenz.
%% Dieser Effekt verndert die Frequenz  {\fontname{Courier}f}  um den Betrag  {\fontname{Courier}f*v/c}, wo 
%% {\fontname{Courier}v}  die Objektgeschwindigkeit (hier maximal 10000 m/s) und 
%% {\fontname{Courier}c}  die Lichtgeschwindigkeit  {\fontname{Courier}c = 299792458 m/s} ist.
%% Kann die ermittelte Frequenzdifferenz durch den Dopplereffekt 
%% verursacht sein?
%%
%% 4. Versuchen Sie die Realisierung der Trgersynchronisation und der 
%% Schrittsynchronisation im Programm nachzuvollziehen.
%%
