%
%
%9.3.4  m-stufige bertragung %<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
% \bfm-PSK
%
% Bei  m-PSK  rcken die diskreten Signale mit steigendem  m  immer nher zusammen, so dass 
% erheblich grsseres  {\fontname{Courier}SNR}  erforderlich ist.  Die Verhltnisse lassen sich gut veranschaulichen mit
%
help mpsk_noise
%% Siehe Kommandofenster!
%
% Ein Beispiel gibt:
%
mpsk_noise(16,20)
%
% Hherstufige  m-PSK  lsst sich nur approximativ behandeln.  Hier sei auf K.D.Kammeyer: 
% Nachrichtenbertragung verwiesen.  Dort findet sich folgende Nherung fr die 
% Symbolfehlerwahrscheinlichkeit.  Bei einschrittiger Codierung fhrt ein Symbolfehler 
% ganz berwiegend zu einem Einbitfehler, so dass die Bitfehlerwahrscheinlichkeit etwa 
% um den Faktor  {\fontname{Courier}1/log_2(m)} kleiner ist.
%
% W(Symbolfehler) = erf((sqrt(log_2(m)*E_b/N_0) * sin(\pi/m))   %<'FontName',MSVFORMFONT>
%
% W(Bitfehler) = erf((sqrt(log_2(m)*E_b/N_0) * sin(\pi/m))/log_2(m)   %<'FontName',MSVFORMFONT>
%
% Das folgende Bild stellt die Bitfehlerwahrscheinlichkeit fr  4-PSK  bis  64-PSK  
% aufgrund dieser Nherung dar.  Die Nherung ist fr Bitfehlerwahrscheinlichkeiten  {\fontname{Courier}< 0.1} , 
% also im praktisch relevanten Bereich sehr gut.  Darber verliert sie an Gltigkeit. 
% Insbesondere berschreiten alle Kurven die theoretische Grenze von  {\fontname{Courier}0.5} .  Dies liegt 
% daran, dass Mehrfachfehler das selbe Bit betreffen knnen, was hier nicht bercksichtigt 
% wurde.  Die Kurven gelten fr kohrente Demodulation mit absolut bekannter Trgerphase.
%
mPSK_err
%
% Verteilt man  m  Symbole nicht nur auf dem Einheitskreis, wie das bei  m-PSK  der Fall 
% ist, sondern in der komplexen Ebene, so kann man bei gleicher mittlerer Symbolenergie 
% den Minimalabstand vergrssern:
%
SNR = 12;            % SNR in dB
v22bis(SNR);         p = get(gcf,'Position');  a = round(p(3)/2);
mPSK_noise(16,SNR);  set(gcf,'Position',[a  p(2)  a  p(4)])
%
%
% \bfm-QAM
%
% Fr   {\fontname{Courier}m > 8}   ist  m-QAM  energetisch gnstiger als  m-PSK .  Allerdings muss man 
% bedenken, dass  QAM  einen linearen Sendeverstrker bentigt, der teurer ist und einen 
% etwas geringeren Wirkungsgrad hat.
%
%
% \bfm-FSK
%
% Fr die Orthogonalitt der Entscheidungen unter den  {\fontname{Courier}m}  Frequenzen muss ihr Abstand 
% {\fontname{Courier}\Deltaf = n*f_s/2}  sein, wo  {\fontname{Courier}n = 1, 2, 3, ...} und  {\fontname{Courier}f_s = Schrittfrequenz} .
% Die bentigte Bandbreite ist damit  {\fontname{Courier}m*n*f_s/2} , also propotional zu  {\fontname{Courier}m} .   {\fontname{Courier}m} enthlt aber 
% nur  {\fontname{Courier}log_2m}  Bit an Information.  m-FSK ist deshalb eine bezglich der Bandbreite 
% verschwenderische Betriebsart.  Sie wird dort benutzt, wo wegen usserst schwacher 
% Signale die Baudrate {\fontname{Courier}f_s}  sehr klein gewhlt werden muss.  Wir bringen hierzu Beispiele 
% in den Abschnitten 14.3.3  und  14.3.6 .
%
% Die Symbolfehlerwahrscheinlichkeit fr m-FSK ist abhngig vom benutzten Empfngerfilter 
% und von der Art des Demodulators.  Wir nehmen den einfachen Fall an, dass in  {\fontname{Courier}m} 
% parallelen Kanlen der (in der Praxis nicht ganz erreichbaren) Bandbreite  {\fontname{Courier}f_s/2}  die
% Energie akkumuliert und im Schritt-Takt abgetastet wird.  Einen Symbolfehler gibt es 
% dann, wenn die maximale Rauschenergie unter allen Kanlen abzglich der Rauschenergie 
% des aktuellen Signalkanals grsser ist als die Signalenergie.  Eine derartige Simulation fhrt 
% die Funktion  {\fontname{Courier}mFSK\_err} durch (das rechnet eine Weile):
%
mFSK_err
%
% Eine direkte Berechnung wird von der Funktion  {\fontname{Courier}mfskerr}  durchgefhrt. 
% Die Ergebnisse sind bis auf die statistischen Fehler des Monte-Carlo-Verfahrens von
% {\fontname{Courier}mFSK\_err}  bei grsseren Werten von  {\fontname{Courier}E_b/N_0}  und die einer Nherung bei 
% kleinen Werten von  {\fontname{Courier}E_b/N_0}  vergleichbar:
%
mfskerr3
%
% FSK wird blicherweise (wie hier auch angenommen) inkohrent demoduliert.  
% Im kohrenten Fall sind die Kurven um 3 dB nach links zu verschieben. 
% Die im Abschnitt 14.3.6 zu besprechende Betriebsart  JT44  ist eine kohrente 
% 44-FSK, bei der eine der Frequenzen ohne weitere Information zur Trger-, 
% Schritt- und Block-Synchronisation verwendet wird.  Die Hlfte der zur Verfgung 
% stehenden Energie wird zur Aussendung dieser Synchronisation verbraucht. 
% Damit verringert sich  {\fontname{Courier}E_b/N_0}  um 3 dB, so dass sich das selbe Diagramm wie 
% oben ergibt, allerdings mit dem entscheidenden Vorteil, dass das Auffinden 
% der Aussendung sowohl im Zeitbereich wie auch im Frequenzbereich wesentlich 
% erleichtert wird.
%
%
%% bung 9.3.3a   Das Bild 
%
mPSK_err
%
%% zeigt deutlich, dass die ntige Bitenergie  {\fontname{Courier}E_b}  bei 
%% festgelegter Bitfehlerwahrscheinlichkeit stark mit der Stufigkeit ansteigt. 
%% Warum betrachten wir dann berhaupt hherstufige bertragung?
%%
%% bung 9.3.3b   Zeichnen Sie den Anstieg der Bitenergie in linearer Skala fr den Fall 
%% der Bitfehlerwahrscheinlichkeit von  {\fontname{Courier}10^{-6}}.
%