function [d,err] = pactor2rx(x,fa,mark,space)
%
% !!!!! gerade in Arbeit !!!!!
% !!!!! diese Trgersync. bentigt ein IIR-Filter (ftr) , das 
%       Einschwingen verursacht. Besser wre ein direkter Fit 
%       des Trgers
%
% [d,err] = pactor2rx(x,fa,mark,space)
% Dekodierung eines Pactor2-Paketes
%
%   x     :  Signalvektor
%   fa    :  Abtastrate von x
%   mark  :  Markfrequenz
%   space :  Spacefrequenz
%
%   d     :  dekodierte Binrdaten
%   err   :  0 , wenn CRC ok,  1 sonst

% Autor:  Klaus von der Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<4  space =  400; end
if nargin<3  mark  =  600; end
if nargin<2  fa    = 2000; end
if nargin<1  x = pactor2tx; end
if abs(mark-space)-200 > 1  error('Abstand von Mark und Space ist nicht 200'); end

% Konstanten
% ==========
m  = 2;                            % Stufigkeit
fs = 100;                          % Schrittfrequenz
sr = round(fa/fs);                 % Abtastungen pro Schritt
srh= round(sr/2);
n  = length(x);                    % Anzahl der Abtastungen
header = [1 0 0 1 0 0 0 1;
          0 0 0 1 0 0 1 1];        % Header
crcpoly= [16 12 5 0];              % CRC-Polynom
dfhead = diffencode(header);       % Header differentiell kodiert
hdsymb = exp(i*pi*dfhead);         % Headersymbole
hdsigm = impulsfolge(hdsymb(1,:),'RC',sr); % Header im Basisband
hdsigs = impulsfolge(hdsymb(2,:),'RC',sr); % Header im Basisband
lhd    = length(hdsigm);
ftr= 0.5;                          % maximale FM-Frequenz auf Trger
t  = (0:n-1)/fa;                   % Zeitbereich
b  = (1 + cos(pi*(-(sr-1):+(sr-1))/sr))/2;  % Matched Filter fr Raised Cosine
b  = b/sum(b);                     % Normierung
ge = length(b) - 1;                % Grad des Empfangsfilters
[bt,at] = ellip(2,0.5,60,ftr/fa);  % Filter fr Trgerregelung
k  = 2*ge:n;
kk = 2*ge+800:n;
kkk = 2*ge+200:n-2*ge;

% Transformation ins Basisband und Empfangsfilter
% ===============================================
xm = filter(b,1,x.*exp(-i*2*pi*(mark *t + rand)));
xs = filter(b,1,x.*exp(-i*2*pi*(space*t + rand)));

% Trgerphasensynchronisation
% ===========================
zsqm = xm.^2;               % Signalquadrat
zsqs = xs.^2;               % Signalquadrat
tsqm = filter(bt,at,zsqm);  % Glttung von zsq (sonst geht unwrap nicht)
tsqs = filter(bt,at,zsqs);  % Glttung von zsq (sonst geht unwrap nicht)
cm   = polyfit(t(kk),unwrap(angle(tsqm(kk))),2);
cs   = polyfit(t(kk),unwrap(angle(tsqs(kk))),2);
ym   = xm(k-ge/2+1).*exp(-i*(polyval(cm,t(k)))/2);
ys   = xs(k-ge/2+1).*exp(-i*(polyval(cs,t(k)))/2);

% Synchronisation der Schrittfrequenz
% ===================================
alpha = angle((ym.^m - ys.^m)*exp(-i*2*pi*fs*t(k))');
schr  = sin(2*pi*fs*t(k)-alpha);
clkm  = find(diff(schr>0)>0);
clks  = clkm + srh;
if clks(end)>length(ys)  clks = clks(1:end-1); end

% Erkennung des Headers
% =====================
for a = 1:20*sr
   hdkorr(a) = abs(hdsigm*ym(a:a+lhd-1)') + abs(hdsigs*ys(srh+(a:a+lhd-1))');
end
anf = min(find(hdkorr>0.9*max(hdkorr))) + lhd - sr;
clkm = clkm(find(clkm>=anf-srh));
clks = clks(find(clks>=anf));

% Abtastung der Schrittwerte
% ==========================
zm = real(ym(clkm));
zs = real(ys(clks));

% Differenzkodierung dekodieren
% =============================
wm = abs(diff(zm));  wm = wm(1:72); 
wm = wm - mean(wm);  wm = wm/mean(abs(wm));
ws = abs(diff(zs));  ws = ws(1:72);  
ws = ws - mean(ws);  ws = ws/mean(abs(ws));

% Verzahnung
% ==========
matrix = reshape([wm ws]',9,16)';
vitin  = reshape(reshape(matrix>0,1,144),72,2)';

% Viterbi-Dekoder
% ===============
g  = faltpoly(2,9);
bv = viterbi2(g(2:-1:1,:),vitin);

% CRC-Prfung
% ===========
err = any(crc(bv(1:64),crcpoly));

% Ausgabe in Kommandofenster
% ==========================
'Pactor2-Empfnger'
hartmarkbitstrom  = binmatout(zm>0) % harte Bitentscheidung
hartspacebitstrom = binmatout(zs>0) % harte Bitentscheidung
hartdiffdekom     = binmatout(wm>0)
hartdiffdekos     = binmatout(ws>0)
hartverzahnmatrix = binmatout(matrix>0)
viterbiinput      = binmatout(reshape((vitin>0),2,72))
dekodbitsm        = binmatout(bv)
dekodtext         = binvec2str(bv,1);
if err CRC = 'Fehler !'
else 
   CRC = 'ok'
   Infotext = dekodtext(1:5)
end

% Darstellung
% ===========

fh0 = fullscreen('Headerkorrelation');
plot(hdkorr);

fh1 = fullscreen('Filter');
set(gca,'Position',[0.07 0.1 0.89 0.85])
filterplot({b; {bt;at}},0,0.2,0,-75,5);
legend('Matched Filter','Filter fr Trgerregelung')

fh4 = fullscreen('Empfangssignal im Basisband');
ha1 = axes('Position',[0 0.4 1 0.6]);
plot(t(k),real(ym)); 
line(t(k(clkm)),zm,'Marker','.','LineStyle','none','LineWidth',3,'Color','r')
axis([[t(1) t(end)]+(ge+1)/fa -2 +2]); axis off
line(get(gca,'XLim'),[0 0],'LineStyle',':','Color',0.7*[1 1 1])
ha2 = axes('Position',[0 0.0 1 0.6]);
plot(t(k),real(ys)); 
line(t(k(clks)),zs,'Marker','.','LineStyle','none','LineWidth',3,'Color','r')
axis([[t(1) t(end)]+(ge+1)/fa -2 +2]); axis off
line(get(gca,'XLim'),[0 0],'LineStyle',':','Color',0.7*[1 1 1])

fh6 = fullscreen('Differenzsignal im Basisband');
ha1 = axes('Position',[0 0.4 1 0.6]);
line(t(k(clkm(1:72))),wm,'Marker','.','LineStyle','none','LineWidth',3,'Color','r')
axis([[t(1) t(end)]+(ge+1)/fa -5 +5]); axis off
line(get(gca,'XLim'),[0 0],'LineStyle',':','Color',0.7*[1 1 1])
ha2 = axes('Position',[0 0.0 1 0.6]);
line(t(k(clks(1:72))),ws,'Marker','.','LineStyle','none','LineWidth',3,'Color','r')
axis([[t(1) t(end)]+(ge+1)/fa -5 +5]); axis off
line(get(gca,'XLim'),[0 0],'LineStyle',':','Color',0.7*[1 1 1])

fh5 = fullscreen('Phase');
title('Trgerphase','FontSize',13)
subplot(2,1,1);
atsq = unwrap(angle(tsqm(kk)));
mq = mean(atsq);
plot(t(kk),atsq-mq)
line(t(kk),polyval(cm,t(kk))-mq,'Color','r')
set(gca,'XLim',[t(kk(1)) t(kk(end))])
subplot(2,1,2);
atsq = unwrap(angle(tsqs(kk)));
mq = mean(atsq);
plot(t(kk),atsq-mq)
line(t(kk),polyval(cs,t(kk))-mq,'Color','r')
set(gca,'XLim',[t(kk(1)) t(kk(end))])
