function [sn,s] = pactor2tx(u,fa,mark,space,sigma)
% s = pactor2tx(u,fa,mark,space)
% Kodierung und Modulation eines Pactor2-Paketes
%
%   u     :  String des zu sendenden ASCII-Textes oder Binrvektor der Lnge 40
%   fa    :  Abtastrate von x
%   mark  :  Markfrequenz
%   space :  Spacefrequenz
%   sigma :  zustzliches Rauschen mit dieser Standardabweichung
%
%   sn    :  Signal mit Kanalrauschen
%   s     :  Signal des Paketes

% Autor:  Klaus von der Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<5  sigma =    0; end
if nargin<4  space =  400; end
if nargin<3   mark =  600; end
if nargin<2     fa = 2000; end
if nargin<1   u = 'Hallo'; end
if abs(mark-space)-200 > 1  error('Abstand von Mark und Space ist nicht 200'); end

% Konstanten
% ==========
fs = 100;                                % Schrittfrequenz
sr = round(fa/fs);                       % Abtastungen pro Schritt
header  = [1 0 0 1 0 0 0 1;
           0 0 0 1 0 0 1 1];             % Header !!!!noch prfen!!!!
status  = zeros(1,8);                    % Status !!!!noch einfgen!!!!
crcpoly = [16 12 5 0];                   % CRC-Polynom
vorlauf = 150 + round(200*rand);         % zuflliger Vorlauf
a = vorlauf;
b = vorlauf + round(sr/2);

% Binr-Kodierung
% ===============
if ischar(u) 
   bninf = str2binvec(u,1);              % Binrinformation !!! fr 4/8/16-PSK erweitern !!!
else
   bninf = u;                            % Binrinformation direkt verwenden
end
info  = [bninf  status];                 % Information fr CRC 
binfo = [info  crc(info,crcpoly)];       % Information plus CRC
fcde  = faltcode(binfo,faltpoly(2,9));   % Faltungskodierung

% Verzahnung
% ==========
matrix= reshape([fcde(2,:),fcde(1,:)]',16,9);        % Verzahnungsmatrix
blkm  = [header(1,:) reshape(matrix(1:8,:)',1,72)];  % Mark-Block
blks  = [header(2,:) reshape(matrix(9:16,:)',1,72)]; % Space-Block

% Differenzkodierung
% ==================
dbm   = diffencode(blkm);                % Differenzkodierung
dbs   = diffencode(blks);                % Differenzkodierung

% m-stufige Symbole
% =================
                                         % !!! hier fehlt: 4/8/16-PSK !!!
symbm = exp(i*pi*dbm);                   % 2-PSK                                          
symbs = exp(i*pi*dbs);                   % 2-PSK                       
                             
% Zeitkontinuierliche Basisbandsignale
% ====================================
sm = [zeros(1,a) impulsfolge(symbm,'RC',sr) zeros(1,b)];
ss = [zeros(1,b) impulsfolge(symbs,'RC',sr) zeros(1,a)];

% Modulation
% ==========
n = length(sm);
t = (0:n-1)/fa;
s = real(sm.*exp(i*2*pi*mark*t) + ss.*exp(i*2*pi*space*t));

% Weisses Kanalrauschen
% =====================
sn = s + sigma.*randn(size(s));

% Ausgabe ins Kommandofenster
% ===========================
'Pactor2-Sender'
if ischar(u) 
   stringinformation = u 
else
   binaerinformation = binmatout(u)
end
bininfopluscrc = binmatout(binfo)
kodewort1 = binmatout(fcde(2,:))
kodewort2 = binmatout(fcde(1,:))
verzahnmatrix  = binmatout(matrix)
'mit Header:'
markblock  = binmatout(blkm)
spaceblock = binmatout(blks)
diffmark   = binmatout(dbm)
diffspace  = binmatout(dbs)

% Darstellung
% ===========
fh1 = fullscreen('Sendesignal','w',1);
plot(t,real(sm)+7,t,real(ss)+4.5,t,sn+1);
axis([0 (n-1)/fa -2 +8]); axis off
set(gca,'Position',[-0.1 0.1 1.2 0.8])

% Sound-Ausgabe
% =============
soundsc([s zeros(1,100) sn],fa)
