function partialresponse(symb,imp)
% partialresponse(symb,imp)
% Anschauliche Graphik fr das Partial Response Verfahren:
% Dargestellt wird das Signal fr die Symbolfolge symb 
% untereinander fr die vier Flle  L = 1, 2, 3, 4. 
% Als zugrundeliegende Impulsform imp kann gewhlt werden:
% 'rect'  :  Rechteck (Default)
% 'tri'   :  Dreieck
% 'rc'    :  Raised Cosine im Zeitbereich
% 'gauss' :  Gauss
% 'sinc'  :  Sinc
% Wird dem String fr imp ein "+" angehngt, so wird 
% zustzlich das Signal fr Klasse 4 gezeichnet.
%
% Default fr symb sind 64 zufllige Binrsymbole -1 / +1.

if nargin<2   imp = 'rect';    end
if nargin<1  symb = randb(64,[-1 +1]); end
col = 'kbgrc';
s   = 20;

pr4 = 0;
if imp(end)=='+'  pr4 = 1; imp = imp(1:end-1); end
switch imp
   case 'rect',       d = s/2;
   case 'gauss',      d = s*3;
   case {'rc','RC'},  d = s;
   case 'tri',        d = s;
   case 'sinc',       d = s*10;
end   

n  = 20*length(symb);
fh = fullscreen('Partial response');

for k=1:4
   x = 0.2*impulsfolge(symb,imp,s,0,k);
   line(1:length(x)-k*d,5-k+x(k*d+1:end),'Color',col(k));
end
if pr4
   x = 0.3*impulsfolge(symb,'PR4',s);
   line(1:length(x)-6*s,x(6*s+1:end),'Color',col(5));
   legend('L = 1','L = 2','L = 3','L = 4','Klasse 4')
else
   legend('L = 1','L = 2','L = 3','L = 4')
end

for k=1:4+pr4
   line([1 n],(5-k)*[1 1],'Color',0.7*[1 1 1],'LineStyle',':')
end

axis([1 n 0-pr4 5]); axis off
set(gca,'Position',[0 0 1 1])