function x0 = pcmod(tmax,fs,fkt,bits)
% x0 = pcmod(tmax,fs,fkt,bits)
% Pulcodemodulation der als String fkt anzugebenden Funktion 
% im Zeitbereich  t = 0..tmax  mit der Abtastrate fs.
% Die freie Zeitvariable in der Funktion ist dabei t.
% Die Abtastung erfolgt im Wertebereich -1 ... +1.
% Die Funktion ist also auf diesen Bereich zu skalieren.
% fktabtast gibt im Vektor x0 die abgetasteten Werte.

% Autor: K. v. d. Heide, e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<4  bits =  6; end
if nargin<3   fkt = '0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)'; end;
if nargin<2    fs = 20; end;
if nargin<1  tmax =  1; end;
fsiz = 13;                       % FontSize
patchcol = 0.7*[1 1 1];
if ischar(fkt) 
   n = floor(tmax*fs); 
else 
   n = length(fkt);
   tmax = n/fs;
end

% Abtastung
% =========
ts= (0:n)/fs;                    % quidistante Abtastpunkte
t = ts;                          % t auf Abtastpunkte umdefinieren (wegen eval)
if ischar(fkt) ya = eval(fkt); else ya = fkt; end % Signal
ys= ya;
if nargin>3                      % falls bits angegeben, dann digitalisieren 
   ys = min(1-2^(1-bits),ys);    % bei +1 abschneiden
   ys = max(-1,ys);              % bei -1 abschneiden
   ys = round(ys*2^(bits-1))*2^(1-bits); % digitalisieren im 2-Komplement
end
x0 = ys;                         % Rckgabe: abgetastete Werte

if nargout>0  break; end

% Bilderzeugung
% =============
h = fullscreen('PCM');
axes('Position',[0.05 0.075 0.9 0.85])

% Darstellung der Abtastniveaus
% =============================
if bits<9
   for k=-2^(bits-1):(2^(bits-1)-1)  
      line(tmax*[0 1],k*2^(1-bits)*[1 1],'Color',0.8*[1 1 1]); 
   end
end

% Darstellung zeitdiskret
% =======================
for i = 1:n
   patch([ts(i),ts(i+1),ts(i+1),ts(i)],[ys(i) ys(i) 0 0],patchcol,'EdgeColor','w'); 
   line([ts(i),ts(i)],[0,ys(i)],'Color','r','LineWidth',2.0); 
end
line(ts,ys,'Marker','o','Color','r','LineStyle','none','LineWidth',3,'MarkerSize',5);
str = sprintf('Pulscodemodulation von  %s',fkt);
if nargin>3  str = sprintf('%s  bei Quantisierung in %3.0f Bits',str,bits); end
title(str,'FontSize',fsiz)
xlabel('Zeitbereich','FontSize',fsiz)

% Darstellung zeitkontinuierlich
% ==============================
t = tmax*(0:799)/800;            % "kontinuierlicher" Zeitbereich: 800 Punkte
line(t,zeros(size(t)));          % Zeitachse zeichnen
y = eval(fkt);                   % Funktion berechnen
line(t,y,'LineWidth',2.0);       % Funktion zeitkontinuierlich zeichnen

