function z = pdmod(tmax,fs,fkt,bits)
% pdmod(tmax,fs,fkt,bits)
% Pulsbreitenmodulation der als String fkt anzugebenden Funktion 
% im Zeitbereich  t = 0..tmax  mit der Abtastrate fs.
% Die freie Zeitvariable in der Funktion ist dabei t.
% Die Abtastung erfolgt im Wertebereich -1 ... +1.
% Die Funktion ist also auf diesen Bereich zu skalieren.
% bits ist die Zahl der zur Quantisierung verwendeten Bits

% Autor: K. v. d. Heide, e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<4  bits =  8; end
if nargin<3   fkt = '0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)'; end;
if nargin<2    fs = 50; end;
if nargin<1  tmax =  1; end;
fsiz = 13;                       % FontSize
patchcol = 0.3*[1 1 1];
if ischar(fkt) 
   n = floor(tmax*fs); 
else 
   n = length(fkt);
   tmax = n/fs;
end
fso = fs*2^bits;                 % Abtastrate der Ausgabe

% Abtastung
% =========
ts = (0:n)/fs;                   % quidistante Abtastpunkte
t  = ts;                         % t auf Abtastpunkte umdefinieren (wegen eval)
if ischar(fkt) ya = eval(fkt); else ya = fkt; end % Signal
ys = ya;
ys = min(1-2^(2-bits),ys);       % bei +1 abschneiden
ys = max(-1,ys);                 % bei -1 abschneiden
ys = round(ys*2^(bits-1))*2^(1-bits); % digitalisieren im 2-Komplement
yy = (ys + 1)/2/fs;              % Normierung auf die Pulsbreite

% Ausgabe
% =======
z  = zeros(1,round(fso*tmax));
for i = 1:n 
   if (round(ts(i)*fso)+(0:round(yy(i)*fso)) > 0) & ...
      (round(ts(i)*fso)+(0:round(yy(i)*fso)) < round(fso*tmax))
      z(round(ts(i)*fso)+(0:round(yy(i)*fso))) = 1; 
   end
end

if nargout>0  break; end

% Bilderzeugung
% =============
h = fullscreen('PDM');
d  = 0.05;

% Darstellung Signal
% ==================
axes('Position',[0  2/3  1  1/3-d])
t = tmax*(0:799)/800;            % "kontinuierlicher" Zeitbereich: 800 Punkte
line(t,zeros(size(t)));          % Zeitachse zeichnen
y = eval(fkt);                   % Funktion berechnen
line(t,y,'LineWidth',2.0);       % Funktion zeitkontinuierlich zeichnen
axis([0.01 1 -1 +1])
for i = 1:n
   line([ts(i),ts(i)],[0,ys(i)],'Color','r','LineWidth',2.0); 
end
line(ts,ys,'Marker','o','Color','r','LineStyle','none','LineWidth',3,'MarkerSize',5);
axis off

% Darstellung der Abtastniveaus
% =============================
axes('Position',[0  1/3  1  1/3-d])
if bits<5
   for k=-2^(bits-1):(2^(bits-1)-1)  
      line(k*2^(1-bits)/fs+[1 1]'*ts,[0 1]'*ones(1,n+1),'Color',0.8*[1 1 1]); 
   end
end

% Darstellung zeitdiskret
% =======================
for i = 1:n
   patch([ts(i),ts(i)+yy(i),ts(i)+yy(i),ts(i)],[1 1 0 0],patchcol,'EdgeColor','w'); 
end
str = sprintf('Pulsdauermodulation von  %s',fkt);
if nargin>3  str = sprintf('%s  bei Quantisierung in %3.0f Bits',str,bits); end
title(str,'FontSize',fsiz)
axis([0.01 1 0 1.2]); axis off

% Darstellung Demodulation
% ========================
x  = pddemod(z);
xx = interp1((0:length(x)-1)/length(x),x,0:0.001:1,'spline');
lx = length(xx);
axes('Position',[0  0  1  1/3-d])
plot(0:0.001:1,xx,'LineWidth',2.0)
line([0 1],[0 0],'LineStyle',':','Color',0.7*[1 1 1])
title('Demoduliertes Signal','FontSize',fsiz)
axis([0.01 1 -1 +1]); axis off

