function perr_psk(vis)
% perr_psk(vis)
% Plot der Bitfehlerwahrscheinlichkeit ber Eb/No fr vier Flle:
% 1. reelles Basisband bipolar
% 2. reelles Basisband unipolar
% 3. BPSK antipodal
% 4. Symbolfehlerwahrscheinlichkeit bei QPSK  = Nherung fr 
%    die Bitfehlerwahrscheinlichkeit bei Gray-Codierung
% 5. BPSK antipodal mit Differenzkodierung
% 6. QPSK mit Differenzkodierung
% Optional knnen beliebige dieser Kurven mit dem booleschen 
% Vektor vis unsichtbar gemacht werden. Default: vis = [1 1 1 1 1 1].

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

if nargin<1  vis = [1 1 1 1 1 1]; end  % Sichtbarbeit der Kurven
fsiz= 13;            % FontSize
lw  = 1.5;           % LineWidth
xdB = -6:0.25:12;    % Eb/No-Bereich [dB]
x   = 10.^(xdB/10);  % dasselbe linear
fh  = fullscreen('PSK-Bitfehler');
if vis(1) line(xdB,0.5*erfc(sqrt(x/2)),'Color','b'); end
if vis(2) line(xdB,0.5*erfc(sqrt(x/4)),'Color','g'); end
if vis(3) line(xdB,0.5*erfc(sqrt(x)),'Color','r');   end
if vis(4) line(xdB,erfc(sqrt(x)) - (0.5*erfc(sqrt(x))).^2,'Color','m'); end
if vis(5) line(xdB,erfc(sqrt(x)),'Color','c'); end
if vis(6) line(xdB,2*(erfc(sqrt(x)) - (0.5*erfc(sqrt(x))).^2),'Color','y'); end
lgnd = [];
if vis(1)  lgnd = [lgnd;'reelles Basisband bipolar ']; end
if vis(2)  lgnd = [lgnd;'reelles Basisband unipolar']; end
if vis(3)  lgnd = [lgnd;'BPSK antipodal            ']; end
if vis(4)  lgnd = [lgnd;'QPSK (Gray-Kodierung)     ']; end
if vis(5)  lgnd = [lgnd;'BPSK Differenzkodierung   ']; end
if vis(6)  lgnd = [lgnd;'QPSK Differenzkodierung   ']; end
title('Bitfehlerwahrscheinlichkeit ber Eb/No','FontSize',fsiz)
xlabel('Eb/No [dB]','FontSize',fsiz)
ylabel('Bitfehlerwahrscheinlichkeit','FontSize',fsiz)
set(gca,'YScale','log','FontSize',fsiz); 
grid on
legend(lgnd,3)
set(gcf,'KeyPressFcn','hervorhebung','UserData',{zeros(1,8); 1.2*ones(1,8); {}});
