function quantrand(n)
%
% Darstellung optimaler Quantisierung in n Bits 
% fr normalverteilte Zufallszahlen.

% Autor: Klaus von der Heide;  e-mail  v.d.heide@on-line.de

if nargin<1  n = 2; end

if n>32  error('quantrand:  n > 32  ist nicht sinnvoll'); end

g  = 3 + log(n);                 % Darstellungsgrenze
x  = -g:0.005:+g;                % Abszisse
m  = length(x);                  % Anzahl der Abszissenpunkte
y  = quantize(x,n);              % Quantisierung
qf = y - x;                      % Quantisierungsfehler
p  = (1/sqrt(2))*exp(-(x.^2)/2); % Normalverteilung
qp = qf.*p;                      % Produkt

fh11 = fullscreen('Quantisierung','w',0,[2 3; 1 1]);
plot(x,y)
line([-g; +g],[0; 0],'Color','k')
axis([-g +g -g +g])
xlabel('Signalwert')
ylabel('quantisiert')

fh21 = fullscreen('Quantisierungsfehler','w',0,[2 3; 2 1]);
plot(x,qf)
axis([-g +g (g-1)*[-1 +1]])
line([-g; +g],[0; 0],'Color','k')
xlabel('Signalwert')
ylabel('Quantisierungsfehler')

fh12 = fullscreen('Normalverteilung','w',0,[2 3; 1 2]);
plot(x,p)
axis([-g +g 0 1])
xlabel('Signalwert')
ylabel('Wahrscheinlichkeitsdichte')

fh22 = fullscreen('Produkt','w',0,[2 3; 2 2]);
plot(x,qp)
line([-g; +g],[0; 0],'Color','k')
axis([-g +g 1.1*max(abs(qp))*[-1 +1]])
xlabel('Signalwert')
ylabel('Produkt')

for k=1:100
   s(k) = k/10;                     % Skalierungsfaktor
   y  = s(k)*quantize(x/s(k),n);    % Quantisierung
   qf = y - x;                      % Quantisierungsfehler
   p  = (1/sqrt(2))*exp(-(x.^2)/2); % Normalverteilung
   qp = qf.*p;                      % Produkt
   mfq(k) = sum(qp.^2)/m;           % mittleres Fehlerquadrat
end
fh13 = fullscreen('mittleres Fehlerquadrat','w',0,[2 3; 1 3]);
plot(s,mfq)
set(gca,'YScale','log')
xlabel('r  ( der quantisierte Bereich ist  \sigma \cdot r \cdot [-1 +1] )')
ylabel('mittleres Fehlerquadrat')

[mn,j] = min(mfq);
sm = j/10;                          % Skalierungsfaktor
x  = max(1,log(sm))*(-g:0.005:+g);  % Abszisse
y  = sm*quantize(x/sm,n);           % Quantisierung
qf = y - x;                         % Quantisierungsfehler
p  = (1/sqrt(2))*exp(-(x.^2)/2);    % Normalverteilung
qp = qf.*p;                         % Produkt

fh23 = fullscreen('Optimum','w',0,[2 3; 2 3]);
plot(x,qp)
line(max(1,log(sm))*[-g; +g],[0; 0],'Color','k')
axis([max(1,log(sm))*[-g +g] 1.1*max(abs(qp))*[-1 +1]])
xlabel('Signalwert')
ylabel('Optimum')
title(sprintf('Quantisierung des Signalbereiches %2.1f ... %2.1f mit %2d Bits',sm,sm,n))

