function randber(k,n)
% randber(k,n)
% Graphik mit der Bitfehlerrate von (n,k)-Randomkodes 
% ber E_b/N_0.
% Ist n ein Vektor, so wird eine entsprechende Kurvenschar 
% gezeichnet.

if nargin<1  k = 8;  end
if nargin<2  n = [1 2 3 4 5 6]*k;  end


% Konstanten
% ==========
ug = -2;
og = 10;
fsiz= 13;                          % FontSize
lw  = 1.5;                         % LineWidth
col  = 'kbgrcymk';                 % Farben
while size(col)<length(n)  col = [col; col]; end
for j=1:length(n)  lg(j,:) = sprintf('n = %4d',n(j)); end   % Legende
ebn0db = linspace(ug,og,1000);     % Eb/N0 in dB
x  = 10.^(ebn0db/10);              % Eb/N0 linear
%s  = [-1 +1];                      % Signalniveaus

fh = fullscreen('BER');

for j=1:length(n)
   sigma = 2./sqrt(2*x*k/n(j));     % Standardabweichung des Rauschens
   dm  = n(j)/2 + n(j)*sigma.^2;    % Erwartungswert der Distanz
%   dm  = n(j);                     % Erwartungswert der Distanz zweier Kodewrter
   sm  = sqrt(n(j)/2 + 2*n(j)*sigma.^2); % Erwartungswert der Standardabweichung
%   sm  = sqrt(2*n(j));             % Erwartungswert der Standardabweichung
   line(ebn0db,erfc((dm-n(j)*sigma.^2)./sm)/2,'Color',col(j),'LineWidth',lw)
end
title(sprintf('Bitfehlerrate von (n,%2d)-Random-Kodes',k),'FontSize',fsiz)
xlabel('E_b/N_0 [dB]','FontSize',fsiz)
ylabel('Bitfehlerrate','FontSize',fsiz)
legend(lg,3)
set(gca,'YScale','log')
axis([ug og 10^-5 1])
grid on


