function y = rsc_encode(g, x, ende)


% encodes a block of data x (0/1)with a recursive systematic
% convolutional code with generator vectors in g, and
% returns the output in y (0/1).
% if ende>0, the trellis is perfectly terminated
% if ende<0, it is left unterminated;

% determine the constraint length (K), memory (m), and rate (1/n)
% and number of information bits.
[n,K] = size(g);
m = K - 1;
if ende>0
  L_info = length(x);
  L_total = L_info + m;
else
  L_total = length(x);
  L_info = L_total - m;
end  


% initialize the state vector
state = zeros(1,m);

% generate the codeword
for i = 1:L_total
   if ende<0 | (ende>0 & i<=L_info)
      d_k = x(1,i);
   elseif ende>0 & i>L_info
      % terminate the trellis
      temp_vector = g(1,:)&[0 state];
      d_k = rem( sum( temp_vector ), 2 );
   end
 
   feedback = g(1,:)&[d_k state];
   a_k = rem( sum( feedback ), 2 );
   [output_bits, state] = encode_bit(g, a_k, state);
   % since systematic, first output is input bit
   output_bits(1,1) = d_k;
   y(n*(i-1)+1:n*i) = output_bits;
end
