function s = simpledds(f,n)
% s = simpledds(f,n)
% Direkte Digitale Cos/Sin-Synthese .
%
%  f  :  Frequenz relativ zur Abtastfrequenz
%        Das Signal s wird analytisch berechnet.  
%        Deshalb ist  0 <= f < 1.0  zulssig.
%        (Default: Zufallszahl)
%        f kann ein abgetastetes Signal sein.  Dann wird die 
%        jeweilige Momentanfrequenz verwendet.
%  n  :  Anzahl zu berechnender Abtastschritte.  Ist f als Vektor 
%        gegeben, so wird anstelle von n die Lnge von f genommen.
%        In diesem Fall wird eine Angabe von n ignoriert.
%
%  s  :  komplexes Ausgabesignal

% Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<1      f = 0.4*rand;    end
if length(f)>1   n = length(f);   elseif nargin<2  n = 1024; end
if length(f)<2   f = f*ones(1,n); end
   
% Exp-Berechnung
% ==============
s = exp(i*2*pi*cumsum(f));
