function   L_sova= sova( output, transition, inv_state, L_in,  g, r, end)
%% Copyright 1997 Yufei Wu
% for academic use only

% soft decision Viterbi decoding 
% takes an encoded (and possibly corrupted) codeword with values between 
% [-1 and 1] and returns the soft output.
% output, transition, inv_state: description of trellis;
% g: code generator;
% r: Lc.*r; where Lc is the channel reliability value, r is the received bits;
% L_in: a priori information of each bit, size(L) = L_total;
% if end>0, the trellis is perfectly terminated, trace back from all-zero state
% if end<0, the trace back from the state with the largest metric

[n,K] = size(g);
m = K - 1;
max_state = 2^m;
rec_size = length(r);
L_total = rec_size/n;

% info bit = 0, transmission = -1; info bit = 1, transmission = +1;
u(1) = -1; u(2) = 1;

% set infinity to an arbitrarily large value
inf = 10^5;

% initialization
trellis = -inf*ones(max_state,L_total);
path = zeros(max_state,L_total);
path_bit = 10*ones(max_state,L_total);
new_path = path;
delta = inf*ones(max_state,L_total);
L_sova = zeros(1,L_total);


% determine trellis and path matrices at time 1
y_segment = r(1,1:n);
for i=0:1
   hypothesis = 2*output( 1, n*i+1:n*(i+1) )-1;
   next_state = transition(1,i+1);
   trellis(next_state,1) = .5*L_in(1)*u(i+1)+.5*y_segment*hypothesis';
   path(next_state,1) = 1;
   path_bit(next_state,1) = i;
   delta(next_state,1)=inf;
end

% now determine trellis and path matrices for times 2 through L
counter = n +1;
for time=2:L_total
   y_segment = r( 1,counter:counter+n-1);
   counter = counter + n;
   for state=1:max_state
      for i=0:1
         hypothesis = 2*output( state, n*i+1:n*(i+1) )-1;
         next_state = transition( state, i+1 );

         % update path metric
         path_metric = trellis(state,time-1) + .5*L_in(time)*u(i+1)+.5*y_segment*hypothesis';

         if path_metric > trellis( next_state, time )
            new_delta(next_state,1:time)=[delta(state,1:time-1) ...
                      abs(path_metric - trellis(next_state,time))];
            trellis( next_state, time ) = path_metric;
            path(next_state, time) = state; 
            path_bit(next_state, time) = i;
         else
            new_delta(next_state,time)=abs(path_metric - trellis(next_state,time));
         end
      end
   end
   delta = new_delta;
end

% most likely path: the survived state and infomation bits
if end > 0	%perfectly terminated, trace back from all zero state
   survival(L_total) = 1;
else   % otherwise trace back from the state with the largest metric
   survival(L_total) = min(find (trellis(:,L_total)==max(trellis(:,L_total))));
end
x_hat(L_total) = path_bit(survival(L_total),L_total);
for time = L_total-1:-1:1
  survival(time) = path(survival(time+1),time+1);
  x_hat(time) = path_bit(survival(time),time);
end  


% find out nonsurving paths which would have led to a different decision than 
% the survived path for the info bit at the time 'window_start'
for window_start = 1:L_total	%current time 'window_start'
% largest distance between the nonsurving path trace back point and the current state
   delay = min([30,L_total-window_start]);
   compete_bit = 20*ones(delay+1,delay+1);	
% competing path start point / time index 'time'
   for time = min(L_total,window_start+delay):-1:window_start
     relative= time-window_start+1; 	%relative time index
     if time>1
        previous = survival(time-1);
     else
        previous = 1;  		% starting from all-zero state
     end   
     discard(relative) = inv_state(survival(time),...
        	3-find(inv_state(survival(time),:)==previous));

     compete_sur = discard(relative);
     compete_bit(relative,relative) = ...
         find(transition(discard(relative),:)==survival(time))-1;
     if time == 1
         compete_bit(1,1) = 10;
     end   
     if relative>1
         compete_bit(relative, relative-1) = path_bit(compete_sur, time-1);
      end
% competing path point trace back to window start point
      for time1 = time-2:-1:window_start
         compete_sur = path(compete_sur, time1+1);
         compete_bit(relative, time1-window_start+1) = path_bit(compete_sur, time1);
      end 
   end

% find out the minimum metric difference among all the chosen nonsurving path
   min_delta = 10000; 
   for k = window_start:min([L_total window_start+delay]) 
      if compete_bit(k-window_start+1, 1) ~= x_hat(window_start)
         min_delta = min( [min_delta delta(survival(L_total),k)]);
      end
   end    
     	  
   L_sova(window_start) = (2*x_hat(window_start)-1)*min_delta;

end
