function [n,k,d] = suchperfektkode(m,q);
% [n,k,d] = suchperfektkode(m,q)
% Vollstndige Suche nach linearen Blockkodes ber GF(q), 
% die die Hamming-Grenzbedingung mit Gleichheitszeichen 
% erfllen, also perfekt sind.
% Gesucht wird nach allen Kodes bis zur Blocklnge m.
% Defaults: m = 128; q = 2.
% n, k, d  sind die Kodeparameter Blocklnge, Anzahl der 
% Informationssymbole und Minimalabstand.
% Gefunden werden bis n = 128 die entsprechenden Hammingkodes mit d = 3, 
% der binre (23,12)-Golaykode, ein binrer (90,78)-Kode mit d = 5
% sowie ein (11,6)-Kode ber q = 3 mit d = 5.

% Defaults und Konstanten
% =======================
if nargin<1  m = 128; end
if nargin<2  q = 2;   end
logq = log(q);
q1   = q - 1;
prec = 1.0e-10;

% Binomialkoeffizienten
% =====================
for n=1:m
   nn = 1;
   zz = 1;
   for t=1:m
      nn = nn*t;
      zz = zz*(n-t+1);
      bk(n,t) = zz/nn;
   end
end

% Hamming-Grenze
% ==============
hg = -0.5*ones(m,m);
for n=1:m
   hg(n,1:m) = log(1 + cumsum(bk(n,1:m).*q1.^(1:m)))/logq;
end

% Hamming-Grenze ganzzahlig?
% ==========================
[n,t] = find(abs(hg-round(hg))<prec);
for j=1:length(n)
   k(j,1) = n(j) - hg(n(j),t(j));
end
j = find(k>1.5);
n = round(n(j));
k = round(k(j));
d = round(2*t(j) + 1);
