function  testcarriersync(sigma,gs,gc,q)
% testcarriersync(sigma,gs,gc,q)
% Demonstration der Wirkung von carriersync.
% sigma :  Standardabweichung des Rauschens
% gs    :  Polynomgrad der simulierten Trgerfrequenz
% gc    :  Polynomgrad der Synchronisation
% q     :  Mass fr die Ungenauigkeit der Trgerfrequenz 
%          (0 <= q <= 0.05)
%          Es kann auch ein Vektor der Lnge gs angegeben werden
%          mit den Grssenordnungen der Polynomkoeffizienten
%          (hchste Potenz zuerst, lineare zuletzt)
% Ausgegeben wird das mit dem rekonstruierten Trgersignal nach
% Frequenz 0 verschobene Signal in der komplexen Ebene.  
% Es sollte also um den (rot markierten) Punkt  1.0 + 0.0*i  rauschen.
% Beispiele (mehrfach aufrufen wegen Zufallsparametern):
% testcarriersync(2.0);  % trotz starken Rauschens gelingt die Synchronisation
% testcarriersync(3.0);  % wegen starken Rauschens misslingt die Synchronisation
% testcarriersync(0.1,3,2,[0.002 0.005 0.005]); % Synchronisation unvollstndig
%                            % wegen Nichtbercksichtigung des Terms vom Grad 3.

% Autor:  K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<1  sigma = 0.1; end           
if nargin<2  gs = 3;      end
if nargin<3  gc = 3;      end
if nargin<4  q  = 0.005;  end
if length(q)<2  q = q*ones(1,gs); end

% Konstanten
% ==========
nx = 16384;                    % Anzahl der Samples
m  = 1;                        % Potenz des Signals zur Synchronisation
fg = 20*max(q);                % Grenzfrequenz des Reglerfilters
t  = (0:nx-1)/nx;              % Zeitbereich

% Simulation des Signals
% ======================
pc = [nx*q.*randn(1,gs)  2*pi*rand]; % zufllige Polynomkoeffizienten
ph = polyval(pc,t);            % Phase als Funktion der Zeit
x  = exp(i*ph);                % Signal
r  = sigma*(randn(size(x)) + i*randn(size(x))); % Rauschen
y  = x + r;                    % Addition des Rauschens

% Synchronisation
% ===============
z  = carriersync(y,fg,m,gc);   % Synchronisation

% Graphik
% =======
a  = max(abs(z));
fh = fullscreen('Sync');
plot(z)
line(a*[-1 0; +1 0],a*[0 -1; 0 +1],'Color',0.7*[1 1 1])
line(1,0,'Marker','.','MarkerSize',20,'Color','r')
axis(a*[-1 +1 -1 +1]); axis square; axis off

% Animationen
% ===========
%komplexanimat(x);
%komplexanimat(y);
%komplexanimat(z);
