function [output, transition, inv_state] = trellis(g)

% copyright Yufei Wu

% set up the trellis given code generator g
% g given in binary form. e.g. g = [ 1 1 1; 1 0 1 ];

% output(i,1:2): trellis output when input = 0, state = i;
% output(i,3:4): trellis output when input = 1, state = i;
% transition(i,1): next state when input = 0, state = i;
% transition(i,2): next state when input = 1, state = i;
% inv_state(i,:): two states that can come to state i;

[n,K] = size(g);
m = K - 1;
max_state = 2^m;



% set up output and transition matrices for systematic code
for state=1:max_state
   state_vector = bin_state( state-1, m );
   
   % hypothesis: receive a 0
   d_k = 0;
   feedback = g(1,:)&[0 state_vector];
   a_k = rem( sum( feedback ), 2 );
   [out_0, state_0] = encode_bit(g, a_k, state_vector);
   out_0(1) = 0;
  
   % hypothesis: receive a 1
   d_k = 1;
   feedback = g(1,:)&[1 state_vector];
   a_k = rem( sum( feedback ), 2 );
   [out_1, state_1] = encode_bit(g, a_k, state_vector);
   out_1(1) = 1;
   output(state,:) = [out_0 out_1];
   transition(state,:) = [(int_state(state_0)+1) (int_state(state_1)+1)];
end

% find out which two states can come to present state
inv_state = zeros(max_state,2);  
for state=1:max_state
  for bit=0:1
     if inv_state(transition(state,bit+1),bit+1)==0
        inv_state(transition(state,bit+1),bit+1)=state;
      else
        inv_state(transition(state,bit+1),2-bit)=state;
      end
   end 
end
