function hndl = trellisdiag(n,q,d)
% trellis(n,q,d)
% Darstellung des Trellis-Diagramms fr
% n :  Constraint Length
% q :  Stufigkeit
% d :  Datenfolge (Vektor aus Integer {0..q-1})
% Falls d angegeben ist, erfolgt die Darstellung der aktuellen 
% Transitionen schrittweise durch beliebigen Tastendruck.
% Die Rechenzeit ist hoch und etwa proportional  q^(2*n).
% q^n = 64 ist darstellungstechnisch und rechentechnisch 
% etwa die Grenze.
% Ausgegeben werden die Handles fr Figure und Axes in 
% einem Vektor von 2 Komponenten.
%
% Mit addtrellisdiag knnen weitere Wege eingefgt werden.

% Autor: Klaus von der Heide, v.d.heide@on-line.de

% Konstanten
% ==========
if nargin<2 q = 2; end
if nargin<1 n = 2; end
m  = q^n;              % Trellis-Tiefe
if nargin>2 tn = length(d); else tn = 13; end % Trellis-Lnge
td = floor(0.13*m + 0.5*q); % Skalierung der Schritt-Achse
ccol = 0.7*[1 1 1];    % Kreisfarbe
r  = 1/4;              % Kreisradius
fsiz = 15;             % FontSize fr berschrift
pt = max([8,round(100/m)]); % FontSize fr Zustandsbezeichnung
lw1= 1.0;              % LineWidth fr mgliche Transitionen
lw2= 3.0;              % LineWidth fr aktuelle Transitionen
cl1= 0.8*[1 1 1];      % Color fr mgliche Transitionen
cl2= 'g';              % Color fr aktuelle Transitionen

% Erzeugen des Fensters
% =====================
fh = fullscreen('Trellis');
ah = axes('xlim',[-0.5 1.51*m],'ylim',[-0.5 m-0.2],'Position',[0 0 1 0.96],'visible','off');
text(0,m-0.3*(m<8),sprintf(...
     'Trellis-Diagramm fr  Constraint Length = %d  und  Stufigkeit = %d',...
     n,q),'FontSize',fsiz)

% Zeichnen der Zustnde
% =====================
%for k=0:m-1
%   drawccir([0,m-k-1],r,ccol,num2basstr(k,q,n),pt)
%end

%for t=1:tn-1
for t=0:tn-1
   for k=0:m-1
      drawccir([t*td,m-k-1],r,ccol,num2basstr(k,q,n),pt);
   end
   text(t*td-0.8*r,m-0.6,sprintf('%3d',t+1),'FontSize',pt)
end

% Zeichnen der mglichen Transitionen
% ===================================
mz = [0];
for t=0:tn-1            % Schritt
   nmz = [];            % Liste der nchsten mglichen Zustnde
   for j=1:length(mz)   % alle mglichen Zustnde in diesem Schritt
      z  = mz(j);       % betrachteter Zustand
      zz = num2basvec(z,q,n); % dieser als Vektor
      for s=0:q-1       % alle nchsten Symbole
         nz = basvec2num([s,zz(1:n-1)],q); % nchster Zustand
         if length(nmz)==0|all(nmz~=nz) nmz = [nmz,nz]; end
         drawarr([t*td,m-z-1],[(t+1)*td,m-nz-1],cl1,lw1,0,r,r);
      end
   end
   mz = nmz;
end

% Zeichnen der aktuellen Transitionen
% ===================================
if nargin>2
   z  = 0;
   zz = zeros(1,n);     % Anfangs-Zustandsvektor
   for t=0:tn-1         % Schritt
      if nargin>3       % schrittweise darstellen
         if (t-1)*td > m  set(ah,'xlim',get(ah,'xlim')+td); end
         pause;
      end
      nz = basvec2num([d(t+1),zz(1:n-1)],q); % nchster Zustand
      drawarr([t*td,m-z-1],[(t+1)*td,m-nz-1],cl2,lw2,0,r,r);
      z  = nz;          % Takt: nchster Zustand wird Zustand
      zz = num2basvec(z,q,n); % dieser als Vektor
   end
end

hndl = [fh,ah];
