function [n_err,recinf] = turbdemo(x,g,EbN0,n_iter,puncture)
% [n_err,recinf] = turbdemo(x,g,EbN0,n_iter,puncture)
% Demo fr Turbo-Code.
% Dieses Programm wurde entwickelt auf der Basis einiger Programme von Yufei Wu
% Es wird ein zuflliges Interleaving verwendet.
%
%        x :  Informationsvektor          (Default : 32 zufllige Bits)
%        g :  zweizeiliger Code-Generator (Default : [1 0 1; 1 1 1])
%     EbN0 :  Eb/N0 in dB                 (Default : 1.5)
%   n_iter :  Anzahl der Iterationen      (Default : 5)
% puncture=1: Code punktieren auf Coderate 1/2 (nur wenn g zwei Zeilen hat; Default: 0)
%
% n_err    :  Anzahl der Bitfehler unter den decodierten Informationsbits
% recinf   :  decodierte Information
%
% wenn keine Zuweisung von n_err auf eine Variable erfolgt, gibt es einige Graphiken.

% Autor:  Klaus von der Heide,  v.d.heide@on-line.de

% Defaults
% ========
if nargin<1  x = randb(32); end
if nargin<2  g = [1 0 1; 1 1 1]; end
if nargin<3  EbN0 = 1.5; end
if nargin<4  n_iter = 8; end
if nargin<5  puncture = 0; end

cri = 3; 
t = clock;
lx  = length(x);
iteration = n_iter;
kkk = 100;
[n,K] = size(g);
if n~=2  error('turbdemo luft nur mit zweizeiligem g !'); end
m = K - 1;
L_total = lx + m;
max_state = 2^m;
L_info = L_total - m;
iinf = 1:L_info;
dimension = cri - 1;
if n ==2 & puncture ==1
   cri  = 2;
   itot = 1:2*L_total;
else
   puncture = -1;
   itot = 1:cri*L_total;
end
rate = 1/cri;

if nargout<1
   fprintf('\n\n----------------------------------------------------\n');  
   fprintf(' Info-Lnge  =%4d Bit\n',L_info);
   fprintf(' Blocklnge  =%4d Bit\n',L_total);
   fprintf(' Code-Lnge  =%4d Bit\n',cri*L_total);
   fprintf(' Code-Generator: \n');
   for i = 1:n
       for j = 1:K
           fprintf( '%6d', g(i,j));
       end
       fprintf('\n');
   end        
   fprintf(' Coderate    = 1/%1d\n', cri);
   fprintf(' Iterationen =%2d\n', iteration);
   fprintf(' Eb/N0       = %4.2f dB\n',EbN0');
end

% set up the trellis for g;
[output, transition, inv_state] = trellis(g);

% output of the first encoder isn't interleaved; order intact
alpha(1,1:L_total) = [1: L_total];
% generate an backward block interleaver for the second encoder
%alpha(2, 1:L_total) = back_block( [1:L_total], 3, 4);
% generate an random interleaver for the second encoder
alpha(2, 1:L_total) = rand_interleave( L_total);

a = 1;  % AWGN channel 'a' is constant;

blocknum = zeros(1,6);
en = 10^(EbN0/10);
sigma = 1/sqrt(2*rate*en);	% standard deviation of AWGN noise
Lc = 4*a*en*rate*ones(1,L_total/rate); 	% reliability value of the channel
    
% turbo encoder output (+1/-1)
en_output = en_turbo( x, g, alpha, puncture ) ;

% corrupted channel output
r = en_output + sigma * randn(size(en_output));

if nargout<1
   fig1 = fullscreen('Kanal:  blau(.): gesendete Bits;  rot(+): empfangene Werte',...
                     'w',0,[1.5 1; 1 1]);
   axes('Position',[0.03 0.05 0.94 0.9])
   plot(itot,0*itot,'g-',itot,en_output,'b.',itot,r,'r-',itot,r,'r+');
   title('blau(.): gesendete Bits;  rot(+): empfangene Werte');
   axis([0 itot(end)+1 max(abs(r))*[-1 +1]])

   fig2 = fullscreen('binrer Fehler bei binrer Datenentscheidung','w',1,[6 1; 5 1]);
   axes('Position',[0.03 0.2 0.94 0.6])
   line([1;1]*itot,[0;1]*(en_output.*r<0),'LineWidth',2,'Color','g')
   line([1;1]*itot(1+cri*(0:lx-1)),[0;1]*((en_output(1+cri*(0:lx-1)).*r(1+cri*(0:lx-1)))<0),...
        'LineWidth',2,'Color','r')
   axis([0 itot(end)+1 [0 1]])
   text(1,0.3,'rot: Informationsbits;  grn: Parittsbits','FontSize',12)

   fig4 = fullscreen('Empfangsdaten','w',0,[4 5; 1 5]);
   hist(r,20);
   set(gca,'XLim',max(get(gca,'XLim'))*[-1 +1],'YLim',1.1*get(gca,'YLim'))
end

% weight channel output by channel reliability, to be used in decoder
r_Lc = r.*Lc; 

% at receiver, serial to paralle demultiplex to get the code word of each
% encoder
subr = demultiplex(r_Lc,dimension,alpha,puncture);
for i = 1:L_total  subv(:,i) = subr(:,n*(i-1)+1); end;
Le(1,:) = zeros(1,L_total);

% iterative decoding begin
for iter = 1:iteration
   L_in = Le;
% Decoder 1
   L_out = sova(output,transition,inv_state, L_in,g,subr(1,:),1); 
   Le = L_out - subv(1,:) - L_in;
% normalization
   varL = sum((abs(Le)-mean(abs(Le))).^2)/(length(Le)-1);
   c = mean(abs(Le))*2/varL;
   Le = c *Le;
   c = min(1,kkk/mean(abs(Le)));
   Le = c *Le;

% interleaving the extrinsic value to be used as a priori information for 
% decoder two 
   dim = 2;
   L_in = Le(alpha(dim,:));
   
   % Decoder 2
   L_out = sova(output,transition,inv_state, L_in,g,subr(dim,:),-1);
   
% deinterleave the soft output 
   temp(alpha(dimension,:)) = L_out;
   
   % calculate bit error rate for the present block, present iteration
   x_hat  = temp(1:L_info) > 0;
   decfehl = x_hat ~= x;   
% extrinsic information to be used in the metrics of the first decoder   
   Le = L_out - subv(dim,:) - L_in;
% deinterleaving the extrinsic value Le as the a priori information 
% of the next decoder
   temp(alpha(dim,:)) = Le;
   Le = temp; 
% normalization
   varL = sum((abs(Le)-mean(abs(Le))).^2)/(length(Le)-1);
   c = mean(abs(Le))*2/varL;
   Le = c *Le;
   c = min(1,kkk/mean(abs(Le)));
   Le = c *Le;
end

if nargout<1
   fprintf('   CPU-Zeit  = %4.2f s',etime(clock,t));
   fprintf('\n----------------------------------------------------\n\n');
   en_x_hat = en_turbo( x_hat, g, alpha, puncture ) ;
   fig3 = fullscreen('Decodierfehler','w',1,[6 1; 6 1]);
   axes('Position',[0.03 0.2 0.94 0.6])
   line([1;1]*itot,[0;1]*(en_output~=en_x_hat),'LineWidth',2,'Color','g')
   line([1;1]*itot(1+cri*(0:lx-1)),[0;1]*(en_output(1+cri*(0:lx-1))~=en_x_hat(1+cri*(0:lx-1))),...
        'LineWidth',2,'Color','r')
   axis([0 itot(end)+1 [0 1]])
   figure(fig2)
end

n_err = sum(decfehl');
recinf = x_hat;
