function  ber = turbober(g,k,ebn0db,m,mt)
% ber = turbober(g,k,ebn0db,m,mt)
% Berechnung der Bitfehlerrate eines einfachen Turbocodes 
% durch Simulation.
% g        :  Generatormatrix
% k        :  Anzahl der Informationsbits im Kodewort
% ebn0db   :  Vektor der Werte Eb/N0 in dB, fr die simuliert werden soll.
% m        :  Anzahl der fr jeden Wert ebn0db zu simulierenden Kodewrter
% m<1      :  relative gewnschte Genauigkeit der BER.  Die Simulation 
%             passt die Anzahl der Kodewrter der Fehlerrate an.
% mt       :  nach mt Sekunden soll die Berechnung abgebrochen werden
% ber(:,1) :  Eb/N0-Werte
% ber(:,2) :  zugehrige Bitfehlerrate
% ber(:,3) :  Anzahl der Bitfehler (optional)

% Autor: Klaus von der Heide, e-mail:  v.d.heideqon-line.de

if nargin<5      mt = 3600;  end
if nargin<4       m = 0.1;   end
if nargin<3  ebn0db = -1:6;  end
if nargin<2       k = 64;    end
if nargin<1       g = [1 0 1; 1 1 1]; end

t0 = clock;
for kk=1:length(ebn0db)
   nf(kk) = 0;
   mm = 0;
   while (etime(clock,t0)<mt) & ((m>=1 & mm<m) | (m<1 & sqrt(nf(kk)/k+1)>m*nf(kk)/k))
      mm = mm + 1;
      n = turbdemo(randb(k),g,ebn0db(kk));
      nf(kk) = nf(kk) + n;
   end
   ber(kk,:) = [ebn0db(kk)  nf(kk)/k/mm  nf(kk)]
end

[gz,gs] = size(g);
txt = sprintf('(%4d,%4d) -Turbo-Kode  g = [',3*k+gs-1,k);
for kk=1:gs  txt = sprintf('%s%2d',txt,g(1,kk)); end
txt = [txt ';'];
for kk=1:gs  txt = sprintf('%s%2d',txt,g(2,kk)); end
txt = [txt ']'];
if m>=1  nerr = m*k*ber'; else nerr = nf'; end
plotber(ber,txt)