function ber = turbotest(g,ebn0db,n,m,iter)
% ber = turbotest(g,ebn0db,n,m,iter)
% Berechnung der Bitfehlerrate fr den TurboCode mit dem Codegenerator g
%
%  g    :  Code-Generator-Matrix  (Default: [1 1 1 1; 1 1 0 1])
% ebn0db:  Vektor der Werte von Eb/N0, fr die simuliert werden soll
%          (Default: [-1 0 1 2 3])
%  n    :  Anzahl der Informationsbits bei jeder Stichprobe (Default: 16) 
%  m    :  Anzahl der Stichproben fr jeden Wert von Eb/N0 ist 
%          round(m*2*ebn0db) (Default: 4)
%  iter :  Anzahl der Iterationen bei der Decodierung       (Default: 5)

if nargin<1      g = [1 1 1 1; 1 1 0 1]; end
[nz,ns] = size(g);
if nz~=2  error('turbotest luft nur mit zweizeiligem g !'); end
if nargin<2 ebn0db = (-1:+3); end
if nargin<3      n = 16; end
if nargin<4      m = 4;  end
if nargin<5   iter = 5;  end
fsiz = 13;

for k=1:length(ebn0db)
   sf    = 0;                                   % noch keine Bitfehler
   for kk=1:round(m*2^ebn0db)                   % m Stichproben
      nf = turbdemo(randb(n),g,ebn0db(k),iter); % Bitfehler
      sf = sf + nf;                             % Bitfehler akkumulieren
      [ebn0db(k) kk nf]                         % Kontrollausgabe
   end
   ber(k) = sf/m/n;                             % Bitfehlerrate
end

if nargout>0  break; end

fh = fullscreen('BER');                         % Graphik
plot(ebn0db,ber)
set(gca,'YScale','log')
title('Bitfehlerrate fr TurboCode','FontSize',fsiz)
xlabel('E_b/N_0  [dB]','FontSize',fsiz)
ylabel('Bitfehlerrate','FontSize',fsiz)
grid on
