function z = zeitspecgraph(puls,fa,dt,sc)
% zeitspecgraph(puls,fa,dt,sc)
% Darstellung eines Impulses ber der Zeit-Frequenz-Ebene
% puls :  im Zeitbereich abgetasteter Impuls
% fa   :  Abtastfrequenz fr den Impuls
% dt   :  Breite der Zeitintervalle fr die Momentanspektren
%         in Abtastschritten von puls
% sc=0 :  lineare Skalierung
% sc=1 :  Quadratwurzel-Skalierung (Default)
% sc=3 :  logarithmische Skalierung

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
% Defaults und Konstanten
% =======================
if nargin<4  sc = 1;     end
if nargin<3  dt = 8;     end
if nargin<2  fa = 1;     end
if nargin<1  puls = sinc(-50:0.1:+50); end

dt = round(dt);                    % dt muss ganzzahlig sein
n  = length(puls);                 % Lnge des Impulses
wn = hamming(dt)';                 % Fenster fr FFT
b  = floor(dt/2);                  % Index fr Nyquistfreq
fsz= 13;                           % FontSize
%
% Momentanspektrum des Impulses
% =============================
p  = [zeros(1,b),puls,zeros(1,b)]; % Zero-padding
for k = 1:n
   ff = fft(p(k:k+dt-1).*wn);      % lokale FFT
   ff = abs(ff(1:b));              % Momentanspektrum
   z(:,k) = [reverse(ff),ff]';     % Eintragung als Spalte in z
end
%
% Darstellung
% ===========
fh = fullscreen('t-f-Diagramm');
switch sc
   case 0,  zz = z;
   case 1,  zz = sqrt(z);
   case 2,  zz = log10(z+eps);
end
[u,v] = size(zz);
contourf((1:v)/fa,fa*(((1:u)-0.5)/u-0.5),zz,4);
title('Zeit-Frequenz-Bedarf von Impulsen','FontSize',fsz);
xlabel('Zeit  [sec]','FontSize',fsz);
ylabel('Frequenz  [Hz]','FontSize',fsz);
colormap(copper);

% Auflsung
% =========
xyl = axis;
line(xyl(1)+0.07*(xyl(2)-xyl(1))+[0 0.4*dt/fa],xyl(3)+0.1*(xyl(4)-xyl(3))+[0 0],...
     'Color','r','LineWidth',3)
line(xyl(1)+0.07*(xyl(2)-xyl(1))+0.2*dt/fa+[0 0],xyl(3)+0.1*(xyl(4)-xyl(3))+1.2*fa/dt*[-1 1],...
     'Color','r','LineWidth',3)
